Class: Komoju::BalanceShow

Inherits:
ApiModelBase show all
Defined in:
lib/komoju-sdk/models/balance_show.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BalanceShow

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/komoju-sdk/models/balance_show.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::BalanceShow` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::BalanceShow`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'total_balance_cents')
    self.total_balance_cents = attributes[:'total_balance_cents']
  else
    self.total_balance_cents = nil
  end

  if attributes.key?(:'payments')
    self.payments = attributes[:'payments']
  else
    self.payments = nil
  end

  if attributes.key?(:'refunds')
    self.refunds = attributes[:'refunds']
  else
    self.refunds = nil
  end

  if attributes.key?(:'platform_model')
    self.platform_model = attributes[:'platform_model']
  end

  if attributes.key?(:'corrections')
    self.corrections = attributes[:'corrections']
  else
    self.corrections = nil
  end

  if attributes.key?(:'komoju_card_charges')
    self.komoju_card_charges = attributes[:'komoju_card_charges']
  else
    self.komoju_card_charges = nil
  end

  if attributes.key?(:'disbursements')
    self.disbursements = attributes[:'disbursements']
  else
    self.disbursements = nil
  end

  if attributes.key?(:'misc')
    self.misc = attributes[:'misc']
  else
    self.misc = nil
  end
end

Instance Attribute Details

#correctionsObject

Returns the value of attribute corrections.



29
30
31
# File 'lib/komoju-sdk/models/balance_show.rb', line 29

def corrections
  @corrections
end

#currencyObject

Returns the value of attribute currency.



18
19
20
# File 'lib/komoju-sdk/models/balance_show.rb', line 18

def currency
  @currency
end

#disbursementsObject

Returns the value of attribute disbursements.



33
34
35
# File 'lib/komoju-sdk/models/balance_show.rb', line 33

def disbursements
  @disbursements
end

#komoju_card_chargesObject

Returns the value of attribute komoju_card_charges.



31
32
33
# File 'lib/komoju-sdk/models/balance_show.rb', line 31

def komoju_card_charges
  @komoju_card_charges
end

#miscObject

Returns the value of attribute misc.



35
36
37
# File 'lib/komoju-sdk/models/balance_show.rb', line 35

def misc
  @misc
end

#paymentsObject

Returns the value of attribute payments.



23
24
25
# File 'lib/komoju-sdk/models/balance_show.rb', line 23

def payments
  @payments
end

#platform_modelObject

Returns the value of attribute platform_model.



27
28
29
# File 'lib/komoju-sdk/models/balance_show.rb', line 27

def platform_model
  @platform_model
end

#refundsObject

Returns the value of attribute refunds.



25
26
27
# File 'lib/komoju-sdk/models/balance_show.rb', line 25

def refunds
  @refunds
end

#total_balance_centsObject

Amount in the lowest denomination of the currency (e.g. cents for USD).



21
22
23
# File 'lib/komoju-sdk/models/balance_show.rb', line 21

def total_balance_cents
  @total_balance_cents
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
# File 'lib/komoju-sdk/models/balance_show.rb', line 378

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/komoju-sdk/models/balance_show.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/komoju-sdk/models/balance_show.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/komoju-sdk/models/balance_show.rb', line 60

def self.attribute_map
  {
    :'currency' => :'currency',
    :'total_balance_cents' => :'total_balance_cents',
    :'payments' => :'payments',
    :'refunds' => :'refunds',
    :'platform_model' => :'platform_model',
    :'corrections' => :'corrections',
    :'komoju_card_charges' => :'komoju_card_charges',
    :'disbursements' => :'disbursements',
    :'misc' => :'misc'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/komoju-sdk/models/balance_show.rb', line 348

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



106
107
108
109
110
111
# File 'lib/komoju-sdk/models/balance_show.rb', line 106

def self.openapi_all_of
  [
  :'Balance',
  :'SharedDetails'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/komoju-sdk/models/balance_show.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/komoju-sdk/models/balance_show.rb', line 85

def self.openapi_types
  {
    :'currency' => :'Currency',
    :'total_balance_cents' => :'Integer',
    :'payments' => :'SharedDetailsPayments',
    :'refunds' => :'SharedDetailsRefunds',
    :'platform_model' => :'SharedDetailsPlatformModel',
    :'corrections' => :'SharedDetailsCorrections',
    :'komoju_card_charges' => :'SharedDetailsCorrections',
    :'disbursements' => :'SharedDetailsDisbursements',
    :'misc' => :'SharedDetailsMisc'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/komoju-sdk/models/balance_show.rb', line 319

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      currency == o.currency &&
      total_balance_cents == o.total_balance_cents &&
      payments == o.payments &&
      refunds == o.refunds &&
      platform_model == o.platform_model &&
      corrections == o.corrections &&
      komoju_card_charges == o.komoju_card_charges &&
      disbursements == o.disbursements &&
      misc == o.misc
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/komoju-sdk/models/balance_show.rb', line 449

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


335
336
337
# File 'lib/komoju-sdk/models/balance_show.rb', line 335

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



341
342
343
# File 'lib/komoju-sdk/models/balance_show.rb', line 341

def hash
  [currency, total_balance_cents, payments, refunds, platform_model, corrections, komoju_card_charges, disbursements, misc].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/komoju-sdk/models/balance_show.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @total_balance_cents.nil?
    invalid_properties.push('invalid value for "total_balance_cents", total_balance_cents cannot be nil.')
  end

  if @payments.nil?
    invalid_properties.push('invalid value for "payments", payments cannot be nil.')
  end

  if @refunds.nil?
    invalid_properties.push('invalid value for "refunds", refunds cannot be nil.')
  end

  if @corrections.nil?
    invalid_properties.push('invalid value for "corrections", corrections cannot be nil.')
  end

  if @komoju_card_charges.nil?
    invalid_properties.push('invalid value for "komoju_card_charges", komoju_card_charges cannot be nil.')
  end

  if @disbursements.nil?
    invalid_properties.push('invalid value for "disbursements", disbursements cannot be nil.')
  end

  if @misc.nil?
    invalid_properties.push('invalid value for "misc", misc cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



425
426
427
# File 'lib/komoju-sdk/models/balance_show.rb', line 425

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/komoju-sdk/models/balance_show.rb', line 431

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



419
420
421
# File 'lib/komoju-sdk/models/balance_show.rb', line 419

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/komoju-sdk/models/balance_show.rb', line 224

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @currency.nil?
  return false if @total_balance_cents.nil?
  return false if @payments.nil?
  return false if @refunds.nil?
  return false if @corrections.nil?
  return false if @komoju_card_charges.nil?
  return false if @disbursements.nil?
  return false if @misc.nil?
  true
end