Class: Komoju::ChargebackDefense
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Komoju::ChargebackDefense
- Defined in:
- lib/komoju-sdk/models/chargeback_defense.rb
Instance Attribute Summary collapse
-
#documents ⇒ Object
Supporting documents submitted with the defense.
-
#product_name ⇒ Object
Name of the product or service, or null if not provided.
-
#reason ⇒ Object
The merchant's defense reason.
-
#recipient_info ⇒ Object
Returns the value of attribute recipient_info.
-
#shipping_info ⇒ Object
Returns the value of attribute shipping_info.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChargebackDefense
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ChargebackDefense
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ChargebackDefense` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ChargebackDefense`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'product_name') self.product_name = attributes[:'product_name'] else self.product_name = nil end if attributes.key?(:'reason') self.reason = attributes[:'reason'] else self.reason = nil end if attributes.key?(:'shipping_info') self.shipping_info = attributes[:'shipping_info'] else self.shipping_info = nil end if attributes.key?(:'recipient_info') self.recipient_info = attributes[:'recipient_info'] else self.recipient_info = nil end if attributes.key?(:'documents') if (value = attributes[:'documents']).is_a?(Array) self.documents = value end else self.documents = nil end end |
Instance Attribute Details
#documents ⇒ Object
Supporting documents submitted with the defense.
29 30 31 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 29 def documents @documents end |
#product_name ⇒ Object
Name of the product or service, or null if not provided.
19 20 21 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 19 def product_name @product_name end |
#reason ⇒ Object
The merchant's defense reason.
22 23 24 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 22 def reason @reason end |
#recipient_info ⇒ Object
Returns the value of attribute recipient_info.
26 27 28 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 26 def recipient_info @recipient_info end |
#shipping_info ⇒ Object
Returns the value of attribute shipping_info.
24 25 26 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 24 def shipping_info @shipping_info end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 251 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 32 def self.attribute_map { :'product_name' => :'product_name', :'reason' => :'reason', :'shipping_info' => :'shipping_info', :'recipient_info' => :'recipient_info', :'documents' => :'documents' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 221 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 68 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 64 def self.openapi_nullable Set.new([ :'product_name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 53 def self.openapi_types { :'product_name' => :'String', :'reason' => :'String', :'shipping_info' => :'ChargebackDefenseShippingInfo', :'recipient_info' => :'ChargebackDefenseRecipientInfo', :'documents' => :'Array<ChargebackDefenseDocument>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
196 197 198 199 200 201 202 203 204 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 196 def ==(o) return true if self.equal?(o) self.class == o.class && product_name == o.product_name && reason == o.reason && shipping_info == o.shipping_info && recipient_info == o.recipient_info && documents == o.documents end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 322 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
208 209 210 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 208 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
214 215 216 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 214 def hash [product_name, reason, shipping_info, recipient_info, documents].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 121 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @reason.nil? invalid_properties.push('invalid value for "reason", reason cannot be nil.') end if @shipping_info.nil? invalid_properties.push('invalid value for "shipping_info", shipping_info cannot be nil.') end if @recipient_info.nil? invalid_properties.push('invalid value for "recipient_info", recipient_info cannot be nil.') end if @documents.nil? invalid_properties.push('invalid value for "documents", documents cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
298 299 300 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 298 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 292 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 152 |
# File 'lib/komoju-sdk/models/chargeback_defense.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @reason.nil? return false if @shipping_info.nil? return false if @recipient_info.nil? return false if @documents.nil? true end |