Class: Komoju::ChargebackPayment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Komoju::ChargebackPayment
- Defined in:
- lib/komoju-sdk/models/chargeback_payment.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#captured_at ⇒ Object
Timestamp when the payment was captured, or null.
-
#created_at ⇒ Object
Timestamp when the payment was created.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
-
#masked_card_number ⇒ Object
Masked card number, or null if not applicable.
-
#payment_method ⇒ Object
Returns the value of attribute payment_method.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChargebackPayment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ChargebackPayment
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ChargebackPayment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ChargebackPayment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'captured_at') self.captured_at = attributes[:'captured_at'] else self.captured_at = nil end if attributes.key?(:'payment_method') self.payment_method = attributes[:'payment_method'] else self.payment_method = nil end if attributes.key?(:'masked_card_number') self.masked_card_number = attributes[:'masked_card_number'] else self.masked_card_number = nil end end |
Instance Attribute Details
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
22 23 24 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 22 def amount @amount end |
#captured_at ⇒ Object
Timestamp when the payment was captured, or null.
30 31 32 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 30 def captured_at @captured_at end |
#created_at ⇒ Object
Timestamp when the payment was created.
27 28 29 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 27 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
24 25 26 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 24 def currency @currency end |
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
19 20 21 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 19 def id @id end |
#masked_card_number ⇒ Object
Masked card number, or null if not applicable.
35 36 37 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 35 def masked_card_number @masked_card_number end |
#payment_method ⇒ Object
Returns the value of attribute payment_method.
32 33 34 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 32 def payment_method @payment_method end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 338 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 60 def self.attribute_map { :'id' => :'id', :'amount' => :'amount', :'currency' => :'currency', :'created_at' => :'created_at', :'captured_at' => :'captured_at', :'payment_method' => :'payment_method', :'masked_card_number' => :'masked_card_number' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 308 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 100 101 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 96 def self.openapi_nullable Set.new([ :'captured_at', :'masked_card_number' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 83 def self.openapi_types { :'id' => :'String', :'amount' => :'Integer', :'currency' => :'Currency', :'created_at' => :'Time', :'captured_at' => :'Time', :'payment_method' => :'ChargebackPaymentMethod', :'masked_card_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 281 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && amount == o.amount && currency == o.currency && created_at == o.created_at && captured_at == o.captured_at && payment_method == o.payment_method && masked_card_number == o.masked_card_number end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 409 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
295 296 297 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 295 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
301 302 303 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 301 def hash [id, amount, currency, created_at, captured_at, payment_method, masked_card_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length > 25 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.') end if @id.to_s.length < 25 invalid_properties.push('invalid value for "id", the character length must be greater than or equal to 25.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @amount < 0 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @payment_method.nil? invalid_properties.push('invalid value for "payment_method", payment_method cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
385 386 387 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 385 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 391 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
379 380 381 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 379 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/komoju-sdk/models/chargeback_payment.rb', line 204 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id.to_s.length > 25 return false if @id.to_s.length < 25 return false if @amount.nil? return false if @amount < 0 return false if @currency.nil? return false if @created_at.nil? return false if @payment_method.nil? true end |