Class: Komoju::ChargebackRequestListItem

Inherits:
ApiModelBase show all
Defined in:
lib/komoju-sdk/models/chargeback_request_list_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ChargebackRequestListItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ChargebackRequestListItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ChargebackRequestListItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'payment_id')
    self.payment_id = attributes[:'payment_id']
  else
    self.payment_id = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  else
    self.payment_method = nil
  end

  if attributes.key?(:'reason_code')
    self.reason_code = attributes[:'reason_code']
  else
    self.reason_code = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  else
    self.due_date = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end
end

Instance Attribute Details

#amountObject

Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).



25
26
27
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 25

def amount
  @amount
end

#created_atObject

Timestamp when the chargeback was created.



38
39
40
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 38

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



27
28
29
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 27

def currency
  @currency
end

#due_dateObject

Deadline by which the merchant must respond.



41
42
43
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 41

def due_date
  @due_date
end

#idObject

A unique 25-character alphanumeric resource identifier.



19
20
21
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 19

def id
  @id
end

#payment_idObject

A unique 25-character alphanumeric resource identifier.



22
23
24
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 22

def payment_id
  @payment_id
end

#payment_methodObject

Returns the value of attribute payment_method.



29
30
31
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 29

def payment_method
  @payment_method
end

#reasonObject

Human-readable chargeback reason corresponding to the reason code.



35
36
37
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 35

def reason
  @reason
end

#reason_codeObject

Machine-readable reason code. Internal codes (e.g. "CB_Fraud") are used by default; for Worldpay Visa/Mastercard payments the network's own reason codes are used instead (e.g. "10.4" or "4837").



32
33
34
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 32

def reason_code
  @reason_code
end

#statusObject

Returns the value of attribute status.



43
44
45
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 43

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 464

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 68

def self.attribute_map
  {
    :'id' => :'id',
    :'payment_id' => :'payment_id',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'payment_method' => :'payment_method',
    :'reason_code' => :'reason_code',
    :'reason' => :'reason',
    :'created_at' => :'created_at',
    :'due_date' => :'due_date',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 434

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 110

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 94

def self.openapi_types
  {
    :'id' => :'String',
    :'payment_id' => :'String',
    :'amount' => :'Integer',
    :'currency' => :'Currency',
    :'payment_method' => :'ChargebackPaymentMethod',
    :'reason_code' => :'String',
    :'reason' => :'String',
    :'created_at' => :'Time',
    :'due_date' => :'Time',
    :'status' => :'ChargebackStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



404
405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 404

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      payment_id == o.payment_id &&
      amount == o.amount &&
      currency == o.currency &&
      payment_method == o.payment_method &&
      reason_code == o.reason_code &&
      reason == o.reason &&
      created_at == o.created_at &&
      due_date == o.due_date &&
      status == o.status
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



535
536
537
538
539
540
541
542
543
544
545
546
547
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 535

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


421
422
423
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 421

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



427
428
429
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 427

def hash
  [id, payment_id, amount, currency, payment_method, reason_code, reason, created_at, due_date, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 194

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @id.to_s.length > 25
    invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.')
  end

  if @id.to_s.length < 25
    invalid_properties.push('invalid value for "id", the character length must be greater than or equal to 25.')
  end

  if @payment_id.nil?
    invalid_properties.push('invalid value for "payment_id", payment_id cannot be nil.')
  end

  if @payment_id.to_s.length > 25
    invalid_properties.push('invalid value for "payment_id", the character length must be smaller than or equal to 25.')
  end

  if @payment_id.to_s.length < 25
    invalid_properties.push('invalid value for "payment_id", the character length must be greater than or equal to 25.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @payment_method.nil?
    invalid_properties.push('invalid value for "payment_method", payment_method cannot be nil.')
  end

  if @reason_code.nil?
    invalid_properties.push('invalid value for "reason_code", reason_code cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @due_date.nil?
    invalid_properties.push('invalid value for "due_date", due_date cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



511
512
513
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 511

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



517
518
519
520
521
522
523
524
525
526
527
528
529
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 517

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



505
506
507
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 505

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/komoju-sdk/models/chargeback_request_list_item.rb', line 262

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @id.to_s.length > 25
  return false if @id.to_s.length < 25
  return false if @payment_id.nil?
  return false if @payment_id.to_s.length > 25
  return false if @payment_id.to_s.length < 25
  return false if @amount.nil?
  return false if @amount < 0
  return false if @currency.nil?
  return false if @payment_method.nil?
  return false if @reason_code.nil?
  return false if @reason.nil?
  return false if @created_at.nil?
  return false if @due_date.nil?
  return false if @status.nil?
  true
end