Class: Komoju::CreateDisbursementRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/create_disbursement_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateDisbursementRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::CreateDisbursementRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::CreateDisbursementRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'account_number')
    self. = attributes[:'account_number']
  else
    self. = nil
  end

  if attributes.key?(:'account_type')
    self. = attributes[:'account_type']
  else
    self. = nil
  end

  if attributes.key?(:'account_name_kana')
    self. = attributes[:'account_name_kana']
  else
    self. = nil
  end

  if attributes.key?(:'bank_code')
    self.bank_code = attributes[:'bank_code']
  else
    self.bank_code = nil
  end

  if attributes.key?(:'branch_code')
    self.branch_code = attributes[:'branch_code']
  else
    self.branch_code = nil
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end
end

Instance Attribute Details

#account_name_kanaObject

Name of the recipient bank account holder in katakana.



30
31
32
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 30

def 
  @account_name_kana
end

#account_numberObject

Recipient’s bank account number.



24
25
26
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 24

def 
  @account_number
end

#account_typeObject

Type of the recipient’s bank account.



27
28
29
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 27

def 
  @account_type
end

#amountObject

Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).



19
20
21
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 19

def amount
  @amount
end

#bank_codeObject

4-digit Zengin bank code.



33
34
35
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 33

def bank_code
  @bank_code
end

#branch_codeObject

3-digit Zengin branch code.



36
37
38
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 36

def branch_code
  @branch_code
end

#currencyObject

Returns the value of attribute currency.



21
22
23
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 21

def currency
  @currency
end

#external_idObject

Merchant-assigned external reference ID for this disbursement.



39
40
41
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 39

def external_id
  @external_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 305

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 64

def self.attribute_map
  {
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'account_number' => :'account_number',
    :'account_type' => :'account_type',
    :'account_name_kana' => :'account_name_kana',
    :'bank_code' => :'bank_code',
    :'branch_code' => :'branch_code',
    :'external_id' => :'external_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 83

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'currency' => :'Currency',
    :'account_number' => :'String',
    :'account_type' => :'String',
    :'account_name_kana' => :'String',
    :'bank_code' => :'String',
    :'branch_code' => :'String',
    :'external_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      currency == o.currency &&
       == o. &&
       == o. &&
       == o. &&
      bank_code == o.bank_code &&
      branch_code == o.branch_code &&
      external_id == o.external_id
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 376

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 268

def hash
  [amount, currency, , , , bank_code, branch_code, external_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @account_number.nil?
    invalid_properties.push('invalid value for "account_number", account_number cannot be nil.')
  end

  if @account_type.nil?
    invalid_properties.push('invalid value for "account_type", account_type cannot be nil.')
  end

  if @account_name_kana.nil?
    invalid_properties.push('invalid value for "account_name_kana", account_name_kana cannot be nil.')
  end

  if @bank_code.nil?
    invalid_properties.push('invalid value for "bank_code", bank_code cannot be nil.')
  end

  if @branch_code.nil?
    invalid_properties.push('invalid value for "branch_code", branch_code cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



352
353
354
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 352

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 358

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



346
347
348
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 346

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/komoju-sdk/models/create_disbursement_request.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 0
  return false if @currency.nil?
  return false if @account_number.nil?
  return false if @account_type.nil?
   = EnumAttributeValidator.new('String', ["ordinary", "checking"])
  return false unless .valid?(@account_type)
  return false if @account_name_kana.nil?
  return false if @bank_code.nil?
  return false if @branch_code.nil?
  true
end