Class: Komoju::CreatePaymentRequestWithCustomer

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/create_payment_request_with_customer.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreatePaymentRequestWithCustomer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::CreatePaymentRequestWithCustomer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::CreatePaymentRequestWithCustomer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'capture')
    self.capture = attributes[:'capture']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'tax')
    self.tax = attributes[:'tax']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'external_order_num')
    self.external_order_num = attributes[:'external_order_num']
  end

  if attributes.key?(:'return_url')
    self.return_url = attributes[:'return_url']
  end

  if attributes.key?(:'cancel_url')
    self.cancel_url = attributes[:'cancel_url']
  end

  if attributes.key?(:'locale')
    self.locale = attributes[:'locale']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'mcc')
    self.mcc = attributes[:'mcc']
  end

  if attributes.key?(:'statement_descriptor')
    self.statement_descriptor = attributes[:'statement_descriptor']
  end

  if attributes.key?(:'fraud_details')
    self.fraud_details = attributes[:'fraud_details']
  end

  if attributes.key?(:'platform_details')
    self.platform_details = attributes[:'platform_details']
  end

  if attributes.key?(:'customer')
    self.customer = attributes[:'customer']
  else
    self.customer = nil
  end
end

Instance Attribute Details

#amountObject

The payment amount before tax, greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).



20
21
22
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 20

def amount
  @amount
end

#cancel_urlObject

For offsite payment methods, specify the URL where user will be redirected to if they cancel the payment.



39
40
41
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 39

def cancel_url
  @cancel_url
end

#captureObject

If ‘false`, the payment will be authorized on success, and you must manually capture it later to secure funds. The payment will be captured immediately if omitted.



23
24
25
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 23

def capture
  @capture
end

#currencyObject

Returns the value of attribute currency.



30
31
32
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 30

def currency
  @currency
end

#customerObject

For a subscription payment, specify customer’s identifier for this payment. This identifier can be obtained from [Customer: Create](doc.komoju.com/reference/createcustomer) endpoint.



56
57
58
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 56

def customer
  @customer
end

#descriptionObject

A description from your application for this payment.



26
27
28
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 26

def description
  @description
end

#external_order_numObject

A unique ID from your application used to track this payment.



33
34
35
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 33

def external_order_num
  @external_order_num
end

#fraud_detailsObject

Returns the value of attribute fraud_details.



51
52
53
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 51

def fraud_details
  @fraud_details
end

#localeObject

Returns the value of attribute locale.



41
42
43
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 41

def locale
  @locale
end

#mccObject

On supported merchant and supported payment methods, specify a custom Merchant Category Code (MCC) for this payment. See [Dynamic Statement Descriptors & MCCs](doc.komoju.com/docs/payments-with-dynamic-statement-descriptors) for more information.



47
48
49
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 47

def mcc
  @mcc
end

#metadataObject

Specify a key-value map which will be stored on the payment. You can use this field to store metadata related to this payment. Keys and values must be strings. Keys have a maximum length of 30 characters. Values have a maximum length of 2000 characters.



44
45
46
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 44

def 
  @metadata
end

#platform_detailsObject

Returns the value of attribute platform_details.



53
54
55
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 53

def platform_details
  @platform_details
end

#return_urlObject

For offsite payment methods, specify the URL where user will be redirected to after they have completed the payment.



36
37
38
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 36

def return_url
  @return_url
end

#statement_descriptorObject

Returns the value of attribute statement_descriptor.



49
50
51
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 49

def statement_descriptor
  @statement_descriptor
end

#taxObject

Returns the value of attribute tax.



28
29
30
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 28

def tax
  @tax
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 387

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



102
103
104
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 102

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 81

def self.attribute_map
  {
    :'amount' => :'amount',
    :'capture' => :'capture',
    :'description' => :'description',
    :'tax' => :'tax',
    :'currency' => :'currency',
    :'external_order_num' => :'external_order_num',
    :'return_url' => :'return_url',
    :'cancel_url' => :'cancel_url',
    :'locale' => :'locale',
    :'metadata' => :'metadata',
    :'mcc' => :'mcc',
    :'statement_descriptor' => :'statement_descriptor',
    :'fraud_details' => :'fraud_details',
    :'platform_details' => :'platform_details',
    :'customer' => :'customer'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 357

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 107

def self.openapi_types
  {
    :'amount' => :'Integer',
    :'capture' => :'Boolean',
    :'description' => :'String',
    :'tax' => :'CreatePaymentRequestWithPaymentDetailsTax',
    :'currency' => :'Currency',
    :'external_order_num' => :'String',
    :'return_url' => :'String',
    :'cancel_url' => :'String',
    :'locale' => :'Locale',
    :'metadata' => :'Object',
    :'mcc' => :'String',
    :'statement_descriptor' => :'StatementDescriptor',
    :'fraud_details' => :'FraudDetails',
    :'platform_details' => :'PlatformDetails',
    :'customer' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      capture == o.capture &&
      description == o.description &&
      tax == o.tax &&
      currency == o.currency &&
      external_order_num == o.external_order_num &&
      return_url == o.return_url &&
      cancel_url == o.cancel_url &&
      locale == o.locale &&
       == o. &&
      mcc == o.mcc &&
      statement_descriptor == o.statement_descriptor &&
      fraud_details == o.fraud_details &&
      platform_details == o.platform_details &&
      customer == o.customer
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 458

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


344
345
346
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 344

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



350
351
352
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 350

def hash
  [amount, capture, description, tax, currency, external_order_num, return_url, cancel_url, locale, , mcc, statement_descriptor, fraud_details, platform_details, customer].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 217

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if !@mcc.nil? && @mcc.to_s.length > 4
    invalid_properties.push('invalid value for "mcc", the character length must be smaller than or equal to 4.')
  end

  if !@mcc.nil? && @mcc.to_s.length < 4
    invalid_properties.push('invalid value for "mcc", the character length must be great than or equal to 4.')
  end

  if @customer.nil?
    invalid_properties.push('invalid value for "customer", customer cannot be nil.')
  end

  if @customer.to_s.length > 25
    invalid_properties.push('invalid value for "customer", the character length must be smaller than or equal to 25.')
  end

  if @customer.to_s.length < 25
    invalid_properties.push('invalid value for "customer", the character length must be great than or equal to 25.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



434
435
436
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 434

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 440

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



428
429
430
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 428

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/komoju-sdk/models/create_payment_request_with_customer.rb', line 257

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @amount < 0
  return false if @currency.nil?
  return false if !@mcc.nil? && @mcc.to_s.length > 4
  return false if !@mcc.nil? && @mcc.to_s.length < 4
  return false if @customer.nil?
  return false if @customer.to_s.length > 25
  return false if @customer.to_s.length < 25
  true
end