Class: Komoju::CreateSessionRequestWithCustomerPaymentMode
- Inherits:
-
Object
- Object
- Komoju::CreateSessionRequestWithCustomerPaymentMode
- Defined in:
- lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer_id ⇒ Object
If provided, updated payment details will be saved on the customer.
-
#default_locale ⇒ Object
Returns the value of attribute default_locale.
-
#email ⇒ Object
Customer’s email address.
-
#expires_in_seconds ⇒ Object
Time in seconds until the session expires after being created.
-
#external_customer_id ⇒ Object
An unique identifier of your customer.
-
#line_items ⇒ Object
Specify the line items which will be displayed on the session page.
-
#metadata ⇒ Object
Store any additional data you want to associate with the session.
-
#mode ⇒ Object
In ‘customer_payment` mode, a payment will be created and: * If `customer_id` is omitted, a new customer will be created.
-
#payment_data ⇒ Object
Returns the value of attribute payment_data.
-
#payment_types ⇒ Object
Specify which payment types are available for this session.
-
#return_url ⇒ Object
Specify the URL where user will be redirected to after they have completed or aborted the session.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateSessionRequestWithCustomerPaymentMode
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateSessionRequestWithCustomerPaymentMode
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::CreateSessionRequestWithCustomerPaymentMode` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::CreateSessionRequestWithCustomerPaymentMode`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'mode') self.mode = attributes[:'mode'] else self.mode = nil end if attributes.key?(:'return_url') self.return_url = attributes[:'return_url'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'expires_in_seconds') self.expires_in_seconds = attributes[:'expires_in_seconds'] end if attributes.key?(:'external_customer_id') self.external_customer_id = attributes[:'external_customer_id'] end if attributes.key?(:'payment_types') if (value = attributes[:'payment_types']).is_a?(Array) self.payment_types = value end end if attributes.key?(:'default_locale') self.default_locale = attributes[:'default_locale'] end if attributes.key?(:'line_items') if (value = attributes[:'line_items']).is_a?(Array) self.line_items = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'payment_data') self.payment_data = attributes[:'payment_data'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end end |
Instance Attribute Details
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
26 27 28 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 26 def amount @amount end |
#currency ⇒ Object
Returns the value of attribute currency.
28 29 30 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 28 def currency @currency end |
#customer_id ⇒ Object
If provided, updated payment details will be saved on the customer.
53 54 55 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 53 def customer_id @customer_id end |
#default_locale ⇒ Object
Returns the value of attribute default_locale.
42 43 44 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 42 def default_locale @default_locale end |
#email ⇒ Object
Customer’s email address.
31 32 33 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 31 def email @email end |
#expires_in_seconds ⇒ Object
Time in seconds until the session expires after being created. The default value and upper limit are 86,400 seconds (24 hours).
34 35 36 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 34 def expires_in_seconds @expires_in_seconds end |
#external_customer_id ⇒ Object
An unique identifier of your customer. If your system has the concept of user accounts, then the ID of the current logged in user would be appropriate.
37 38 39 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 37 def external_customer_id @external_customer_id end |
#line_items ⇒ Object
Specify the line items which will be displayed on the session page.
45 46 47 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 45 def line_items @line_items end |
#metadata ⇒ Object
Store any additional data you want to associate with the session. The object’s keys and values must be strings. Keys have a maximum length of 30 characters. Values have a maximum length of 2000 characters.
48 49 50 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 48 def @metadata end |
#mode ⇒ Object
In ‘customer_payment` mode, a payment will be created and: * If `customer_id` is omitted, a new customer will be created. * If `customer_id` is given, updated payment information will be saved to that customer.
20 21 22 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 20 def mode @mode end |
#payment_data ⇒ Object
Returns the value of attribute payment_data.
50 51 52 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 50 def payment_data @payment_data end |
#payment_types ⇒ Object
Specify which payment types are available for this session. By default, all activated payment methods will be available for the session if this value is omitted.
40 41 42 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 40 def payment_types @payment_types end |
#return_url ⇒ Object
Specify the URL where user will be redirected to after they have completed or aborted the session. A ‘session_id` will be appended to this URL as a query parameter.
23 24 25 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 23 def return_url @return_url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 339 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 97 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 78 def self.attribute_map { :'mode' => :'mode', :'return_url' => :'return_url', :'amount' => :'amount', :'currency' => :'currency', :'email' => :'email', :'expires_in_seconds' => :'expires_in_seconds', :'external_customer_id' => :'external_customer_id', :'payment_types' => :'payment_types', :'default_locale' => :'default_locale', :'line_items' => :'line_items', :'metadata' => :'metadata', :'payment_data' => :'payment_data', :'customer_id' => :'customer_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 102 def self.openapi_types { :'mode' => :'String', :'return_url' => :'String', :'amount' => :'Integer', :'currency' => :'Currency', :'email' => :'String', :'expires_in_seconds' => :'Integer', :'external_customer_id' => :'String', :'payment_types' => :'Array<PaymentType>', :'default_locale' => :'Locale', :'line_items' => :'Array<LineItem>', :'metadata' => :'Object', :'payment_data' => :'PaymentDataRequest', :'customer_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 276 def ==(o) return true if self.equal?(o) self.class == o.class && mode == o.mode && return_url == o.return_url && amount == o.amount && currency == o.currency && email == o.email && expires_in_seconds == o.expires_in_seconds && external_customer_id == o.external_customer_id && payment_types == o.payment_types && default_locale == o.default_locale && line_items == o.line_items && == o. && payment_data == o.payment_data && customer_id == o.customer_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 410 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 302 def hash [mode, return_url, amount, currency, email, expires_in_seconds, external_customer_id, payment_types, default_locale, line_items, , payment_data, customer_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 206 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @mode.nil? invalid_properties.push('invalid value for "mode", mode cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if !@customer_id.nil? && @customer_id.to_s.length > 25 invalid_properties.push('invalid value for "customer_id", the character length must be smaller than or equal to 25.') end if !@customer_id.nil? && @customer_id.to_s.length < 25 invalid_properties.push('invalid value for "customer_id", the character length must be great than or equal to 25.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
386 387 388 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 386 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 392 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
380 381 382 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 380 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/komoju-sdk/models/create_session_request_with_customer_payment_mode.rb', line 234 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @mode.nil? mode_validator = EnumAttributeValidator.new('String', ["customer_payment"]) return false unless mode_validator.valid?(@mode) return false if @amount.nil? return false if @currency.nil? return false if !@customer_id.nil? && @customer_id.to_s.length > 25 return false if !@customer_id.nil? && @customer_id.to_s.length < 25 true end |