Class: Komoju::CreateSessionRequestWithPaymentMode

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/komoju-sdk/models/create_session_request_with_payment_mode.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSessionRequestWithPaymentMode

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::CreateSessionRequestWithPaymentMode` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::CreateSessionRequestWithPaymentMode`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'return_url')
    self.return_url = attributes[:'return_url']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'expires_in_seconds')
    self.expires_in_seconds = attributes[:'expires_in_seconds']
  end

  if attributes.key?(:'external_customer_id')
    self.external_customer_id = attributes[:'external_customer_id']
  end

  if attributes.key?(:'payment_types')
    if (value = attributes[:'payment_types']).is_a?(Array)
      self.payment_types = value
    end
  end

  if attributes.key?(:'default_locale')
    self.default_locale = attributes[:'default_locale']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'payment_data')
    self.payment_data = attributes[:'payment_data']
  end
end

Instance Attribute Details

#amountObject

Amount greater than 0, in the lowest denomination of the currency (e.g. cents for USD).



23
24
25
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 23

def amount
  @amount
end

#currencyObject

Returns the value of attribute currency.



28
29
30
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 28

def currency
  @currency
end

#default_localeObject

Returns the value of attribute default_locale.



42
43
44
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 42

def default_locale
  @default_locale
end

#emailObject

Customer's email address.



31
32
33
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 31

def email
  @email
end

#expires_in_secondsObject

Time in seconds until the session expires after being created. The default value and upper limit are 86,400 seconds (24 hours).



34
35
36
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 34

def expires_in_seconds
  @expires_in_seconds
end

#external_customer_idObject

An unique identifier of your customer. If your system has the concept of user accounts, then the ID of the current logged in user would be appropriate.



37
38
39
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 37

def external_customer_id
  @external_customer_id
end

#line_itemsObject

Specify the line items which will be displayed on the session page.



45
46
47
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 45

def line_items
  @line_items
end

#metadataObject

Store any additional data you want to associate with the session. The object's keys and values must be strings. Keys have a maximum length of 30 characters. Values have a maximum length of 2000 characters.



48
49
50
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 48

def 
  @metadata
end

#modeObject

In payment mode, a payment will be created after customer has completed the session. payment is the default mode and may be omitted.



20
21
22
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 20

def mode
  @mode
end

#payment_dataObject

Returns the value of attribute payment_data.



50
51
52
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 50

def payment_data
  @payment_data
end

#payment_typesObject

Specify which payment types are available for this session. By default, all activated payment methods will be available for the session if this value is omitted.



40
41
42
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 40

def payment_types
  @payment_types
end

#return_urlObject

Specify the URL where user will be redirected to after they have completed or aborted the session. A session_id will be appended to this URL as a query parameter.



26
27
28
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 26

def return_url
  @return_url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 320

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



93
94
95
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 98

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 75

def self.attribute_map
  {
    :'mode' => :'mode',
    :'amount' => :'amount',
    :'return_url' => :'return_url',
    :'currency' => :'currency',
    :'email' => :'email',
    :'expires_in_seconds' => :'expires_in_seconds',
    :'external_customer_id' => :'external_customer_id',
    :'payment_types' => :'payment_types',
    :'default_locale' => :'default_locale',
    :'line_items' => :'line_items',
    :'metadata' => :'metadata',
    :'payment_data' => :'payment_data'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 290

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 121

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 103

def self.openapi_types
  {
    :'mode' => :'String',
    :'amount' => :'Integer',
    :'return_url' => :'String',
    :'currency' => :'Currency',
    :'email' => :'String',
    :'expires_in_seconds' => :'Integer',
    :'external_customer_id' => :'String',
    :'payment_types' => :'Array<PaymentType>',
    :'default_locale' => :'Locale',
    :'line_items' => :'Array<LineItem>',
    :'metadata' => :'Object',
    :'payment_data' => :'PaymentDataRequest'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 258

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      mode == o.mode &&
      amount == o.amount &&
      return_url == o.return_url &&
      currency == o.currency &&
      email == o.email &&
      expires_in_seconds == o.expires_in_seconds &&
      external_customer_id == o.external_customer_id &&
      payment_types == o.payment_types &&
      default_locale == o.default_locale &&
      line_items == o.line_items &&
       == o. &&
      payment_data == o.payment_data
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 391

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


277
278
279
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 277

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



283
284
285
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 283

def hash
  [mode, amount, return_url, currency, email, expires_in_seconds, external_customer_id, payment_types, default_locale, line_items, , payment_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 201

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



367
368
369
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 367

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 373

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



361
362
363
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 361

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
220
221
222
223
224
# File 'lib/komoju-sdk/models/create_session_request_with_payment_mode.rb', line 217

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  mode_validator = EnumAttributeValidator.new('String', ["payment"])
  return false unless mode_validator.valid?(@mode)
  return false if @amount.nil?
  return false if @currency.nil?
  true
end