Class: Komoju::ErroredField

Inherits:
ApiModelBase show all
Defined in:
lib/komoju-sdk/models/errored_field.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ErroredField

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/komoju-sdk/models/errored_field.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ErroredField` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ErroredField`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'field_type')
    self.field_type = attributes[:'field_type']
  else
    self.field_type = nil
  end

  if attributes.key?(:'field')
    self.field = attributes[:'field']
  else
    self.field = nil
  end

  if attributes.key?(:'field_name')
    self.field_name = attributes[:'field_name']
  else
    self.field_name = nil
  end

  if attributes.key?(:'field_properties')
    self.field_properties = attributes[:'field_properties']
  else
    self.field_properties = nil
  end

  if attributes.key?(:'position')
    self.position = attributes[:'position']
  else
    self.position = nil
  end

  if attributes.key?(:'optional')
    self.optional = attributes[:'optional']
  else
    self.optional = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'error')
    if (value = attributes[:'error']).is_a?(Array)
      self.error = value
    end
  else
    self.error = nil
  end
end

Instance Attribute Details

#errorObject

Returns the value of attribute error.



37
38
39
# File 'lib/komoju-sdk/models/errored_field.rb', line 37

def error
  @error
end

#fieldObject

Machine-readable key name of the field.



22
23
24
# File 'lib/komoju-sdk/models/errored_field.rb', line 22

def field
  @field
end

#field_nameObject

Human-readable display name of the field.



25
26
27
# File 'lib/komoju-sdk/models/errored_field.rb', line 25

def field_name
  @field_name
end

#field_propertiesObject

Returns the value of attribute field_properties.



27
28
29
# File 'lib/komoju-sdk/models/errored_field.rb', line 27

def field_properties
  @field_properties
end

#field_typeObject

The input type for this field (e.g. "text", "file", "boolean").



19
20
21
# File 'lib/komoju-sdk/models/errored_field.rb', line 19

def field_type
  @field_type
end

#optionalObject

Whether this field is optional (true) or required (false).



33
34
35
# File 'lib/komoju-sdk/models/errored_field.rb', line 33

def optional
  @optional
end

#positionObject

Display order position of this field in the application form.



30
31
32
# File 'lib/komoju-sdk/models/errored_field.rb', line 30

def position
  @position
end

#valueObject

Returns the value of attribute value.



35
36
37
# File 'lib/komoju-sdk/models/errored_field.rb', line 35

def value
  @value
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/komoju-sdk/models/errored_field.rb', line 352

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/komoju-sdk/models/errored_field.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/komoju-sdk/models/errored_field.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/komoju-sdk/models/errored_field.rb', line 40

def self.attribute_map
  {
    :'field_type' => :'field_type',
    :'field' => :'field',
    :'field_name' => :'field_name',
    :'field_properties' => :'field_properties',
    :'position' => :'position',
    :'optional' => :'optional',
    :'value' => :'value',
    :'error' => :'error'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/komoju-sdk/models/errored_field.rb', line 322

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



84
85
86
87
88
# File 'lib/komoju-sdk/models/errored_field.rb', line 84

def self.openapi_all_of
  [
  :'SubmittedField'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/komoju-sdk/models/errored_field.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/komoju-sdk/models/errored_field.rb', line 64

def self.openapi_types
  {
    :'field_type' => :'String',
    :'field' => :'String',
    :'field_name' => :'String',
    :'field_properties' => :'FieldFieldProperties',
    :'position' => :'Integer',
    :'optional' => :'Boolean',
    :'value' => :'SubmittedFieldAllOfValue',
    :'error' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/komoju-sdk/models/errored_field.rb', line 294

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      field_type == o.field_type &&
      field == o.field &&
      field_name == o.field_name &&
      field_properties == o.field_properties &&
      position == o.position &&
      optional == o.optional &&
      value == o.value &&
      error == o.error
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/komoju-sdk/models/errored_field.rb', line 423

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


309
310
311
# File 'lib/komoju-sdk/models/errored_field.rb', line 309

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



315
316
317
# File 'lib/komoju-sdk/models/errored_field.rb', line 315

def hash
  [field_type, field, field_name, field_properties, position, optional, value, error].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/komoju-sdk/models/errored_field.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @field_type.nil?
    invalid_properties.push('invalid value for "field_type", field_type cannot be nil.')
  end

  if @field.nil?
    invalid_properties.push('invalid value for "field", field cannot be nil.')
  end

  if @field_name.nil?
    invalid_properties.push('invalid value for "field_name", field_name cannot be nil.')
  end

  if @field_properties.nil?
    invalid_properties.push('invalid value for "field_properties", field_properties cannot be nil.')
  end

  if @position.nil?
    invalid_properties.push('invalid value for "position", position cannot be nil.')
  end

  if @optional.nil?
    invalid_properties.push('invalid value for "optional", optional cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @error.nil?
    invalid_properties.push('invalid value for "error", error cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



399
400
401
# File 'lib/komoju-sdk/models/errored_field.rb', line 399

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/komoju-sdk/models/errored_field.rb', line 405

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



393
394
395
# File 'lib/komoju-sdk/models/errored_field.rb', line 393

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/komoju-sdk/models/errored_field.rb', line 199

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @field_type.nil?
  return false if @field.nil?
  return false if @field_name.nil?
  return false if @field_properties.nil?
  return false if @position.nil?
  return false if @optional.nil?
  return false if @value.nil?
  return false if @error.nil?
  true
end