Class: Komoju::FraudDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/fraud_details.rb

Overview

Specify customer’s personal information to help us determine the legitimacy of the payment. It’s recommended to include this information whenever possible to reduce the number of chargebacks. See [Fraud Details](doc.komoju.com/docs/fraud-details) for more details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FraudDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/komoju-sdk/models/fraud_details.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::FraudDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::FraudDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'customer_ip')
    self.customer_ip = attributes[:'customer_ip']
  else
    self.customer_ip = nil
  end

  if attributes.key?(:'customer_email')
    self.customer_email = attributes[:'customer_email']
  else
    self.customer_email = nil
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'browser_language')
    self.browser_language = attributes[:'browser_language']
  end

  if attributes.key?(:'browser_user_agent')
    self.browser_user_agent = attributes[:'browser_user_agent']
  end

  if attributes.key?(:'browser_session_id')
    self.browser_session_id = attributes[:'browser_session_id']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end
end

Instance Attribute Details

#browser_languageObject

Customer’s current language setting.



29
30
31
# File 'lib/komoju-sdk/models/fraud_details.rb', line 29

def browser_language
  @browser_language
end

#browser_session_idObject

A unique identifier for the current browser session. We expect this to behave similarly to the lifetime of [window.sessionStorage](developer.mozilla.org/en-US/docs/Web/API/Window/sessionStorage) in a web browsing context.



35
36
37
# File 'lib/komoju-sdk/models/fraud_details.rb', line 35

def browser_session_id
  @browser_session_id
end

#browser_user_agentObject



32
33
34
# File 'lib/komoju-sdk/models/fraud_details.rb', line 32

def browser_user_agent
  @browser_user_agent
end

#customer_emailObject

Customer’s email address. This field can be omitted if ‘email` is provided in `email` field inside `payment_details` of create payment request, or in the create payment session request. Otherwise, this field is required.



23
24
25
# File 'lib/komoju-sdk/models/fraud_details.rb', line 23

def customer_email
  @customer_email
end

#customer_idObject

An unique identifier of your customer. If your system has the concept of user accounts, then the ID of the current logged in user would be appropriate.



26
27
28
# File 'lib/komoju-sdk/models/fraud_details.rb', line 26

def customer_id
  @customer_id
end

#customer_ipObject

IPv4 or IPv6-formatted IP address of the customer at the time of payment.



20
21
22
# File 'lib/komoju-sdk/models/fraud_details.rb', line 20

def customer_ip
  @customer_ip
end

#phoneObject

Customer’s phone number.



38
39
40
# File 'lib/komoju-sdk/models/fraud_details.rb', line 38

def phone
  @phone
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/komoju-sdk/models/fraud_details.rb', line 209

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/komoju-sdk/models/fraud_details.rb', line 54

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/komoju-sdk/models/fraud_details.rb', line 41

def self.attribute_map
  {
    :'customer_ip' => :'customer_ip',
    :'customer_email' => :'customer_email',
    :'customer_id' => :'customer_id',
    :'browser_language' => :'browser_language',
    :'browser_user_agent' => :'browser_user_agent',
    :'browser_session_id' => :'browser_session_id',
    :'phone' => :'phone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/komoju-sdk/models/fraud_details.rb', line 179

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/komoju-sdk/models/fraud_details.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/komoju-sdk/models/fraud_details.rb', line 59

def self.openapi_types
  {
    :'customer_ip' => :'String',
    :'customer_email' => :'String',
    :'customer_id' => :'String',
    :'browser_language' => :'String',
    :'browser_user_agent' => :'String',
    :'browser_session_id' => :'String',
    :'phone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
162
# File 'lib/komoju-sdk/models/fraud_details.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      customer_ip == o.customer_ip &&
      customer_email == o.customer_email &&
      customer_id == o.customer_id &&
      browser_language == o.browser_language &&
      browser_user_agent == o.browser_user_agent &&
      browser_session_id == o.browser_session_id &&
      phone == o.phone
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/komoju-sdk/models/fraud_details.rb', line 280

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/komoju-sdk/models/fraud_details.rb', line 166

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



172
173
174
# File 'lib/komoju-sdk/models/fraud_details.rb', line 172

def hash
  [customer_ip, customer_email, customer_id, browser_language, browser_user_agent, browser_session_id, phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/komoju-sdk/models/fraud_details.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @customer_ip.nil?
    invalid_properties.push('invalid value for "customer_ip", customer_ip cannot be nil.')
  end

  if @customer_email.nil?
    invalid_properties.push('invalid value for "customer_email", customer_email cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
# File 'lib/komoju-sdk/models/fraud_details.rb', line 256

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/komoju-sdk/models/fraud_details.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



250
251
252
# File 'lib/komoju-sdk/models/fraud_details.rb', line 250

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
147
148
# File 'lib/komoju-sdk/models/fraud_details.rb', line 143

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @customer_ip.nil?
  return false if @customer_email.nil?
  true
end