Class: Komoju::LiveApplicationWithSubmittedFields

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/live_application_with_submitted_fields.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LiveApplicationWithSubmittedFields

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::LiveApplicationWithSubmittedFields` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::LiveApplicationWithSubmittedFields`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'merchant_id')
    self.merchant_id = attributes[:'merchant_id']
  else
    self.merchant_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'payments_enabled')
    self.payments_enabled = attributes[:'payments_enabled']
  else
    self.payments_enabled = nil
  end

  if attributes.key?(:'payouts_enabled')
    self.payouts_enabled = attributes[:'payouts_enabled']
  else
    self.payouts_enabled = nil
  end

  if attributes.key?(:'requested_fields')
    if (value = attributes[:'requested_fields']).is_a?(Array)
      self.requested_fields = value
    end
  else
    self.requested_fields = nil
  end

  if attributes.key?(:'newly_requested_fields')
    if (value = attributes[:'newly_requested_fields']).is_a?(Array)
      self.newly_requested_fields = value
    end
  else
    self.newly_requested_fields = nil
  end

  if attributes.key?(:'errored_fields')
    if (value = attributes[:'errored_fields']).is_a?(Array)
      self.errored_fields = value
    end
  else
    self.errored_fields = nil
  end

  if attributes.key?(:'submitted_fields')
    if (value = attributes[:'submitted_fields']).is_a?(Array)
      self. = value
    end
  else
    self. = nil
  end
end

Instance Attribute Details

#errored_fieldsObject

Fields that were submitted but failed validation.



36
37
38
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 36

def errored_fields
  @errored_fields
end

#merchant_idObject

A unique 25-character alphanumeric resource identifier.



19
20
21
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 19

def merchant_id
  @merchant_id
end

#newly_requested_fieldsObject

Fields newly added to the required list since last submission.



33
34
35
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 33

def newly_requested_fields
  @newly_requested_fields
end

#payments_enabledObject

Whether payments have been enabled following application review.



24
25
26
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 24

def payments_enabled
  @payments_enabled
end

#payouts_enabledObject

Whether payouts have been enabled following application review.



27
28
29
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 27

def payouts_enabled
  @payouts_enabled
end

#requested_fieldsObject

Fields currently required to be submitted for this application.



30
31
32
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 30

def requested_fields
  @requested_fields
end

#statusObject

Returns the value of attribute status.



21
22
23
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 21

def status
  @status
end

#submitted_fieldsObject

Returns the value of attribute submitted_fields.



38
39
40
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 38

def 
  @submitted_fields
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 323

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 63

def self.attribute_map
  {
    :'merchant_id' => :'merchant_id',
    :'status' => :'status',
    :'payments_enabled' => :'payments_enabled',
    :'payouts_enabled' => :'payouts_enabled',
    :'requested_fields' => :'requested_fields',
    :'newly_requested_fields' => :'newly_requested_fields',
    :'errored_fields' => :'errored_fields',
    :'submitted_fields' => :'submitted_fields'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 293

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



102
103
104
105
106
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 102

def self.openapi_all_of
  [
  :'LiveApplication'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 82

def self.openapi_types
  {
    :'merchant_id' => :'String',
    :'status' => :'LiveApplicationStatus',
    :'payments_enabled' => :'Boolean',
    :'payouts_enabled' => :'Boolean',
    :'requested_fields' => :'Array<Field>',
    :'newly_requested_fields' => :'Array<Field>',
    :'errored_fields' => :'Array<ErroredField>',
    :'submitted_fields' => :'Array<SubmittedField>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 265

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      merchant_id == o.merchant_id &&
      status == o.status &&
      payments_enabled == o.payments_enabled &&
      payouts_enabled == o.payouts_enabled &&
      requested_fields == o.requested_fields &&
      newly_requested_fields == o.newly_requested_fields &&
      errored_fields == o.errored_fields &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 394

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


280
281
282
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 280

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



286
287
288
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 286

def hash
  [merchant_id, status, payments_enabled, payouts_enabled, requested_fields, newly_requested_fields, errored_fields, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 182

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @merchant_id.nil?
    invalid_properties.push('invalid value for "merchant_id", merchant_id cannot be nil.')
  end

  if @merchant_id.to_s.length > 25
    invalid_properties.push('invalid value for "merchant_id", the character length must be smaller than or equal to 25.')
  end

  if @merchant_id.to_s.length < 25
    invalid_properties.push('invalid value for "merchant_id", the character length must be great than or equal to 25.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @payments_enabled.nil?
    invalid_properties.push('invalid value for "payments_enabled", payments_enabled cannot be nil.')
  end

  if @payouts_enabled.nil?
    invalid_properties.push('invalid value for "payouts_enabled", payouts_enabled cannot be nil.')
  end

  if @requested_fields.nil?
    invalid_properties.push('invalid value for "requested_fields", requested_fields cannot be nil.')
  end

  if @newly_requested_fields.nil?
    invalid_properties.push('invalid value for "newly_requested_fields", newly_requested_fields cannot be nil.')
  end

  if @errored_fields.nil?
    invalid_properties.push('invalid value for "errored_fields", errored_fields cannot be nil.')
  end

  if @submitted_fields.nil?
    invalid_properties.push('invalid value for "submitted_fields", submitted_fields cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



370
371
372
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 370

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 376

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



364
365
366
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 364

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/komoju-sdk/models/live_application_with_submitted_fields.rb', line 230

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @merchant_id.nil?
  return false if @merchant_id.to_s.length > 25
  return false if @merchant_id.to_s.length < 25
  return false if @status.nil?
  return false if @payments_enabled.nil?
  return false if @payouts_enabled.nil?
  return false if @requested_fields.nil?
  return false if @newly_requested_fields.nil?
  return false if @errored_fields.nil?
  return false if @submitted_fields.nil?
  true
end