Class: Komoju::PaymentData

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/payment_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/komoju-sdk/models/payment_data.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::PaymentData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::PaymentData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'capture')
    self.capture = attributes[:'capture']
  else
    self.capture = nil
  end

  if attributes.key?(:'external_order_num')
    self.external_order_num = attributes[:'external_order_num']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'name_kana')
    self.name_kana = attributes[:'name_kana']
  end

  if attributes.key?(:'platform_details')
    self.platform_details = attributes[:'platform_details']
  end
end

Instance Attribute Details

#captureObject

Whether the payment is captured automatically on completion, or held for manual capture.



19
20
21
# File 'lib/komoju-sdk/models/payment_data.rb', line 19

def capture
  @capture
end

#external_order_numObject

Merchant-assigned order reference number associated with this payment.



22
23
24
# File 'lib/komoju-sdk/models/payment_data.rb', line 22

def external_order_num
  @external_order_num
end

#nameObject

Customer’s full name as provided at session creation.



25
26
27
# File 'lib/komoju-sdk/models/payment_data.rb', line 25

def name
  @name
end

#name_kanaObject

Customer’s full name in katakana as provided at session creation.



28
29
30
# File 'lib/komoju-sdk/models/payment_data.rb', line 28

def name_kana
  @name_kana
end

#platform_detailsObject

Returns the value of attribute platform_details.



30
31
32
# File 'lib/komoju-sdk/models/payment_data.rb', line 30

def platform_details
  @platform_details
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/komoju-sdk/models/payment_data.rb', line 214

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/komoju-sdk/models/payment_data.rb', line 66

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/komoju-sdk/models/payment_data.rb', line 55

def self.attribute_map
  {
    :'capture' => :'capture',
    :'external_order_num' => :'external_order_num',
    :'name' => :'name',
    :'name_kana' => :'name_kana',
    :'platform_details' => :'platform_details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/komoju-sdk/models/payment_data.rb', line 184

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/komoju-sdk/models/payment_data.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
# File 'lib/komoju-sdk/models/payment_data.rb', line 71

def self.openapi_types
  {
    :'capture' => :'String',
    :'external_order_num' => :'String',
    :'name' => :'String',
    :'name_kana' => :'String',
    :'platform_details' => :'PlatformDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



159
160
161
162
163
164
165
166
167
# File 'lib/komoju-sdk/models/payment_data.rb', line 159

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      capture == o.capture &&
      external_order_num == o.external_order_num &&
      name == o.name &&
      name_kana == o.name_kana &&
      platform_details == o.platform_details
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/komoju-sdk/models/payment_data.rb', line 285

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


171
172
173
# File 'lib/komoju-sdk/models/payment_data.rb', line 171

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



177
178
179
# File 'lib/komoju-sdk/models/payment_data.rb', line 177

def hash
  [capture, external_order_num, name, name_kana, platform_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
# File 'lib/komoju-sdk/models/payment_data.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @capture.nil?
    invalid_properties.push('invalid value for "capture", capture cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
# File 'lib/komoju-sdk/models/payment_data.rb', line 261

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/komoju-sdk/models/payment_data.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



255
256
257
# File 'lib/komoju-sdk/models/payment_data.rb', line 255

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
145
# File 'lib/komoju-sdk/models/payment_data.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @capture.nil?
  capture_validator = EnumAttributeValidator.new('String', ["auto", "manual"])
  return false unless capture_validator.valid?(@capture)
  true
end