Class: Komoju::PaymentDataRequest

Inherits:
ApiModelBase show all
Defined in:
lib/komoju-sdk/models/payment_data_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentDataRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::PaymentDataRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::PaymentDataRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'capture')
    self.capture = attributes[:'capture']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'external_order_num')
    self.external_order_num = attributes[:'external_order_num']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'name_kana')
    self.name_kana = attributes[:'name_kana']
  end

  if attributes.key?(:'mcc')
    self.mcc = attributes[:'mcc']
  end

  if attributes.key?(:'intent')
    self.intent = attributes[:'intent']
  end

  if attributes.key?(:'statement_descriptor')
    self.statement_descriptor = attributes[:'statement_descriptor']
  end

  if attributes.key?(:'platform_details')
    self.platform_details = attributes[:'platform_details']
  end

  if attributes.key?(:'billing_address')
    self.billing_address = attributes[:'billing_address']
  end

  if attributes.key?(:'shipping_address')
    self.shipping_address = attributes[:'shipping_address']
  end
end

Instance Attribute Details

#amountObject

Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).



22
23
24
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 22

def amount
  @amount
end

#billing_addressObject

Returns the value of attribute billing_address.



44
45
46
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 44

def billing_address
  @billing_address
end

#captureObject

Whether to capture the payment automatically on completion, or hold it for manual capture later.



19
20
21
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 19

def capture
  @capture
end

#currencyObject

Returns the value of attribute currency.



24
25
26
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 24

def currency
  @currency
end

#external_order_numObject

Merchant-assigned order reference number to associate with the payment.



27
28
29
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 27

def external_order_num
  @external_order_num
end

#intentObject

Returns the value of attribute intent.



38
39
40
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 38

def intent
  @intent
end

#mccObject

Merchant Category Code to use for this payment.



36
37
38
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 36

def mcc
  @mcc
end

#nameObject

Customer's full name.



30
31
32
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 30

def name
  @name
end

#name_kanaObject

Customer's full name in katakana.



33
34
35
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 33

def name_kana
  @name_kana
end

#platform_detailsObject

Returns the value of attribute platform_details.



42
43
44
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 42

def platform_details
  @platform_details
end

#shipping_addressObject

Returns the value of attribute shipping_address.



46
47
48
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 46

def shipping_address
  @shipping_address
end

#statement_descriptorObject

Returns the value of attribute statement_descriptor.



40
41
42
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 40

def statement_descriptor
  @statement_descriptor
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 297

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 71

def self.attribute_map
  {
    :'capture' => :'capture',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'external_order_num' => :'external_order_num',
    :'name' => :'name',
    :'name_kana' => :'name_kana',
    :'mcc' => :'mcc',
    :'intent' => :'intent',
    :'statement_descriptor' => :'statement_descriptor',
    :'platform_details' => :'platform_details',
    :'billing_address' => :'billing_address',
    :'shipping_address' => :'shipping_address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 267

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



117
118
119
120
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 117

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 99

def self.openapi_types
  {
    :'capture' => :'String',
    :'amount' => :'Integer',
    :'currency' => :'Currency',
    :'external_order_num' => :'String',
    :'name' => :'String',
    :'name_kana' => :'String',
    :'mcc' => :'String',
    :'intent' => :'Intent',
    :'statement_descriptor' => :'StatementDescriptor',
    :'platform_details' => :'PlatformDetails',
    :'billing_address' => :'Address',
    :'shipping_address' => :'Address'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      capture == o.capture &&
      amount == o.amount &&
      currency == o.currency &&
      external_order_num == o.external_order_num &&
      name == o.name &&
      name_kana == o.name_kana &&
      mcc == o.mcc &&
      intent == o.intent &&
      statement_descriptor == o.statement_descriptor &&
      platform_details == o.platform_details &&
      billing_address == o.billing_address &&
      shipping_address == o.shipping_address
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 368

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 254

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



260
261
262
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 260

def hash
  [capture, amount, currency, external_order_num, name, name_kana, mcc, intent, statement_descriptor, platform_details, billing_address, shipping_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



189
190
191
192
193
194
195
196
197
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 189

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@amount.nil? && @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 344

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



338
339
340
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 338

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
# File 'lib/komoju-sdk/models/payment_data_request.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  capture_validator = EnumAttributeValidator.new('String', ["auto", "manual"])
  return false unless capture_validator.valid?(@capture)
  return false if !@amount.nil? && @amount < 0
  true
end