Class: Komoju::PaymentDetailsCreditCardBrazil

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/payment_details_credit_card_brazil.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentDetailsCreditCardBrazil

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 181

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::PaymentDetailsCreditCardBrazil` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::PaymentDetailsCreditCardBrazil`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  else
    self.number = nil
  end

  if attributes.key?(:'month')
    self.month = attributes[:'month']
  else
    self.month = nil
  end

  if attributes.key?(:'year')
    self.year = attributes[:'year']
  else
    self.year = nil
  end

  if attributes.key?(:'verification_value')
    self.verification_value = attributes[:'verification_value']
  else
    self.verification_value = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'cpf_or_cnpj')
    self.cpf_or_cnpj = attributes[:'cpf_or_cnpj']
  else
    self.cpf_or_cnpj = nil
  end

  if attributes.key?(:'customer_ip')
    self.customer_ip = attributes[:'customer_ip']
  else
    self.customer_ip = nil
  end

  if attributes.key?(:'shipping_address_name')
    self.shipping_address_name = attributes[:'shipping_address_name']
  end

  if attributes.key?(:'shipping_address_line1')
    self.shipping_address_line1 = attributes[:'shipping_address_line1']
  end

  if attributes.key?(:'shipping_address_line2')
    self.shipping_address_line2 = attributes[:'shipping_address_line2']
  end

  if attributes.key?(:'shipping_address_city')
    self.shipping_address_city = attributes[:'shipping_address_city']
  end

  if attributes.key?(:'shipping_address_state')
    self.shipping_address_state = attributes[:'shipping_address_state']
  end

  if attributes.key?(:'shipping_address_zip')
    self.shipping_address_zip = attributes[:'shipping_address_zip']
  end

  if attributes.key?(:'shipping_address_country')
    self.shipping_address_country = attributes[:'shipping_address_country']
  end

  if attributes.key?(:'billing_address_name')
    self.billing_address_name = attributes[:'billing_address_name']
  end

  if attributes.key?(:'billing_address_line1')
    self.billing_address_line1 = attributes[:'billing_address_line1']
  end

  if attributes.key?(:'billing_address_line2')
    self.billing_address_line2 = attributes[:'billing_address_line2']
  end

  if attributes.key?(:'billing_address_city')
    self.billing_address_city = attributes[:'billing_address_city']
  end

  if attributes.key?(:'billing_address_state')
    self.billing_address_state = attributes[:'billing_address_state']
  end

  if attributes.key?(:'billing_address_zip')
    self.billing_address_zip = attributes[:'billing_address_zip']
  end

  if attributes.key?(:'billing_address_country')
    self.billing_address_country = attributes[:'billing_address_country']
  end
end

Instance Attribute Details

#billing_address_cityObject

Billing address city.



77
78
79
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 77

def billing_address_city
  @billing_address_city
end

#billing_address_countryObject

Billing address country.



86
87
88
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 86

def billing_address_country
  @billing_address_country
end

#billing_address_line1Object

Billing address line 1.



71
72
73
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 71

def billing_address_line1
  @billing_address_line1
end

#billing_address_line2Object

Billing address line 2.



74
75
76
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 74

def billing_address_line2
  @billing_address_line2
end

#billing_address_nameObject

Billing address name. This is the paying customer’s name.



68
69
70
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 68

def billing_address_name
  @billing_address_name
end

#billing_address_stateObject

Billing address state.



80
81
82
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 80

def billing_address_state
  @billing_address_state
end

#billing_address_zipObject

Billing address ZIP code.



83
84
85
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 83

def billing_address_zip
  @billing_address_zip
end

#cpf_or_cnpjObject

Specify customer’s CPF or CNPJ.



41
42
43
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 41

def cpf_or_cnpj
  @cpf_or_cnpj
end

#customer_ipObject

Specify customer’s IPv4 or IPv6-formatted IP address of the customer at the time of payment.



44
45
46
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 44

def customer_ip
  @customer_ip
end

#emailObject

Customer’s email address. Will be used for fraud prevention and payment receipt.



23
24
25
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 23

def email
  @email
end

#monthObject

Credit card expiration month.



29
30
31
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 29

def month
  @month
end

#nameObject

Full name of the customer. This attribute takes precedence over ‘given_name` and `family_name`.



38
39
40
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 38

def name
  @name
end

#numberObject

Credit card number.



26
27
28
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 26

def number
  @number
end

#shipping_address_cityObject

Shipping address city.



56
57
58
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 56

def shipping_address_city
  @shipping_address_city
end

#shipping_address_countryObject

Shipping address country.



65
66
67
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 65

def shipping_address_country
  @shipping_address_country
end

#shipping_address_line1Object

Shipping address line 1.



50
51
52
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 50

def shipping_address_line1
  @shipping_address_line1
end

#shipping_address_line2Object

Shipping address line 2.



53
54
55
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 53

def shipping_address_line2
  @shipping_address_line2
end

#shipping_address_nameObject

Shipping address name. This is the recipient’s name.



47
48
49
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 47

def shipping_address_name
  @shipping_address_name
end

#shipping_address_stateObject

Shipping address state.



59
60
61
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 59

def shipping_address_state
  @shipping_address_state
end

#shipping_address_zipObject

Shipping address ZIP code.



62
63
64
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 62

def shipping_address_zip
  @shipping_address_zip
end

#typeObject

Payment method type.



20
21
22
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 20

def type
  @type
end

#verification_valueObject

Credit card verification value (Also known as CVV2 or CVC2).



35
36
37
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 35

def verification_value
  @verification_value
end

#yearObject

Credit card expiration year. If this value is less than 100, it will be treated as two digits year in the current century. E.g. If current year is ‘2024`, `99` means `2099`.



32
33
34
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 32

def year
  @year
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 555

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



140
141
142
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 140

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 111

def self.attribute_map
  {
    :'type' => :'type',
    :'email' => :'email',
    :'number' => :'number',
    :'month' => :'month',
    :'year' => :'year',
    :'verification_value' => :'verification_value',
    :'name' => :'name',
    :'cpf_or_cnpj' => :'cpf_or_cnpj',
    :'customer_ip' => :'customer_ip',
    :'shipping_address_name' => :'shipping_address_name',
    :'shipping_address_line1' => :'shipping_address_line1',
    :'shipping_address_line2' => :'shipping_address_line2',
    :'shipping_address_city' => :'shipping_address_city',
    :'shipping_address_state' => :'shipping_address_state',
    :'shipping_address_zip' => :'shipping_address_zip',
    :'shipping_address_country' => :'shipping_address_country',
    :'billing_address_name' => :'billing_address_name',
    :'billing_address_line1' => :'billing_address_line1',
    :'billing_address_line2' => :'billing_address_line2',
    :'billing_address_city' => :'billing_address_city',
    :'billing_address_state' => :'billing_address_state',
    :'billing_address_zip' => :'billing_address_zip',
    :'billing_address_country' => :'billing_address_country'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 525

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



174
175
176
177
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 174

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 145

def self.openapi_types
  {
    :'type' => :'String',
    :'email' => :'String',
    :'number' => :'String',
    :'month' => :'Integer',
    :'year' => :'Integer',
    :'verification_value' => :'String',
    :'name' => :'String',
    :'cpf_or_cnpj' => :'String',
    :'customer_ip' => :'String',
    :'shipping_address_name' => :'String',
    :'shipping_address_line1' => :'String',
    :'shipping_address_line2' => :'String',
    :'shipping_address_city' => :'String',
    :'shipping_address_state' => :'String',
    :'shipping_address_zip' => :'String',
    :'shipping_address_country' => :'String',
    :'billing_address_name' => :'String',
    :'billing_address_line1' => :'String',
    :'billing_address_line2' => :'String',
    :'billing_address_city' => :'String',
    :'billing_address_state' => :'String',
    :'billing_address_zip' => :'String',
    :'billing_address_country' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 482

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      email == o.email &&
      number == o.number &&
      month == o.month &&
      year == o.year &&
      verification_value == o.verification_value &&
      name == o.name &&
      cpf_or_cnpj == o.cpf_or_cnpj &&
      customer_ip == o.customer_ip &&
      shipping_address_name == o.shipping_address_name &&
      shipping_address_line1 == o.shipping_address_line1 &&
      shipping_address_line2 == o.shipping_address_line2 &&
      shipping_address_city == o.shipping_address_city &&
      shipping_address_state == o.shipping_address_state &&
      shipping_address_zip == o.shipping_address_zip &&
      shipping_address_country == o.shipping_address_country &&
      billing_address_name == o.billing_address_name &&
      billing_address_line1 == o.billing_address_line1 &&
      billing_address_line2 == o.billing_address_line2 &&
      billing_address_city == o.billing_address_city &&
      billing_address_state == o.billing_address_state &&
      billing_address_zip == o.billing_address_zip &&
      billing_address_country == o.billing_address_country
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 626

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


512
513
514
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 512

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



518
519
520
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 518

def hash
  [type, email, number, month, year, verification_value, name, cpf_or_cnpj, customer_ip, shipping_address_name, shipping_address_line1, shipping_address_line2, shipping_address_city, shipping_address_state, shipping_address_zip, shipping_address_country, billing_address_name, billing_address_line1, billing_address_line2, billing_address_city, billing_address_state, billing_address_zip, billing_address_country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 307

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @number.nil?
    invalid_properties.push('invalid value for "number", number cannot be nil.')
  end

  if @number.to_s.length > 19
    invalid_properties.push('invalid value for "number", the character length must be smaller than or equal to 19.')
  end

  if @number.to_s.length < 8
    invalid_properties.push('invalid value for "number", the character length must be great than or equal to 8.')
  end

  if @month.nil?
    invalid_properties.push('invalid value for "month", month cannot be nil.')
  end

  if @month > 12
    invalid_properties.push('invalid value for "month", must be smaller than or equal to 12.')
  end

  if @month < 1
    invalid_properties.push('invalid value for "month", must be greater than or equal to 1.')
  end

  if @year.nil?
    invalid_properties.push('invalid value for "year", year cannot be nil.')
  end

  if @year > 2100
    invalid_properties.push('invalid value for "year", must be smaller than or equal to 2100.')
  end

  if @year < 0
    invalid_properties.push('invalid value for "year", must be greater than or equal to 0.')
  end

  if @verification_value.nil?
    invalid_properties.push('invalid value for "verification_value", verification_value cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if @cpf_or_cnpj.nil?
    invalid_properties.push('invalid value for "cpf_or_cnpj", cpf_or_cnpj cannot be nil.')
  end

  if @customer_ip.nil?
    invalid_properties.push('invalid value for "customer_ip", customer_ip cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



602
603
604
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 602

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 608

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



596
597
598
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 596

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/komoju-sdk/models/payment_details_credit_card_brazil.rb', line 379

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["credit_card_brazil"])
  return false unless type_validator.valid?(@type)
  return false if @email.nil?
  return false if @number.nil?
  return false if @number.to_s.length > 19
  return false if @number.to_s.length < 8
  return false if @month.nil?
  return false if @month > 12
  return false if @month < 1
  return false if @year.nil?
  return false if @year > 2100
  return false if @year < 0
  return false if @verification_value.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 255
  return false if @cpf_or_cnpj.nil?
  return false if @customer_ip.nil?
  true
end