Class: Komoju::PaymentMethod

Inherits:
ApiModelBase show all
Defined in:
lib/komoju-sdk/models/payment_method.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethod

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/komoju-sdk/models/payment_method.rb', line 124

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::PaymentMethod` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::PaymentMethod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'hashed_gateway')
    self.hashed_gateway = attributes[:'hashed_gateway']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'exchange_rate')
    self.exchange_rate = attributes[:'exchange_rate']
  end

  if attributes.key?(:'offsite')
    self.offsite = attributes[:'offsite']
  end

  if attributes.key?(:'additional_fields')
    if (value = attributes[:'additional_fields']).is_a?(Array)
      self.additional_fields = value
    end
  end

  if attributes.key?(:'brands')
    self.brands = attributes[:'brands']
  end

  if attributes.key?(:'seven_eleven_merchant_number')
    self.seven_eleven_merchant_number = attributes[:'seven_eleven_merchant_number']
  end

  if attributes.key?(:'installments')
    if (value = attributes[:'installments']).is_a?(Array)
      self.installments = value
    end
  end

  if attributes.key?(:'api_endpoint')
    self.api_endpoint = attributes[:'api_endpoint']
  end
end

Instance Attribute Details

#additional_fieldsObject

Names of additional input fields required to complete payment with this method.



36
37
38
# File 'lib/komoju-sdk/models/payment_method.rb', line 36

def additional_fields
  @additional_fields
end

#amountObject

Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).



25
26
27
# File 'lib/komoju-sdk/models/payment_method.rb', line 25

def amount
  @amount
end

#api_endpointObject

Only for Komoju Pay



47
48
49
# File 'lib/komoju-sdk/models/payment_method.rb', line 47

def api_endpoint
  @api_endpoint
end

#brandsObject

Returns the value of attribute brands.



38
39
40
# File 'lib/komoju-sdk/models/payment_method.rb', line 38

def brands
  @brands
end

#currencyObject

Returns the value of attribute currency.



27
28
29
# File 'lib/komoju-sdk/models/payment_method.rb', line 27

def currency
  @currency
end

#exchange_rateObject

Exchange rate applied when this payment method's currency differs from the session currency.



30
31
32
# File 'lib/komoju-sdk/models/payment_method.rb', line 30

def exchange_rate
  @exchange_rate
end

#hashed_gatewayObject

Hashed identifier of the payment gateway processing this method.



22
23
24
# File 'lib/komoju-sdk/models/payment_method.rb', line 22

def hashed_gateway
  @hashed_gateway
end

#installmentsObject

Only for Komoju Pay



44
45
46
# File 'lib/komoju-sdk/models/payment_method.rb', line 44

def installments
  @installments
end

#offsiteObject

Whether this payment method redirects the customer to an external site to complete payment.



33
34
35
# File 'lib/komoju-sdk/models/payment_method.rb', line 33

def offsite
  @offsite
end

#seven_eleven_merchant_numberObject

Only for Konbini



41
42
43
# File 'lib/komoju-sdk/models/payment_method.rb', line 41

def seven_eleven_merchant_number
  @seven_eleven_merchant_number
end

#typeObject

Machine-readable type slug for this payment method (e.g. "credit_card", "konbini").



19
20
21
# File 'lib/komoju-sdk/models/payment_method.rb', line 19

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/komoju-sdk/models/payment_method.rb', line 301

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/komoju-sdk/models/payment_method.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/komoju-sdk/models/payment_method.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/komoju-sdk/models/payment_method.rb', line 72

def self.attribute_map
  {
    :'type' => :'type',
    :'hashed_gateway' => :'hashed_gateway',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'exchange_rate' => :'exchange_rate',
    :'offsite' => :'offsite',
    :'additional_fields' => :'additional_fields',
    :'brands' => :'brands',
    :'seven_eleven_merchant_number' => :'seven_eleven_merchant_number',
    :'installments' => :'installments',
    :'api_endpoint' => :'api_endpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/komoju-sdk/models/payment_method.rb', line 271

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
120
# File 'lib/komoju-sdk/models/payment_method.rb', line 116

def self.openapi_nullable
  Set.new([
    :'seven_eleven_merchant_number',
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/komoju-sdk/models/payment_method.rb', line 99

def self.openapi_types
  {
    :'type' => :'String',
    :'hashed_gateway' => :'String',
    :'amount' => :'Integer',
    :'currency' => :'Currency',
    :'exchange_rate' => :'Float',
    :'offsite' => :'Boolean',
    :'additional_fields' => :'Array<String>',
    :'brands' => :'PaymentMethodBrands',
    :'seven_eleven_merchant_number' => :'String',
    :'installments' => :'Array<PaymentMethodInstallmentsInner>',
    :'api_endpoint' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/komoju-sdk/models/payment_method.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      hashed_gateway == o.hashed_gateway &&
      amount == o.amount &&
      currency == o.currency &&
      exchange_rate == o.exchange_rate &&
      offsite == o.offsite &&
      additional_fields == o.additional_fields &&
      brands == o.brands &&
      seven_eleven_merchant_number == o.seven_eleven_merchant_number &&
      installments == o.installments &&
      api_endpoint == o.api_endpoint
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/komoju-sdk/models/payment_method.rb', line 372

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


258
259
260
# File 'lib/komoju-sdk/models/payment_method.rb', line 258

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



264
265
266
# File 'lib/komoju-sdk/models/payment_method.rb', line 264

def hash
  [type, hashed_gateway, amount, currency, exchange_rate, offsite, additional_fields, brands, seven_eleven_merchant_number, installments, api_endpoint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/komoju-sdk/models/payment_method.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@amount.nil? && @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



348
349
350
# File 'lib/komoju-sdk/models/payment_method.rb', line 348

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/komoju-sdk/models/payment_method.rb', line 354

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



342
343
344
# File 'lib/komoju-sdk/models/payment_method.rb', line 342

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
# File 'lib/komoju-sdk/models/payment_method.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  return false if !@amount.nil? && @amount < 0
  true
end