Class: Komoju::PaymentMethodApplicationWithSubmittedFields

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethodApplicationWithSubmittedFields

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::PaymentMethodApplicationWithSubmittedFields` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::PaymentMethodApplicationWithSubmittedFields`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'merchant_id')
    self.merchant_id = attributes[:'merchant_id']
  else
    self.merchant_id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'payments_enabled')
    self.payments_enabled = attributes[:'payments_enabled']
  else
    self.payments_enabled = nil
  end

  if attributes.key?(:'payouts_enabled')
    self.payouts_enabled = attributes[:'payouts_enabled']
  else
    self.payouts_enabled = nil
  end

  if attributes.key?(:'requested_fields')
    if (value = attributes[:'requested_fields']).is_a?(Array)
      self.requested_fields = value
    end
  else
    self.requested_fields = nil
  end

  if attributes.key?(:'newly_requested_fields')
    if (value = attributes[:'newly_requested_fields']).is_a?(Array)
      self.newly_requested_fields = value
    end
  else
    self.newly_requested_fields = nil
  end

  if attributes.key?(:'errored_fields')
    if (value = attributes[:'errored_fields']).is_a?(Array)
      self.errored_fields = value
    end
  else
    self.errored_fields = nil
  end

  if attributes.key?(:'submitted_fields')
    if (value = attributes[:'submitted_fields']).is_a?(Array)
      self. = value
    end
  else
    self. = nil
  end
end

Instance Attribute Details

#errored_fieldsObject

Fields that were submitted but failed validation.



36
37
38
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 36

def errored_fields
  @errored_fields
end

#merchant_idObject

A unique 25-character alphanumeric resource identifier.



19
20
21
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 19

def merchant_id
  @merchant_id
end

#newly_requested_fieldsObject

Fields newly added to the required list since last submission.



33
34
35
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 33

def newly_requested_fields
  @newly_requested_fields
end

#payments_enabledObject

Whether payments have been enabled following payment-method review.



24
25
26
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 24

def payments_enabled
  @payments_enabled
end

#payouts_enabledObject

Whether payouts have been enabled following payment-method review.



27
28
29
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 27

def payouts_enabled
  @payouts_enabled
end

#requested_fieldsObject

Fields currently required to be submitted for this payment method.



30
31
32
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 30

def requested_fields
  @requested_fields
end

#statusObject

Returns the value of attribute status.



21
22
23
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 21

def status
  @status
end

#submitted_fieldsObject

Returns the value of attribute submitted_fields.



38
39
40
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 38

def 
  @submitted_fields
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 399

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 63

def self.attribute_map
  {
    :'merchant_id' => :'merchant_id',
    :'status' => :'status',
    :'payments_enabled' => :'payments_enabled',
    :'payouts_enabled' => :'payouts_enabled',
    :'requested_fields' => :'requested_fields',
    :'newly_requested_fields' => :'newly_requested_fields',
    :'errored_fields' => :'errored_fields',
    :'submitted_fields' => :'submitted_fields'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 369

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



107
108
109
110
111
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 107

def self.openapi_all_of
  [
  :'PaymentMethodApplication'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 87

def self.openapi_types
  {
    :'merchant_id' => :'String',
    :'status' => :'PaymentMethodApplicationStatus',
    :'payments_enabled' => :'Boolean',
    :'payouts_enabled' => :'Boolean',
    :'requested_fields' => :'Array<Field>',
    :'newly_requested_fields' => :'Array<Field>',
    :'errored_fields' => :'Array<ErroredField>',
    :'submitted_fields' => :'Array<SubmittedField>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 341

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      merchant_id == o.merchant_id &&
      status == o.status &&
      payments_enabled == o.payments_enabled &&
      payouts_enabled == o.payouts_enabled &&
      requested_fields == o.requested_fields &&
      newly_requested_fields == o.newly_requested_fields &&
      errored_fields == o.errored_fields &&
       == o.
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 470

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


356
357
358
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 356

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



362
363
364
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 362

def hash
  [merchant_id, status, payments_enabled, payouts_enabled, requested_fields, newly_requested_fields, errored_fields, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 188

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @merchant_id.nil?
    invalid_properties.push('invalid value for "merchant_id", merchant_id cannot be nil.')
  end

  if @merchant_id.to_s.length > 25
    invalid_properties.push('invalid value for "merchant_id", the character length must be smaller than or equal to 25.')
  end

  if @merchant_id.to_s.length < 25
    invalid_properties.push('invalid value for "merchant_id", the character length must be greater than or equal to 25.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @payments_enabled.nil?
    invalid_properties.push('invalid value for "payments_enabled", payments_enabled cannot be nil.')
  end

  if @payouts_enabled.nil?
    invalid_properties.push('invalid value for "payouts_enabled", payouts_enabled cannot be nil.')
  end

  if @requested_fields.nil?
    invalid_properties.push('invalid value for "requested_fields", requested_fields cannot be nil.')
  end

  if @newly_requested_fields.nil?
    invalid_properties.push('invalid value for "newly_requested_fields", newly_requested_fields cannot be nil.')
  end

  if @errored_fields.nil?
    invalid_properties.push('invalid value for "errored_fields", errored_fields cannot be nil.')
  end

  if @submitted_fields.nil?
    invalid_properties.push('invalid value for "submitted_fields", submitted_fields cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



446
447
448
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 446

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



452
453
454
455
456
457
458
459
460
461
462
463
464
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 452

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



440
441
442
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 440

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/komoju-sdk/models/payment_method_application_with_submitted_fields.rb', line 236

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @merchant_id.nil?
  return false if @merchant_id.to_s.length > 25
  return false if @merchant_id.to_s.length < 25
  return false if @status.nil?
  return false if @payments_enabled.nil?
  return false if @payouts_enabled.nil?
  return false if @requested_fields.nil?
  return false if @newly_requested_fields.nil?
  return false if @errored_fields.nil?
  return false if @submitted_fields.nil?
  true
end