Class: Komoju::RefundRequest

Inherits:
ApiModelBase show all
Defined in:
lib/komoju-sdk/models/refund_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ RefundRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/komoju-sdk/models/refund_request.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::RefundRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::RefundRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'payment')
    self.payment = attributes[:'payment']
  else
    self.payment = nil
  end

  if attributes.key?(:'customer_name')
    self.customer_name = attributes[:'customer_name']
  else
    self.customer_name = nil
  end

  if attributes.key?(:'bank_name')
    self.bank_name = attributes[:'bank_name']
  else
    self.bank_name = nil
  end

  if attributes.key?(:'bank_code')
    self.bank_code = attributes[:'bank_code']
  else
    self.bank_code = nil
  end

  if attributes.key?(:'branch_name')
    self.branch_name = attributes[:'branch_name']
  else
    self.branch_name = nil
  end

  if attributes.key?(:'branch_number')
    self.branch_number = attributes[:'branch_number']
  else
    self.branch_number = nil
  end

  if attributes.key?(:'account_number')
    self. = attributes[:'account_number']
  else
    self. = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'platform_details')
    self.platform_details = attributes[:'platform_details']
  end
end

Instance Attribute Details

#account_numberObject

7-digit account number.



40
41
42
# File 'lib/komoju-sdk/models/refund_request.rb', line 40

def 
  @account_number
end

#bank_codeObject

4-digit bank code. May be null if it's not given.



31
32
33
# File 'lib/komoju-sdk/models/refund_request.rb', line 31

def bank_code
  @bank_code
end

#bank_nameObject

The name of the bank that customer would like money to be deposited to.



28
29
30
# File 'lib/komoju-sdk/models/refund_request.rb', line 28

def bank_name
  @bank_name
end

#branch_nameObject

The name of the branch.



34
35
36
# File 'lib/komoju-sdk/models/refund_request.rb', line 34

def branch_name
  @branch_name
end

#branch_numberObject

3-digit branch number.



37
38
39
# File 'lib/komoju-sdk/models/refund_request.rb', line 37

def branch_number
  @branch_number
end

#created_atObject

Timestamp when the refund request was created.



48
49
50
# File 'lib/komoju-sdk/models/refund_request.rb', line 48

def created_at
  @created_at
end

#customer_nameObject

Customer's name in half-width katakana characters.



25
26
27
# File 'lib/komoju-sdk/models/refund_request.rb', line 25

def customer_name
  @customer_name
end

#descriptionObject

Optional description or reason for this refund request.



43
44
45
# File 'lib/komoju-sdk/models/refund_request.rb', line 43

def description
  @description
end

#idObject

A unique 25-character alphanumeric refund request identifier.



19
20
21
# File 'lib/komoju-sdk/models/refund_request.rb', line 19

def id
  @id
end

#paymentObject

A unique 25-character alphanumeric payment identifier.



22
23
24
# File 'lib/komoju-sdk/models/refund_request.rb', line 22

def payment
  @payment
end

#platform_detailsObject

Returns the value of attribute platform_details.



50
51
52
# File 'lib/komoju-sdk/models/refund_request.rb', line 50

def platform_details
  @platform_details
end

#statusObject

Returns the value of attribute status.



45
46
47
# File 'lib/komoju-sdk/models/refund_request.rb', line 45

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
# File 'lib/komoju-sdk/models/refund_request.rb', line 530

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



93
94
95
# File 'lib/komoju-sdk/models/refund_request.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/komoju-sdk/models/refund_request.rb', line 98

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/komoju-sdk/models/refund_request.rb', line 75

def self.attribute_map
  {
    :'id' => :'id',
    :'payment' => :'payment',
    :'customer_name' => :'customer_name',
    :'bank_name' => :'bank_name',
    :'bank_code' => :'bank_code',
    :'branch_name' => :'branch_name',
    :'branch_number' => :'branch_number',
    :'account_number' => :'account_number',
    :'description' => :'description',
    :'status' => :'status',
    :'created_at' => :'created_at',
    :'platform_details' => :'platform_details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
# File 'lib/komoju-sdk/models/refund_request.rb', line 500

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
# File 'lib/komoju-sdk/models/refund_request.rb', line 121

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/komoju-sdk/models/refund_request.rb', line 103

def self.openapi_types
  {
    :'id' => :'String',
    :'payment' => :'String',
    :'customer_name' => :'String',
    :'bank_name' => :'String',
    :'bank_code' => :'String',
    :'branch_name' => :'String',
    :'branch_number' => :'String',
    :'account_number' => :'String',
    :'description' => :'String',
    :'status' => :'RefundRequestStatus',
    :'created_at' => :'Time',
    :'platform_details' => :'PlatformDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/komoju-sdk/models/refund_request.rb', line 468

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      payment == o.payment &&
      customer_name == o.customer_name &&
      bank_name == o.bank_name &&
      bank_code == o.bank_code &&
      branch_name == o.branch_name &&
      branch_number == o.branch_number &&
       == o. &&
      description == o.description &&
      status == o.status &&
      created_at == o.created_at &&
      platform_details == o.platform_details
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



601
602
603
604
605
606
607
608
609
610
611
612
613
# File 'lib/komoju-sdk/models/refund_request.rb', line 601

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


487
488
489
# File 'lib/komoju-sdk/models/refund_request.rb', line 487

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



493
494
495
# File 'lib/komoju-sdk/models/refund_request.rb', line 493

def hash
  [id, payment, customer_name, bank_name, bank_code, branch_name, branch_number, , description, status, created_at, platform_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/komoju-sdk/models/refund_request.rb', line 213

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @id.to_s.length > 25
    invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.')
  end

  if @id.to_s.length < 25
    invalid_properties.push('invalid value for "id", the character length must be greater than or equal to 25.')
  end

  if @payment.nil?
    invalid_properties.push('invalid value for "payment", payment cannot be nil.')
  end

  if @payment.to_s.length > 25
    invalid_properties.push('invalid value for "payment", the character length must be smaller than or equal to 25.')
  end

  if @payment.to_s.length < 25
    invalid_properties.push('invalid value for "payment", the character length must be greater than or equal to 25.')
  end

  if @customer_name.nil?
    invalid_properties.push('invalid value for "customer_name", customer_name cannot be nil.')
  end

  if @bank_name.nil?
    invalid_properties.push('invalid value for "bank_name", bank_name cannot be nil.')
  end

  if @bank_code.nil?
    invalid_properties.push('invalid value for "bank_code", bank_code cannot be nil.')
  end

  if @bank_code.to_s.length > 4
    invalid_properties.push('invalid value for "bank_code", the character length must be smaller than or equal to 4.')
  end

  if @bank_code.to_s.length < 4
    invalid_properties.push('invalid value for "bank_code", the character length must be greater than or equal to 4.')
  end

  if @branch_name.nil?
    invalid_properties.push('invalid value for "branch_name", branch_name cannot be nil.')
  end

  if @branch_number.nil?
    invalid_properties.push('invalid value for "branch_number", branch_number cannot be nil.')
  end

  if @branch_number.to_s.length > 3
    invalid_properties.push('invalid value for "branch_number", the character length must be smaller than or equal to 3.')
  end

  if @branch_number.to_s.length < 3
    invalid_properties.push('invalid value for "branch_number", the character length must be greater than or equal to 3.')
  end

  if @account_number.nil?
    invalid_properties.push('invalid value for "account_number", account_number cannot be nil.')
  end

  if @account_number.to_s.length > 7
    invalid_properties.push('invalid value for "account_number", the character length must be smaller than or equal to 7.')
  end

  if @account_number.to_s.length < 7
    invalid_properties.push('invalid value for "account_number", the character length must be greater than or equal to 7.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



577
578
579
# File 'lib/komoju-sdk/models/refund_request.rb', line 577

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



583
584
585
586
587
588
589
590
591
592
593
594
595
# File 'lib/komoju-sdk/models/refund_request.rb', line 583

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



571
572
573
# File 'lib/komoju-sdk/models/refund_request.rb', line 571

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/komoju-sdk/models/refund_request.rb', line 301

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @id.to_s.length > 25
  return false if @id.to_s.length < 25
  return false if @payment.nil?
  return false if @payment.to_s.length > 25
  return false if @payment.to_s.length < 25
  return false if @customer_name.nil?
  return false if @bank_name.nil?
  return false if @bank_code.nil?
  return false if @bank_code.to_s.length > 4
  return false if @bank_code.to_s.length < 4
  return false if @branch_name.nil?
  return false if @branch_number.nil?
  return false if @branch_number.to_s.length > 3
  return false if @branch_number.to_s.length < 3
  return false if @account_number.nil?
  return false if @account_number.to_s.length > 7
  return false if @account_number.to_s.length < 7
  return false if @status.nil?
  return false if @created_at.nil?
  true
end