Module: Komoju::ResponsePaymentDetailsAll

Defined in:
lib/komoju-sdk/models/response_payment_details_all.rb

Overview

Specific payment details and attributes for each payment type. It may include payment method specific attributes that are not part of the original request.

Class Method Summary collapse

Class Method Details

.build(data) ⇒ Object

Builds the object

Parameters:

  • Data (Mixed)

    to be matched against the list of oneOf items

Returns:

  • (Object)

    Returns the model or the data itself



162
163
164
165
166
167
168
169
170
# File 'lib/komoju-sdk/models/response_payment_details_all.rb', line 162

def build(data)
  discriminator_value = data[openapi_discriminator_name]
  return nil if discriminator_value.nil?

  klass = openapi_discriminator_mapping[discriminator_value.to_s.to_sym]
  return nil unless klass

  Komoju.const_get(klass).build_from_hash(data)
end

.openapi_discriminator_mappingObject

Discriminator’s mapping (OpenAPI v3)



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/komoju-sdk/models/response_payment_details_all.rb', line 93

def openapi_discriminator_mapping
  {
    :'alipay' => :'ResponsePaymentDetailsAlipay',
    :'alipay_hk' => :'ResponsePaymentDetailsAlipayHK',
    :'au' => :'ResponsePaymentDetailsAU',
    :'aupay' => :'ResponsePaymentDetailsAupay',
    :'bancontact' => :'ResponsePaymentDetailsBancontact',
    :'bank_transfer' => :'ResponsePaymentDetailsBankTransfer',
    :'bit_cash' => :'ResponsePaymentDetailsBitCash',
    :'blik' => :'ResponsePaymentDetailsBlik',
    :'credit_card' => :'ResponsePaymentDetailsCreditCard',
    :'credit_card_brazil' => :'ResponsePaymentDetailsCreditCardBrazil',
    :'credit_card_korea' => :'ResponsePaymentDetailsCreditCardKorea',
    :'credit_card_terminal' => :'ResponsePaymentDetailsCreditCardTerminal',
    :'culture_voucher' => :'ResponsePaymentDetailsCultureVoucher',
    :'cvs' => :'ResponsePaymentDetailsCVS',
    :'dana' => :'ResponsePaymentDetailsDana',
    :'docomo' => :'ResponsePaymentDetailsDocomo',
    :'doku_wallet' => :'ResponsePaymentDetailsDokuWallet',
    :'dospara' => :'ResponsePaymentDetailsDospara',
    :'dragonpay' => :'ResponsePaymentDetailsDragonpay',
    :'enets' => :'ResponsePaymentDetailsEnets',
    :'epospay' => :'ResponsePaymentDetailsEpospay',
    :'eps' => :'ResponsePaymentDetailsEps',
    :'fpx' => :'ResponsePaymentDetailsFpx',
    :'gcash' => :'ResponsePaymentDetailsGCash',
    :'giropay' => :'ResponsePaymentDetailsGiropay',
    :'happy_money' => :'ResponsePaymentDetailsHappyMoney',
    :'ideal' => :'ResponsePaymentDetailsIdeal',
    :'japan_mobile' => :'ResponsePaymentDetailsMobileJapan',
    :'kakaopay' => :'ResponsePaymentDetailsKakaopay',
    :'konbini' => :'ResponsePaymentDetailsKonbini',
    :'merpay' => :'ResponsePaymentDetailsMerpay',
    :'mobile' => :'ResponsePaymentDetailsMobile',
    :'multibanco' => :'ResponsePaymentDetailsMultibanco',
    :'mybank' => :'ResponsePaymentDetailsMybank',
    :'narvesen' => :'ResponsePaymentDetailsNarvesen',
    :'naverpay' => :'ResponsePaymentDetailsNaverpay',
    :'net_cash' => :'ResponsePaymentDetailsNetCash',
    :'ovo' => :'ResponsePaymentDetailsOvo',
    :'paidy' => :'ResponsePaymentDetailsPaidy',
    :'pay_easy' => :'ResponsePaymentDetailsPayEasy',
    :'payco' => :'ResponsePaymentDetailsPayco',
    :'paypay' => :'ResponsePaymentDetailsPayPay',
    :'paypost' => :'ResponsePaymentDetailsPaypost',
    :'paysafe_card' => :'ResponsePaymentDetailsPaysafeCard',
    :'paysafe_cash' => :'ResponsePaymentDetailsPaysafeCash',
    :'paysera' => :'ResponsePaymentDetailsPaysera',
    :'payu' => :'ResponsePaymentDetailsPayu',
    :'perlas' => :'ResponsePaymentDetailsPerlas',
    :'pix' => :'ResponsePaymentDetailsPix',
    :'poli' => :'ResponsePaymentDetailsPoli',
    :'przelewy24' => :'ResponsePaymentDetailsPrzelewy24',
    :'rakutenpay' => :'ResponsePaymentDetailsRakutenpay',
    :'sepa_transfer' => :'ResponsePaymentDetailsSepaTransfer',
    :'sofortbanking' => :'ResponsePaymentDetailsSofortbanking',
    :'softbank' => :'ResponsePaymentDetailsSoftbank',
    :'tng' => :'ResponsePaymentDetailsTNG',
    :'toss' => :'ResponsePaymentDetailsToss',
    :'truemoney' => :'ResponsePaymentDetailsTruemoney',
    :'unionpay' => :'ResponsePaymentDetailsUnionpay',
    :'web_money' => :'ResponsePaymentDetailsWebMoney',
    :'wechatpay' => :'ResponsePaymentDetailsWechatpay'
  }
end

.openapi_discriminator_nameObject

Discriminator’s property name (OpenAPI v3)



88
89
90
# File 'lib/komoju-sdk/models/response_payment_details_all.rb', line 88

def openapi_discriminator_name
  :'type'
end

.openapi_one_ofObject

List of class defined in oneOf (OpenAPI v3)



21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/komoju-sdk/models/response_payment_details_all.rb', line 21

def openapi_one_of
  [
    :'ResponsePaymentDetailsAU',
    :'ResponsePaymentDetailsAlipay',
    :'ResponsePaymentDetailsAlipayHK',
    :'ResponsePaymentDetailsAupay',
    :'ResponsePaymentDetailsBancontact',
    :'ResponsePaymentDetailsBankTransfer',
    :'ResponsePaymentDetailsBitCash',
    :'ResponsePaymentDetailsBlik',
    :'ResponsePaymentDetailsCVS',
    :'ResponsePaymentDetailsCreditCard',
    :'ResponsePaymentDetailsCreditCardBrazil',
    :'ResponsePaymentDetailsCreditCardKorea',
    :'ResponsePaymentDetailsCreditCardTerminal',
    :'ResponsePaymentDetailsCultureVoucher',
    :'ResponsePaymentDetailsDana',
    :'ResponsePaymentDetailsDocomo',
    :'ResponsePaymentDetailsDokuWallet',
    :'ResponsePaymentDetailsDospara',
    :'ResponsePaymentDetailsDragonpay',
    :'ResponsePaymentDetailsEnets',
    :'ResponsePaymentDetailsEpospay',
    :'ResponsePaymentDetailsEps',
    :'ResponsePaymentDetailsFpx',
    :'ResponsePaymentDetailsGCash',
    :'ResponsePaymentDetailsGiropay',
    :'ResponsePaymentDetailsHappyMoney',
    :'ResponsePaymentDetailsIdeal',
    :'ResponsePaymentDetailsKakaopay',
    :'ResponsePaymentDetailsKonbini',
    :'ResponsePaymentDetailsMerpay',
    :'ResponsePaymentDetailsMobile',
    :'ResponsePaymentDetailsMobileJapan',
    :'ResponsePaymentDetailsMultibanco',
    :'ResponsePaymentDetailsMybank',
    :'ResponsePaymentDetailsNarvesen',
    :'ResponsePaymentDetailsNaverpay',
    :'ResponsePaymentDetailsNetCash',
    :'ResponsePaymentDetailsOvo',
    :'ResponsePaymentDetailsPaidy',
    :'ResponsePaymentDetailsPayEasy',
    :'ResponsePaymentDetailsPayPay',
    :'ResponsePaymentDetailsPayco',
    :'ResponsePaymentDetailsPaypost',
    :'ResponsePaymentDetailsPaysafeCard',
    :'ResponsePaymentDetailsPaysafeCash',
    :'ResponsePaymentDetailsPaysera',
    :'ResponsePaymentDetailsPayu',
    :'ResponsePaymentDetailsPerlas',
    :'ResponsePaymentDetailsPix',
    :'ResponsePaymentDetailsPoli',
    :'ResponsePaymentDetailsPrzelewy24',
    :'ResponsePaymentDetailsRakutenpay',
    :'ResponsePaymentDetailsSepaTransfer',
    :'ResponsePaymentDetailsSofortbanking',
    :'ResponsePaymentDetailsSoftbank',
    :'ResponsePaymentDetailsTNG',
    :'ResponsePaymentDetailsToss',
    :'ResponsePaymentDetailsTruemoney',
    :'ResponsePaymentDetailsUnionpay',
    :'ResponsePaymentDetailsWebMoney',
    :'ResponsePaymentDetailsWechatpay'
  ]
end