Class: Komoju::ResponsePaymentDetailsCreditCard

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/komoju-sdk/models/response_payment_details_credit_card.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResponsePaymentDetailsCreditCard

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 214

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ResponsePaymentDetailsCreditCard` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ResponsePaymentDetailsCreditCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  else
    self.brand = nil
  end

  if attributes.key?(:'last_four_digits')
    self.last_four_digits = attributes[:'last_four_digits']
  else
    self.last_four_digits = nil
  end

  if attributes.key?(:'month')
    self.month = attributes[:'month']
  else
    self.month = nil
  end

  if attributes.key?(:'year')
    self.year = attributes[:'year']
  else
    self.year = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'verification_value')
    self.verification_value = attributes[:'verification_value']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'expiry_days')
    self.expiry_days = attributes[:'expiry_days']
  end

  if attributes.key?(:'intent')
    self.intent = attributes[:'intent']
  end

  if attributes.key?(:'initiator')
    self.initiator = attributes[:'initiator']
  end

  if attributes.key?(:'usage')
    self.usage = attributes[:'usage']
  end

  if attributes.key?(:'scheme_reference')
    self.scheme_reference = attributes[:'scheme_reference']
  end

  if attributes.key?(:'installments')
    self.installments = attributes[:'installments']
  end

  if attributes.key?(:'shipping_address_name')
    self.shipping_address_name = attributes[:'shipping_address_name']
  end

  if attributes.key?(:'shipping_address_line1')
    self.shipping_address_line1 = attributes[:'shipping_address_line1']
  end

  if attributes.key?(:'shipping_address_line2')
    self.shipping_address_line2 = attributes[:'shipping_address_line2']
  end

  if attributes.key?(:'shipping_address_city')
    self.shipping_address_city = attributes[:'shipping_address_city']
  end

  if attributes.key?(:'shipping_address_state')
    self.shipping_address_state = attributes[:'shipping_address_state']
  end

  if attributes.key?(:'shipping_address_zip')
    self.shipping_address_zip = attributes[:'shipping_address_zip']
  end

  if attributes.key?(:'shipping_address_country')
    self.shipping_address_country = attributes[:'shipping_address_country']
  end

  if attributes.key?(:'billing_address_name')
    self.billing_address_name = attributes[:'billing_address_name']
  end

  if attributes.key?(:'billing_address_line1')
    self.billing_address_line1 = attributes[:'billing_address_line1']
  end

  if attributes.key?(:'billing_address_line2')
    self.billing_address_line2 = attributes[:'billing_address_line2']
  end

  if attributes.key?(:'billing_address_city')
    self.billing_address_city = attributes[:'billing_address_city']
  end

  if attributes.key?(:'billing_address_state')
    self.billing_address_state = attributes[:'billing_address_state']
  end

  if attributes.key?(:'billing_address_zip')
    self.billing_address_zip = attributes[:'billing_address_zip']
  end

  if attributes.key?(:'billing_address_country')
    self.billing_address_country = attributes[:'billing_address_country']
  end
end

Instance Attribute Details

#billing_address_cityObject

Billing address city.



91
92
93
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 91

def billing_address_city
  @billing_address_city
end

#billing_address_countryObject

Billing address country.



100
101
102
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 100

def billing_address_country
  @billing_address_country
end

#billing_address_line1Object

Billing address line 1.



85
86
87
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 85

def billing_address_line1
  @billing_address_line1
end

#billing_address_line2Object

Billing address line 2.



88
89
90
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 88

def billing_address_line2
  @billing_address_line2
end

#billing_address_nameObject

Billing address name. This is the paying customer's name.



82
83
84
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 82

def billing_address_name
  @billing_address_name
end

#billing_address_stateObject

Billing address state.



94
95
96
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 94

def billing_address_state
  @billing_address_state
end

#billing_address_zipObject

Billing address ZIP code.



97
98
99
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 97

def billing_address_zip
  @billing_address_zip
end

#brandObject

Card brand (e.g. "visa", "mastercard", "jcb").



23
24
25
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 23

def brand
  @brand
end

#emailObject

Customer's email address. Will be used for fraud prevention and payment receipt.



35
36
37
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 35

def email
  @email
end

#expiry_daysObject

Returns the value of attribute expiry_days.



48
49
50
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 48

def expiry_days
  @expiry_days
end

#family_nameObject

Family name of the customer.



46
47
48
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 46

def family_name
  @family_name
end

#given_nameObject

Given name of the customer.



43
44
45
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 43

def given_name
  @given_name
end

#initiatorObject

Returns the value of attribute initiator.



52
53
54
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 52

def initiator
  @initiator
end

#installmentsObject

Returns the value of attribute installments.



58
59
60
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 58

def installments
  @installments
end

#intentObject

Returns the value of attribute intent.



50
51
52
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 50

def intent
  @intent
end

#last_four_digitsObject

Last four digits of the card number.



26
27
28
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 26

def last_four_digits
  @last_four_digits
end

#monthObject

Credit card expiration month.



29
30
31
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 29

def month
  @month
end

#nameObject

Full name of the customer. This attribute takes precedence over given_name and family_name.



40
41
42
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 40

def name
  @name
end

#scheme_referenceObject

Returns the value of attribute scheme_reference.



56
57
58
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 56

def scheme_reference
  @scheme_reference
end

#shipping_address_cityObject

Shipping address city.



70
71
72
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 70

def shipping_address_city
  @shipping_address_city
end

#shipping_address_countryObject

Shipping address country.



79
80
81
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 79

def shipping_address_country
  @shipping_address_country
end

#shipping_address_line1Object

Shipping address line 1.



64
65
66
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 64

def shipping_address_line1
  @shipping_address_line1
end

#shipping_address_line2Object

Shipping address line 2.



67
68
69
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 67

def shipping_address_line2
  @shipping_address_line2
end

#shipping_address_nameObject

Shipping address name. This is the recipient's name.



61
62
63
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 61

def shipping_address_name
  @shipping_address_name
end

#shipping_address_stateObject

Shipping address state.



73
74
75
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 73

def shipping_address_state
  @shipping_address_state
end

#shipping_address_zipObject

Shipping address ZIP code.



76
77
78
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 76

def shipping_address_zip
  @shipping_address_zip
end

#typeObject

Payment method type.



20
21
22
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 20

def type
  @type
end

#usageObject

Returns the value of attribute usage.



54
55
56
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 54

def usage
  @usage
end

#verification_valueObject

Returns the value of attribute verification_value.



37
38
39
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 37

def verification_value
  @verification_value
end

#yearObject

Credit card expiration year. If this value is less than 100, it will be treated as two digits year in the current century. E.g. If current year is 2024, 99 means 2099.



32
33
34
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 32

def year
  @year
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 691

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



161
162
163
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 161

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



166
167
168
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 166

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 125

def self.attribute_map
  {
    :'type' => :'type',
    :'brand' => :'brand',
    :'last_four_digits' => :'last_four_digits',
    :'month' => :'month',
    :'year' => :'year',
    :'email' => :'email',
    :'verification_value' => :'verification_value',
    :'name' => :'name',
    :'given_name' => :'given_name',
    :'family_name' => :'family_name',
    :'expiry_days' => :'expiry_days',
    :'intent' => :'intent',
    :'initiator' => :'initiator',
    :'usage' => :'usage',
    :'scheme_reference' => :'scheme_reference',
    :'installments' => :'installments',
    :'shipping_address_name' => :'shipping_address_name',
    :'shipping_address_line1' => :'shipping_address_line1',
    :'shipping_address_line2' => :'shipping_address_line2',
    :'shipping_address_city' => :'shipping_address_city',
    :'shipping_address_state' => :'shipping_address_state',
    :'shipping_address_zip' => :'shipping_address_zip',
    :'shipping_address_country' => :'shipping_address_country',
    :'billing_address_name' => :'billing_address_name',
    :'billing_address_line1' => :'billing_address_line1',
    :'billing_address_line2' => :'billing_address_line2',
    :'billing_address_city' => :'billing_address_city',
    :'billing_address_state' => :'billing_address_state',
    :'billing_address_zip' => :'billing_address_zip',
    :'billing_address_country' => :'billing_address_country'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 661

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



207
208
209
210
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 207

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 171

def self.openapi_types
  {
    :'type' => :'String',
    :'brand' => :'String',
    :'last_four_digits' => :'String',
    :'month' => :'Integer',
    :'year' => :'Integer',
    :'email' => :'String',
    :'verification_value' => :'String',
    :'name' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'expiry_days' => :'Integer',
    :'intent' => :'String',
    :'initiator' => :'String',
    :'usage' => :'String',
    :'scheme_reference' => :'String',
    :'installments' => :'Installments',
    :'shipping_address_name' => :'String',
    :'shipping_address_line1' => :'String',
    :'shipping_address_line2' => :'String',
    :'shipping_address_city' => :'String',
    :'shipping_address_state' => :'String',
    :'shipping_address_zip' => :'String',
    :'shipping_address_country' => :'String',
    :'billing_address_name' => :'String',
    :'billing_address_line1' => :'String',
    :'billing_address_line2' => :'String',
    :'billing_address_city' => :'String',
    :'billing_address_state' => :'String',
    :'billing_address_zip' => :'String',
    :'billing_address_country' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 611

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      brand == o.brand &&
      last_four_digits == o.last_four_digits &&
      month == o.month &&
      year == o.year &&
      email == o.email &&
      verification_value == o.verification_value &&
      name == o.name &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      expiry_days == o.expiry_days &&
      intent == o.intent &&
      initiator == o.initiator &&
      usage == o.usage &&
      scheme_reference == o.scheme_reference &&
      installments == o.installments &&
      shipping_address_name == o.shipping_address_name &&
      shipping_address_line1 == o.shipping_address_line1 &&
      shipping_address_line2 == o.shipping_address_line2 &&
      shipping_address_city == o.shipping_address_city &&
      shipping_address_state == o.shipping_address_state &&
      shipping_address_zip == o.shipping_address_zip &&
      shipping_address_country == o.shipping_address_country &&
      billing_address_name == o.billing_address_name &&
      billing_address_line1 == o.billing_address_line1 &&
      billing_address_line2 == o.billing_address_line2 &&
      billing_address_city == o.billing_address_city &&
      billing_address_state == o.billing_address_state &&
      billing_address_zip == o.billing_address_zip &&
      billing_address_country == o.billing_address_country
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



762
763
764
765
766
767
768
769
770
771
772
773
774
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 762

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


648
649
650
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 648

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



654
655
656
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 654

def hash
  [type, brand, last_four_digits, month, year, email, verification_value, name, given_name, family_name, expiry_days, intent, initiator, usage, scheme_reference, installments, shipping_address_name, shipping_address_line1, shipping_address_line2, shipping_address_city, shipping_address_state, shipping_address_zip, shipping_address_country, billing_address_name, billing_address_line1, billing_address_line2, billing_address_city, billing_address_state, billing_address_zip, billing_address_country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 363

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @brand.nil?
    invalid_properties.push('invalid value for "brand", brand cannot be nil.')
  end

  if @last_four_digits.nil?
    invalid_properties.push('invalid value for "last_four_digits", last_four_digits cannot be nil.')
  end

  if @month.nil?
    invalid_properties.push('invalid value for "month", month cannot be nil.')
  end

  if @month > 12
    invalid_properties.push('invalid value for "month", must be smaller than or equal to 12.')
  end

  if @month < 1
    invalid_properties.push('invalid value for "month", must be greater than or equal to 1.')
  end

  if @year.nil?
    invalid_properties.push('invalid value for "year", year cannot be nil.')
  end

  if @year > 2100
    invalid_properties.push('invalid value for "year", must be smaller than or equal to 2100.')
  end

  if @year < 0
    invalid_properties.push('invalid value for "year", must be greater than or equal to 0.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if !@given_name.nil? && @given_name.to_s.length > 255
    invalid_properties.push('invalid value for "given_name", the character length must be smaller than or equal to 255.')
  end

  if !@family_name.nil? && @family_name.to_s.length > 255
    invalid_properties.push('invalid value for "family_name", the character length must be smaller than or equal to 255.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



738
739
740
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 738

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



744
745
746
747
748
749
750
751
752
753
754
755
756
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 744

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



732
733
734
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 732

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/komoju-sdk/models/response_payment_details_credit_card.rb', line 423

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["credit_card"])
  return false unless type_validator.valid?(@type)
  return false if @brand.nil?
  return false if @last_four_digits.nil?
  return false if @month.nil?
  return false if @month > 12
  return false if @month < 1
  return false if @year.nil?
  return false if @year > 2100
  return false if @year < 0
  return false if @email.nil?
  verification_value_validator = EnumAttributeValidator.new('String', ["Approved", "Invalid", "Not Checked", "Not Supplied"])
  return false unless verification_value_validator.valid?(@verification_value)
  return false if !@name.nil? && @name.to_s.length > 255
  return false if !@given_name.nil? && @given_name.to_s.length > 255
  return false if !@family_name.nil? && @family_name.to_s.length > 255
  intent_validator = EnumAttributeValidator.new('String', ["one_time", "card_on_file", "subscription", "installment"])
  return false unless intent_validator.valid?(@intent)
  initiator_validator = EnumAttributeValidator.new('String', ["merchant", "customer"])
  return false unless initiator_validator.valid?(@initiator)
  usage_validator = EnumAttributeValidator.new('String', ["first", "used"])
  return false unless usage_validator.valid?(@usage)
  true
end