Class: Komoju::ResponsePaymentDetailsEpospay

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/response_payment_details_epospay.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResponsePaymentDetailsEpospay

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 196

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ResponsePaymentDetailsEpospay` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ResponsePaymentDetailsEpospay`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'offsite_fake_new_path')
    self.offsite_fake_new_path = attributes[:'offsite_fake_new_path']
  end

  if attributes.key?(:'offsite_url')
    self.offsite_url = attributes[:'offsite_url']
  end

  if attributes.key?(:'merchant_id')
    self.merchant_id = attributes[:'merchant_id']
  end

  if attributes.key?(:'shop_id')
    self.shop_id = attributes[:'shop_id']
  end

  if attributes.key?(:'deal_id')
    self.deal_id = attributes[:'deal_id']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'prd_list')
    self.prd_list = attributes[:'prd_list']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'return_url')
    self.return_url = attributes[:'return_url']
  end

  if attributes.key?(:'shipping_address_name')
    self.shipping_address_name = attributes[:'shipping_address_name']
  end

  if attributes.key?(:'shipping_address_line1')
    self.shipping_address_line1 = attributes[:'shipping_address_line1']
  end

  if attributes.key?(:'shipping_address_line2')
    self.shipping_address_line2 = attributes[:'shipping_address_line2']
  end

  if attributes.key?(:'shipping_address_city')
    self.shipping_address_city = attributes[:'shipping_address_city']
  end

  if attributes.key?(:'shipping_address_state')
    self.shipping_address_state = attributes[:'shipping_address_state']
  end

  if attributes.key?(:'shipping_address_zip')
    self.shipping_address_zip = attributes[:'shipping_address_zip']
  end

  if attributes.key?(:'shipping_address_country')
    self.shipping_address_country = attributes[:'shipping_address_country']
  end

  if attributes.key?(:'billing_address_name')
    self.billing_address_name = attributes[:'billing_address_name']
  end

  if attributes.key?(:'billing_address_line1')
    self.billing_address_line1 = attributes[:'billing_address_line1']
  end

  if attributes.key?(:'billing_address_line2')
    self.billing_address_line2 = attributes[:'billing_address_line2']
  end

  if attributes.key?(:'billing_address_city')
    self.billing_address_city = attributes[:'billing_address_city']
  end

  if attributes.key?(:'billing_address_state')
    self.billing_address_state = attributes[:'billing_address_state']
  end

  if attributes.key?(:'billing_address_zip')
    self.billing_address_zip = attributes[:'billing_address_zip']
  end

  if attributes.key?(:'billing_address_country')
    self.billing_address_country = attributes[:'billing_address_country']
  end
end

Instance Attribute Details

#amountObject

Payment amount in the lowest denomination of the currency.



47
48
49
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 47

def amount
  @amount
end

#billing_address_cityObject

Billing address city.



86
87
88
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 86

def billing_address_city
  @billing_address_city
end

#billing_address_countryObject

Billing address country.



95
96
97
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 95

def billing_address_country
  @billing_address_country
end

#billing_address_line1Object

Billing address line 1.



80
81
82
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 80

def billing_address_line1
  @billing_address_line1
end

#billing_address_line2Object

Billing address line 2.



83
84
85
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 83

def billing_address_line2
  @billing_address_line2
end

#billing_address_nameObject

Billing address name. This is the paying customer’s name.



77
78
79
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 77

def billing_address_name
  @billing_address_name
end

#billing_address_stateObject

Billing address state.



89
90
91
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 89

def billing_address_state
  @billing_address_state
end

#billing_address_zipObject

Billing address ZIP code.



92
93
94
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 92

def billing_address_zip
  @billing_address_zip
end

#customer_idObject

Customer identifier in the EPOS system.



50
51
52
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 50

def customer_id
  @customer_id
end

#deal_idObject

Deal identifier for this EPOS transaction.



38
39
40
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 38

def deal_id
  @deal_id
end

#emailObject

Customer’s email address. Will be used for fraud prevention and payment receipt.



23
24
25
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 23

def email
  @email
end

#merchant_idObject

Merchant identifier used in the EPOS payment request.



32
33
34
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 32

def merchant_id
  @merchant_id
end

#offsite_fake_new_pathObject

When using test mode.



26
27
28
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 26

def offsite_fake_new_path
  @offsite_fake_new_path
end

#offsite_urlObject

URL for the customer to complete the EPOS payment offsite.



29
30
31
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 29

def offsite_url
  @offsite_url
end

#prd_listObject

Product list data for the EPOS payment.



44
45
46
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 44

def prd_list
  @prd_list
end

#return_urlObject

URL to redirect the customer to after completing the EPOS payment.



53
54
55
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 53

def return_url
  @return_url
end

#shipping_address_cityObject

Shipping address city.



65
66
67
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 65

def shipping_address_city
  @shipping_address_city
end

#shipping_address_countryObject

Shipping address country.



74
75
76
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 74

def shipping_address_country
  @shipping_address_country
end

#shipping_address_line1Object

Shipping address line 1.



59
60
61
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 59

def shipping_address_line1
  @shipping_address_line1
end

#shipping_address_line2Object

Shipping address line 2.



62
63
64
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 62

def shipping_address_line2
  @shipping_address_line2
end

#shipping_address_nameObject

Shipping address name. This is the recipient’s name.



56
57
58
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 56

def shipping_address_name
  @shipping_address_name
end

#shipping_address_stateObject

Shipping address state.



68
69
70
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 68

def shipping_address_state
  @shipping_address_state
end

#shipping_address_zipObject

Shipping address ZIP code.



71
72
73
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 71

def shipping_address_zip
  @shipping_address_zip
end

#shop_idObject

Shop identifier used in the EPOS payment request.



35
36
37
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 35

def shop_id
  @shop_id
end

#tokenObject

Authentication token for the EPOS payment.



41
42
43
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 41

def token
  @token
end

#typeObject

Payment method type.



20
21
22
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 20

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 433

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



152
153
154
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 152

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 120

def self.attribute_map
  {
    :'type' => :'type',
    :'email' => :'email',
    :'offsite_fake_new_path' => :'offsite_fake_new_path',
    :'offsite_url' => :'offsite_url',
    :'merchant_id' => :'merchant_id',
    :'shop_id' => :'shop_id',
    :'deal_id' => :'deal_id',
    :'token' => :'token',
    :'prd_list' => :'prd_list',
    :'amount' => :'amount',
    :'customer_id' => :'customer_id',
    :'return_url' => :'return_url',
    :'shipping_address_name' => :'shipping_address_name',
    :'shipping_address_line1' => :'shipping_address_line1',
    :'shipping_address_line2' => :'shipping_address_line2',
    :'shipping_address_city' => :'shipping_address_city',
    :'shipping_address_state' => :'shipping_address_state',
    :'shipping_address_zip' => :'shipping_address_zip',
    :'shipping_address_country' => :'shipping_address_country',
    :'billing_address_name' => :'billing_address_name',
    :'billing_address_line1' => :'billing_address_line1',
    :'billing_address_line2' => :'billing_address_line2',
    :'billing_address_city' => :'billing_address_city',
    :'billing_address_state' => :'billing_address_state',
    :'billing_address_zip' => :'billing_address_zip',
    :'billing_address_country' => :'billing_address_country'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 403

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



189
190
191
192
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 189

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 157

def self.openapi_types
  {
    :'type' => :'String',
    :'email' => :'String',
    :'offsite_fake_new_path' => :'String',
    :'offsite_url' => :'String',
    :'merchant_id' => :'String',
    :'shop_id' => :'String',
    :'deal_id' => :'String',
    :'token' => :'String',
    :'prd_list' => :'String',
    :'amount' => :'Integer',
    :'customer_id' => :'String',
    :'return_url' => :'String',
    :'shipping_address_name' => :'String',
    :'shipping_address_line1' => :'String',
    :'shipping_address_line2' => :'String',
    :'shipping_address_city' => :'String',
    :'shipping_address_state' => :'String',
    :'shipping_address_zip' => :'String',
    :'shipping_address_country' => :'String',
    :'billing_address_name' => :'String',
    :'billing_address_line1' => :'String',
    :'billing_address_line2' => :'String',
    :'billing_address_city' => :'String',
    :'billing_address_state' => :'String',
    :'billing_address_zip' => :'String',
    :'billing_address_country' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 357

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      email == o.email &&
      offsite_fake_new_path == o.offsite_fake_new_path &&
      offsite_url == o.offsite_url &&
      merchant_id == o.merchant_id &&
      shop_id == o.shop_id &&
      deal_id == o.deal_id &&
      token == o.token &&
      prd_list == o.prd_list &&
      amount == o.amount &&
      customer_id == o.customer_id &&
      return_url == o.return_url &&
      shipping_address_name == o.shipping_address_name &&
      shipping_address_line1 == o.shipping_address_line1 &&
      shipping_address_line2 == o.shipping_address_line2 &&
      shipping_address_city == o.shipping_address_city &&
      shipping_address_state == o.shipping_address_state &&
      shipping_address_zip == o.shipping_address_zip &&
      shipping_address_country == o.shipping_address_country &&
      billing_address_name == o.billing_address_name &&
      billing_address_line1 == o.billing_address_line1 &&
      billing_address_line2 == o.billing_address_line2 &&
      billing_address_city == o.billing_address_city &&
      billing_address_state == o.billing_address_state &&
      billing_address_zip == o.billing_address_zip &&
      billing_address_country == o.billing_address_country
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 504

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


390
391
392
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 390

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



396
397
398
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 396

def hash
  [type, email, offsite_fake_new_path, offsite_url, merchant_id, shop_id, deal_id, token, prd_list, amount, customer_id, return_url, shipping_address_name, shipping_address_line1, shipping_address_line2, shipping_address_city, shipping_address_state, shipping_address_zip, shipping_address_country, billing_address_name, billing_address_line1, billing_address_line2, billing_address_city, billing_address_state, billing_address_zip, billing_address_country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 320

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



480
481
482
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 480

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 486

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



474
475
476
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 474

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



336
337
338
339
340
341
342
343
# File 'lib/komoju-sdk/models/response_payment_details_epospay.rb', line 336

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["epospay"])
  return false unless type_validator.valid?(@type)
  return false if @email.nil?
  true
end