Class: Komoju::ResponsePaymentDetailsPayEasy

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/response_payment_details_pay_easy.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ResponsePaymentDetailsPayEasy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 177

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ResponsePaymentDetailsPayEasy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ResponsePaymentDetailsPayEasy`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'bank_id')
    self.bank_id = attributes[:'bank_id']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'confirmation_id')
    self.confirmation_id = attributes[:'confirmation_id']
  end

  if attributes.key?(:'instructions_url')
    self.instructions_url = attributes[:'instructions_url']
  end

  if attributes.key?(:'payment_url')
    self.payment_url = attributes[:'payment_url']
  end

  if attributes.key?(:'cvs_code')
    self.cvs_code = attributes[:'cvs_code']
  end

  if attributes.key?(:'shipping_address_name')
    self.shipping_address_name = attributes[:'shipping_address_name']
  end

  if attributes.key?(:'shipping_address_line1')
    self.shipping_address_line1 = attributes[:'shipping_address_line1']
  end

  if attributes.key?(:'shipping_address_line2')
    self.shipping_address_line2 = attributes[:'shipping_address_line2']
  end

  if attributes.key?(:'shipping_address_city')
    self.shipping_address_city = attributes[:'shipping_address_city']
  end

  if attributes.key?(:'shipping_address_state')
    self.shipping_address_state = attributes[:'shipping_address_state']
  end

  if attributes.key?(:'shipping_address_zip')
    self.shipping_address_zip = attributes[:'shipping_address_zip']
  end

  if attributes.key?(:'shipping_address_country')
    self.shipping_address_country = attributes[:'shipping_address_country']
  end

  if attributes.key?(:'billing_address_name')
    self.billing_address_name = attributes[:'billing_address_name']
  end

  if attributes.key?(:'billing_address_line1')
    self.billing_address_line1 = attributes[:'billing_address_line1']
  end

  if attributes.key?(:'billing_address_line2')
    self.billing_address_line2 = attributes[:'billing_address_line2']
  end

  if attributes.key?(:'billing_address_city')
    self.billing_address_city = attributes[:'billing_address_city']
  end

  if attributes.key?(:'billing_address_state')
    self.billing_address_state = attributes[:'billing_address_state']
  end

  if attributes.key?(:'billing_address_zip')
    self.billing_address_zip = attributes[:'billing_address_zip']
  end

  if attributes.key?(:'billing_address_country')
    self.billing_address_country = attributes[:'billing_address_country']
  end
end

Instance Attribute Details

#bank_idObject

Bank identifier for the Pay-easy payment.



26
27
28
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 26

def bank_id
  @bank_id
end

#billing_address_cityObject

Billing address city.



74
75
76
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 74

def billing_address_city
  @billing_address_city
end

#billing_address_countryObject

Billing address country.



83
84
85
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 83

def billing_address_country
  @billing_address_country
end

#billing_address_line1Object

Billing address line 1.



68
69
70
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 68

def billing_address_line1
  @billing_address_line1
end

#billing_address_line2Object

Billing address line 2.



71
72
73
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 71

def billing_address_line2
  @billing_address_line2
end

#billing_address_nameObject

Billing address name. This is the paying customer’s name.



65
66
67
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 65

def billing_address_name
  @billing_address_name
end

#billing_address_stateObject

Billing address state.



77
78
79
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 77

def billing_address_state
  @billing_address_state
end

#billing_address_zipObject

Billing address ZIP code.



80
81
82
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 80

def billing_address_zip
  @billing_address_zip
end

#confirmation_idObject

Confirmation ID for the Pay-easy payment.



32
33
34
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 32

def confirmation_id
  @confirmation_id
end

#customer_idObject

Customer identifier for the Pay-easy payment.



29
30
31
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 29

def customer_id
  @customer_id
end

#cvs_codeObject

CVS code for convenience store payment.



41
42
43
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 41

def cvs_code
  @cvs_code
end

#emailObject

Customer’s email address. Will be used for fraud prevention, payment instruction, and payment receipt.



23
24
25
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 23

def email
  @email
end

#instructions_urlObject

URL with payment instructions for the customer.



35
36
37
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 35

def instructions_url
  @instructions_url
end

#payment_urlObject

URL where the customer can complete the Pay-easy payment online.



38
39
40
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 38

def payment_url
  @payment_url
end

#shipping_address_cityObject

Shipping address city.



53
54
55
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 53

def shipping_address_city
  @shipping_address_city
end

#shipping_address_countryObject

Shipping address country.



62
63
64
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 62

def shipping_address_country
  @shipping_address_country
end

#shipping_address_line1Object

Shipping address line 1.



47
48
49
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 47

def shipping_address_line1
  @shipping_address_line1
end

#shipping_address_line2Object

Shipping address line 2.



50
51
52
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 50

def shipping_address_line2
  @shipping_address_line2
end

#shipping_address_nameObject

Shipping address name. This is the recipient’s name.



44
45
46
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 44

def shipping_address_name
  @shipping_address_name
end

#shipping_address_stateObject

Shipping address state.



56
57
58
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 56

def shipping_address_state
  @shipping_address_state
end

#shipping_address_zipObject

Shipping address ZIP code.



59
60
61
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 59

def shipping_address_zip
  @shipping_address_zip
end

#typeObject

Payment method type.



20
21
22
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 20

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 394

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



136
137
138
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 136

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 108

def self.attribute_map
  {
    :'type' => :'type',
    :'email' => :'email',
    :'bank_id' => :'bank_id',
    :'customer_id' => :'customer_id',
    :'confirmation_id' => :'confirmation_id',
    :'instructions_url' => :'instructions_url',
    :'payment_url' => :'payment_url',
    :'cvs_code' => :'cvs_code',
    :'shipping_address_name' => :'shipping_address_name',
    :'shipping_address_line1' => :'shipping_address_line1',
    :'shipping_address_line2' => :'shipping_address_line2',
    :'shipping_address_city' => :'shipping_address_city',
    :'shipping_address_state' => :'shipping_address_state',
    :'shipping_address_zip' => :'shipping_address_zip',
    :'shipping_address_country' => :'shipping_address_country',
    :'billing_address_name' => :'billing_address_name',
    :'billing_address_line1' => :'billing_address_line1',
    :'billing_address_line2' => :'billing_address_line2',
    :'billing_address_city' => :'billing_address_city',
    :'billing_address_state' => :'billing_address_state',
    :'billing_address_zip' => :'billing_address_zip',
    :'billing_address_country' => :'billing_address_country'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 364

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



169
170
171
172
173
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 169

def self.openapi_nullable
  Set.new([
    :'cvs_code',
  ])
end

.openapi_typesObject

Attribute type mapping.



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 141

def self.openapi_types
  {
    :'type' => :'String',
    :'email' => :'String',
    :'bank_id' => :'String',
    :'customer_id' => :'String',
    :'confirmation_id' => :'String',
    :'instructions_url' => :'String',
    :'payment_url' => :'String',
    :'cvs_code' => :'String',
    :'shipping_address_name' => :'String',
    :'shipping_address_line1' => :'String',
    :'shipping_address_line2' => :'String',
    :'shipping_address_city' => :'String',
    :'shipping_address_state' => :'String',
    :'shipping_address_zip' => :'String',
    :'shipping_address_country' => :'String',
    :'billing_address_name' => :'String',
    :'billing_address_line1' => :'String',
    :'billing_address_line2' => :'String',
    :'billing_address_city' => :'String',
    :'billing_address_state' => :'String',
    :'billing_address_zip' => :'String',
    :'billing_address_country' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      email == o.email &&
      bank_id == o.bank_id &&
      customer_id == o.customer_id &&
      confirmation_id == o.confirmation_id &&
      instructions_url == o.instructions_url &&
      payment_url == o.payment_url &&
      cvs_code == o.cvs_code &&
      shipping_address_name == o.shipping_address_name &&
      shipping_address_line1 == o.shipping_address_line1 &&
      shipping_address_line2 == o.shipping_address_line2 &&
      shipping_address_city == o.shipping_address_city &&
      shipping_address_state == o.shipping_address_state &&
      shipping_address_zip == o.shipping_address_zip &&
      shipping_address_country == o.shipping_address_country &&
      billing_address_name == o.billing_address_name &&
      billing_address_line1 == o.billing_address_line1 &&
      billing_address_line2 == o.billing_address_line2 &&
      billing_address_city == o.billing_address_city &&
      billing_address_state == o.billing_address_state &&
      billing_address_zip == o.billing_address_zip &&
      billing_address_country == o.billing_address_country
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 465

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


351
352
353
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 351

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



357
358
359
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 357

def hash
  [type, email, bank_id, customer_id, confirmation_id, instructions_url, payment_url, cvs_code, shipping_address_name, shipping_address_line1, shipping_address_line2, shipping_address_city, shipping_address_state, shipping_address_zip, shipping_address_country, billing_address_name, billing_address_line1, billing_address_line2, billing_address_city, billing_address_state, billing_address_zip, billing_address_country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 285

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



441
442
443
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 441

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



447
448
449
450
451
452
453
454
455
456
457
458
459
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 447

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



435
436
437
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 435

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



301
302
303
304
305
306
307
308
# File 'lib/komoju-sdk/models/response_payment_details_pay_easy.rb', line 301

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["pay_easy"])
  return false unless type_validator.valid?(@type)
  return false if @email.nil?
  true
end