Class: Komoju::SecureToken
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Komoju::SecureToken
- Defined in:
- lib/komoju-sdk/models/secure_token.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#authentication_url ⇒ Object
URL to redirect the customer to for 3DS authentication.
-
#created_at ⇒ Object
Timestamp when the SecureToken was created.
-
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
-
#three_d_secure_account ⇒ Object
Returns the value of attribute three_d_secure_account.
-
#three_ds_auth_result ⇒ Object
Returns the value of attribute three_ds_auth_result.
-
#verification_status ⇒ Object
Current 3DS verification status of this SecureToken.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SecureToken
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SecureToken
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::SecureToken` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::SecureToken`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'verification_status') self.verification_status = attributes[:'verification_status'] else self.verification_status = nil end if attributes.key?(:'authentication_url') self.authentication_url = attributes[:'authentication_url'] end if attributes.key?(:'three_d_secure_account') self.three_d_secure_account = attributes[:'three_d_secure_account'] end if attributes.key?(:'three_ds_auth_result') self.three_ds_auth_result = attributes[:'three_ds_auth_result'] end end |
Instance Attribute Details
#authentication_url ⇒ Object
URL to redirect the customer to for 3DS authentication. Only present when verification_status is "NEEDS_VERIFY".
28 29 30 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 28 def authentication_url @authentication_url end |
#created_at ⇒ Object
Timestamp when the SecureToken was created.
22 23 24 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 22 def created_at @created_at end |
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
19 20 21 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 19 def id @id end |
#three_d_secure_account ⇒ Object
Returns the value of attribute three_d_secure_account.
30 31 32 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 30 def three_d_secure_account @three_d_secure_account end |
#three_ds_auth_result ⇒ Object
Returns the value of attribute three_ds_auth_result.
32 33 34 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 32 def three_ds_auth_result @three_ds_auth_result end |
#verification_status ⇒ Object
Current 3DS verification status of this SecureToken.
25 26 27 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 25 def verification_status @verification_status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 281 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 57 def self.attribute_map { :'id' => :'id', :'created_at' => :'created_at', :'verification_status' => :'verification_status', :'authentication_url' => :'authentication_url', :'three_d_secure_account' => :'three_d_secure_account', :'three_ds_auth_result' => :'three_ds_auth_result' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 251 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 79 def self.openapi_types { :'id' => :'String', :'created_at' => :'Time', :'verification_status' => :'String', :'authentication_url' => :'String', :'three_d_secure_account' => :'SecureTokenThreeDSecureAccount', :'three_ds_auth_result' => :'ThreeDsAuthResult' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 234 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 225 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && created_at == o.created_at && verification_status == o.verification_status && authentication_url == o.authentication_url && three_d_secure_account == o.three_d_secure_account && three_ds_auth_result == o.three_ds_auth_result end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 352 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
238 239 240 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 238 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 244 def hash [id, created_at, verification_status, authentication_url, three_d_secure_account, three_ds_auth_result].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length > 25 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.') end if @id.to_s.length < 25 invalid_properties.push('invalid value for "id", the character length must be greater than or equal to 25.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @verification_status.nil? invalid_properties.push('invalid value for "verification_status", verification_status cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
328 329 330 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 328 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 334 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
322 323 324 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 322 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/komoju-sdk/models/secure_token.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id.to_s.length > 25 return false if @id.to_s.length < 25 return false if @created_at.nil? return false if @verification_status.nil? verification_status_validator = EnumAttributeValidator.new('String', ["OK", "NEEDS_VERIFY", "ERRORED", "SKIPPED", "CREATED", "EXPIRED"]) return false unless verification_status_validator.valid?(@verification_status) true end |