Class: Komoju::SecureTokensApi

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/api/secure_tokens_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SecureTokensApi

Returns a new instance of SecureTokensApi.



19
20
21
# File 'lib/komoju-sdk/api/secure_tokens_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/komoju-sdk/api/secure_tokens_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_secure_token(create_secure_token_request, opts = {}) ⇒ SecureToken

SecureToken: Create Creates a SecureToken with the given credit card ‘payment_details` or `customer` ID. There are two ways to create a SecureToken: - Using `payment_details` with credit card information. - Using `customer` ID, which is a unique identifier for a customer created via the [Customer: Create](doc.komoju.com/reference/createcustomer) endpoint. Customer’s saved payment details will be used as ‘payment_details`. It is recommended to have a client application make this request directly so that sensitive payment information (e.g. credit card number) doesn’t hit your server. Receiving credit card numbers requires your business to be PCI-DSS compliant. Once you create a secure token using a customer’s credit card details, you can redirect the customer to the authentication url to perform 3DS authentication. Once a secure token has been authenticated, the secure token id can safely be sent to your server and used as ‘payment_details` to a future KOMOJU API request.

Parameters:

Returns:



27
28
29
30
# File 'lib/komoju-sdk/api/secure_tokens_api.rb', line 27

def create_secure_token(create_secure_token_request, opts = {})
  data, _status_code, _headers = create_secure_token_with_http_info(create_secure_token_request, opts)
  data
end

#create_secure_token_with_http_info(create_secure_token_request, opts = {}) ⇒ Array<(SecureToken, Integer, Hash)>

SecureToken: Create Creates a SecureToken with the given credit card &#x60;payment_details&#x60; or &#x60;customer&#x60; ID. There are two ways to create a SecureToken: - Using &#x60;payment_details&#x60; with credit card information. - Using &#x60;customer&#x60; ID, which is a unique identifier for a customer created via the [Customer: Create](doc.komoju.com/reference/createcustomer) endpoint. Customer&#39;s saved payment details will be used as &#x60;payment_details&#x60;. It is recommended to have a client application make this request directly so that sensitive payment information (e.g. credit card number) doesn&#39;t hit your server. Receiving credit card numbers requires your business to be PCI-DSS compliant. Once you create a secure token using a customer&#39;s credit card details, you can redirect the customer to the authentication url to perform 3DS authentication. Once a secure token has been authenticated, the secure token id can safely be sent to your server and used as &#x60;payment_details&#x60; to a future KOMOJU API request.

Parameters:

Returns:

  • (Array<(SecureToken, Integer, Hash)>)

    SecureToken data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/komoju-sdk/api/secure_tokens_api.rb', line 37

def create_secure_token_with_http_info(create_secure_token_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SecureTokensApi.create_secure_token ...'
  end
  # verify the required parameter 'create_secure_token_request' is set
  if @api_client.config.client_side_validation && create_secure_token_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_secure_token_request' when calling SecureTokensApi.create_secure_token"
  end
  # resource path
  local_var_path = '/secure_tokens'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_secure_token_request)

  # return_type
  return_type = opts[:debug_return_type] || 'SecureToken'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['api_key']

  new_options = opts.merge(
    :operation => :"SecureTokensApi.create_secure_token",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SecureTokensApi#create_secure_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#show_secure_token(id, opts = {}) ⇒ SecureToken

SecureToken: Show Retrieves a single SecureToken object by its ‘id`.

Parameters:

  • id (String)

    A unique identifier for the SecureToken.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



95
96
97
98
# File 'lib/komoju-sdk/api/secure_tokens_api.rb', line 95

def show_secure_token(id, opts = {})
  data, _status_code, _headers = show_secure_token_with_http_info(id, opts)
  data
end

#show_secure_token_with_http_info(id, opts = {}) ⇒ Array<(SecureToken, Integer, Hash)>

SecureToken: Show Retrieves a single SecureToken object by its &#x60;id&#x60;.

Parameters:

  • id (String)

    A unique identifier for the SecureToken.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(SecureToken, Integer, Hash)>)

    SecureToken data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/komoju-sdk/api/secure_tokens_api.rb', line 105

def show_secure_token_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SecureTokensApi.show_secure_token ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SecureTokensApi.show_secure_token"
  end
  if @api_client.config.client_side_validation && id.to_s.length > 25
    fail ArgumentError, 'invalid value for "id" when calling SecureTokensApi.show_secure_token, the character length must be smaller than or equal to 25.'
  end

  if @api_client.config.client_side_validation && id.to_s.length < 25
    fail ArgumentError, 'invalid value for "id" when calling SecureTokensApi.show_secure_token, the character length must be great than or equal to 25.'
  end

  # resource path
  local_var_path = '/secure_tokens/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'SecureToken'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['api_key']

  new_options = opts.merge(
    :operation => :"SecureTokensApi.show_secure_token",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SecureTokensApi#show_secure_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end