Class: Komoju::SerializedSubmerchant

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/serialized_submerchant.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SerializedSubmerchant

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::SerializedSubmerchant` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::SerializedSubmerchant`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'live')
    self.live = attributes[:'live']
  else
    self.live = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'platform_role')
    self.platform_role = attributes[:'platform_role']
  else
    self.platform_role = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'payments_enabled')
    self.payments_enabled = attributes[:'payments_enabled']
  else
    self.payments_enabled = nil
  end

  if attributes.key?(:'payouts_enabled')
    self.payouts_enabled = attributes[:'payouts_enabled']
  else
    self.payouts_enabled = nil
  end

  if attributes.key?(:'send_payment_instruction_email')
    self.send_payment_instruction_email = attributes[:'send_payment_instruction_email']
  else
    self.send_payment_instruction_email = nil
  end

  if attributes.key?(:'send_payment_receipt_email')
    self.send_payment_receipt_email = attributes[:'send_payment_receipt_email']
  else
    self.send_payment_receipt_email = nil
  end

  if attributes.key?(:'send_payment_reminder_email')
    self.send_payment_reminder_email = attributes[:'send_payment_reminder_email']
  else
    self.send_payment_reminder_email = nil
  end

  if attributes.key?(:'send_payment_refund_email')
    self.send_payment_refund_email = attributes[:'send_payment_refund_email']
  else
    self.send_payment_refund_email = nil
  end

  if attributes.key?(:'expiry_settings')
    if (value = attributes[:'expiry_settings']).is_a?(Array)
      self.expiry_settings = value
    end
  else
    self.expiry_settings = nil
  end

  if attributes.key?(:'active_payment_methods')
    if (value = attributes[:'active_payment_methods']).is_a?(Array)
      self.active_payment_methods = value
    end
  else
    self.active_payment_methods = nil
  end

  if attributes.key?(:'publishable_key')
    self.publishable_key = attributes[:'publishable_key']
  else
    self.publishable_key = nil
  end
end

Instance Attribute Details

#account_idObject

Account identifier associated with this merchant.



31
32
33
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 31

def 
  @account_id
end

#active_payment_methodsObject

Returns the value of attribute active_payment_methods.



61
62
63
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 61

def active_payment_methods
  @active_payment_methods
end

#created_atObject

Timestamp when this merchant was created.



25
26
27
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 25

def created_at
  @created_at
end

#expiry_settingsObject

Returns the value of attribute expiry_settings.



59
60
61
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 59

def expiry_settings
  @expiry_settings
end

#idObject

Unique identifier for this sub-merchant.



19
20
21
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 19

def id
  @id
end

#liveObject

Whether this merchant is operating in live (production) mode.



22
23
24
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 22

def live
  @live
end

#nameObject

Display name of the sub-merchant.



34
35
36
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 34

def name
  @name
end

#payments_enabledObject

Whether payments are currently enabled for this merchant.



42
43
44
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 42

def payments_enabled
  @payments_enabled
end

#payouts_enabledObject

Whether payouts are currently enabled for this merchant.



45
46
47
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 45

def payouts_enabled
  @payouts_enabled
end

#platform_roleObject

Returns the value of attribute platform_role.



36
37
38
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 36

def platform_role
  @platform_role
end

#publishable_keyObject

The merchant’s publishable API key for client-side use.



64
65
66
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 64

def publishable_key
  @publishable_key
end

#send_payment_instruction_emailObject

Whether payment instruction emails are sent to customers for this merchant.



48
49
50
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 48

def send_payment_instruction_email
  @send_payment_instruction_email
end

#send_payment_receipt_emailObject

Whether payment receipt emails are sent to customers for this merchant.



51
52
53
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 51

def send_payment_receipt_email
  @send_payment_receipt_email
end

#send_payment_refund_emailObject

Whether refund notification emails are sent to customers for this merchant.



57
58
59
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 57

def send_payment_refund_email
  @send_payment_refund_email
end

#send_payment_reminder_emailObject

Whether payment reminder emails are sent to customers for this merchant.



54
55
56
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 54

def send_payment_reminder_email
  @send_payment_reminder_email
end

#statusObject

Current account/application status of the merchant.



39
40
41
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 39

def status
  @status
end

#updated_atObject

Timestamp when this merchant record was last updated.



28
29
30
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 28

def updated_at
  @updated_at
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 436

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



112
113
114
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 112

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 89

def self.attribute_map
  {
    :'id' => :'id',
    :'live' => :'live',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'account_id' => :'account_id',
    :'name' => :'name',
    :'platform_role' => :'platform_role',
    :'status' => :'status',
    :'payments_enabled' => :'payments_enabled',
    :'payouts_enabled' => :'payouts_enabled',
    :'send_payment_instruction_email' => :'send_payment_instruction_email',
    :'send_payment_receipt_email' => :'send_payment_receipt_email',
    :'send_payment_reminder_email' => :'send_payment_reminder_email',
    :'send_payment_refund_email' => :'send_payment_refund_email',
    :'expiry_settings' => :'expiry_settings',
    :'active_payment_methods' => :'active_payment_methods',
    :'publishable_key' => :'publishable_key'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 406

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



140
141
142
143
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 140

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 117

def self.openapi_types
  {
    :'id' => :'String',
    :'live' => :'Boolean',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'account_id' => :'String',
    :'name' => :'String',
    :'platform_role' => :'MerchantRole',
    :'status' => :'String',
    :'payments_enabled' => :'Boolean',
    :'payouts_enabled' => :'Boolean',
    :'send_payment_instruction_email' => :'Boolean',
    :'send_payment_receipt_email' => :'Boolean',
    :'send_payment_reminder_email' => :'Boolean',
    :'send_payment_refund_email' => :'Boolean',
    :'expiry_settings' => :'Array<SerializedSubmerchantExpirySettingsInner>',
    :'active_payment_methods' => :'Array<SerializedSubmerchantActivePaymentMethodsInner>',
    :'publishable_key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 369

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      live == o.live &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
       == o. &&
      name == o.name &&
      platform_role == o.platform_role &&
      status == o.status &&
      payments_enabled == o.payments_enabled &&
      payouts_enabled == o.payouts_enabled &&
      send_payment_instruction_email == o.send_payment_instruction_email &&
      send_payment_receipt_email == o.send_payment_receipt_email &&
      send_payment_reminder_email == o.send_payment_reminder_email &&
      send_payment_refund_email == o.send_payment_refund_email &&
      expiry_settings == o.expiry_settings &&
      active_payment_methods == o.active_payment_methods &&
      publishable_key == o.publishable_key
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



507
508
509
510
511
512
513
514
515
516
517
518
519
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 507

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


393
394
395
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 393

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



399
400
401
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 399

def hash
  [id, live, created_at, updated_at, , name, platform_role, status, payments_enabled, payouts_enabled, send_payment_instruction_email, send_payment_receipt_email, send_payment_reminder_email, send_payment_refund_email, expiry_settings, active_payment_methods, publishable_key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 269

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @live.nil?
    invalid_properties.push('invalid value for "live", live cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @platform_role.nil?
    invalid_properties.push('invalid value for "platform_role", platform_role cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @payments_enabled.nil?
    invalid_properties.push('invalid value for "payments_enabled", payments_enabled cannot be nil.')
  end

  if @payouts_enabled.nil?
    invalid_properties.push('invalid value for "payouts_enabled", payouts_enabled cannot be nil.')
  end

  if @send_payment_instruction_email.nil?
    invalid_properties.push('invalid value for "send_payment_instruction_email", send_payment_instruction_email cannot be nil.')
  end

  if @send_payment_receipt_email.nil?
    invalid_properties.push('invalid value for "send_payment_receipt_email", send_payment_receipt_email cannot be nil.')
  end

  if @send_payment_reminder_email.nil?
    invalid_properties.push('invalid value for "send_payment_reminder_email", send_payment_reminder_email cannot be nil.')
  end

  if @send_payment_refund_email.nil?
    invalid_properties.push('invalid value for "send_payment_refund_email", send_payment_refund_email cannot be nil.')
  end

  if @expiry_settings.nil?
    invalid_properties.push('invalid value for "expiry_settings", expiry_settings cannot be nil.')
  end

  if @active_payment_methods.nil?
    invalid_properties.push('invalid value for "active_payment_methods", active_payment_methods cannot be nil.')
  end

  if @publishable_key.nil?
    invalid_properties.push('invalid value for "publishable_key", publishable_key cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



483
484
485
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 483

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



489
490
491
492
493
494
495
496
497
498
499
500
501
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 489

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



477
478
479
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 477

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/komoju-sdk/models/serialized_submerchant.rb', line 345

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @live.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @platform_role.nil?
  return false if @status.nil?
  return false if @payments_enabled.nil?
  return false if @payouts_enabled.nil?
  return false if @send_payment_instruction_email.nil?
  return false if @send_payment_receipt_email.nil?
  return false if @send_payment_reminder_email.nil?
  return false if @send_payment_refund_email.nil?
  return false if @expiry_settings.nil?
  return false if @active_payment_methods.nil?
  return false if @publishable_key.nil?
  true
end