Class: Komoju::SerializedSubmerchantExpirySettingsInner
- Inherits:
-
Object
- Object
- Komoju::SerializedSubmerchantExpirySettingsInner
- Defined in:
- lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#default_expiry_days ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#expiry_days ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#name ⇒ Object
Human-readable name of the payment method this expiry setting applies to.
-
#slug ⇒ Object
Machine-readable slug identifying the payment method.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SerializedSubmerchantExpirySettingsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SerializedSubmerchantExpirySettingsInner
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::SerializedSubmerchantExpirySettingsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::SerializedSubmerchantExpirySettingsInner`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'slug') self.slug = attributes[:'slug'] else self.slug = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'expiry_days') self.expiry_days = attributes[:'expiry_days'] else self.expiry_days = nil end if attributes.key?(:'default_expiry_days') self.default_expiry_days = attributes[:'default_expiry_days'] else self.default_expiry_days = nil end end |
Instance Attribute Details
#currency ⇒ Object
Returns the value of attribute currency.
24 25 26 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 24 def currency @currency end |
#default_expiry_days ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
30 31 32 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 30 def default_expiry_days @default_expiry_days end |
#expiry_days ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
27 28 29 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 27 def expiry_days @expiry_days end |
#name ⇒ Object
Human-readable name of the payment method this expiry setting applies to.
19 20 21 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 19 def name @name end |
#slug ⇒ Object
Machine-readable slug identifying the payment method.
22 23 24 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 22 def slug @slug end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 268 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 66 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 55 def self.attribute_map { :'name' => :'name', :'slug' => :'slug', :'currency' => :'currency', :'expiry_days' => :'expiry_days', :'default_expiry_days' => :'default_expiry_days' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 71 def self.openapi_types { :'name' => :'String', :'slug' => :'String', :'currency' => :'Currency', :'expiry_days' => :'Integer', :'default_expiry_days' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && slug == o.slug && currency == o.currency && expiry_days == o.expiry_days && default_expiry_days == o.default_expiry_days end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 339 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 231 def hash [name, slug, currency, expiry_days, default_expiry_days].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @slug.nil? invalid_properties.push('invalid value for "slug", slug cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @expiry_days.nil? invalid_properties.push('invalid value for "expiry_days", expiry_days cannot be nil.') end if @expiry_days < 0 invalid_properties.push('invalid value for "expiry_days", must be greater than or equal to 0.') end if @default_expiry_days.nil? invalid_properties.push('invalid value for "default_expiry_days", default_expiry_days cannot be nil.') end if @default_expiry_days < 0 invalid_properties.push('invalid value for "default_expiry_days", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
315 316 317 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 315 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
309 310 311 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 309 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/komoju-sdk/models/serialized_submerchant_expiry_settings_inner.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @slug.nil? return false if @currency.nil? return false if @expiry_days.nil? return false if @expiry_days < 0 return false if @default_expiry_days.nil? return false if @default_expiry_days < 0 true end |