Class: Komoju::SessionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/api/sessions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SessionsApi

Returns a new instance of SessionsApi.



19
20
21
# File 'lib/komoju-sdk/api/sessions_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/komoju-sdk/api/sessions_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#cancel_session(id, opts = {}) ⇒ Session

Session: Cancel Cancels a session.

Parameters:

  • id (String)

    A unique identifier for the session.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/komoju-sdk/api/sessions_api.rb', line 27

def cancel_session(id, opts = {})
  data, _status_code, _headers = cancel_session_with_http_info(id, opts)
  data
end

#cancel_session_with_http_info(id, opts = {}) ⇒ Array<(Session, Integer, Hash)>

Session: Cancel Cancels a session.

Parameters:

  • id (String)

    A unique identifier for the session.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Session, Integer, Hash)>)

    Session data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/komoju-sdk/api/sessions_api.rb', line 37

def cancel_session_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.cancel_session ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SessionsApi.cancel_session"
  end
  # resource path
  local_var_path = '/sessions/{id}/cancel'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Session'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['api_key']

  new_options = opts.merge(
    :operation => :"SessionsApi.cancel_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#cancel_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_session(create_session_request, opts = {}) ⇒ Session

Session: Create Creates a session. There’re 3 modes for the session: * ‘payment`: A payment will be created after user completed the session (default). * `customer`: A customer will be created instead of a payment, or updated if `customer_id` is given. This customer resource can then be used to perform delayed billing or subscriptions. * `customer_payment`: A payment will be created, and customer will be created or updated. You can use this mode to charge money upfront and save customer’s payment details in one go.

Parameters:

  • create_session_request (CreateSessionRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



90
91
92
93
# File 'lib/komoju-sdk/api/sessions_api.rb', line 90

def create_session(create_session_request, opts = {})
  data, _status_code, _headers = create_session_with_http_info(create_session_request, opts)
  data
end

#create_session_with_http_info(create_session_request, opts = {}) ⇒ Array<(Session, Integer, Hash)>

Session: Create Creates a session. There&#39;re 3 modes for the session: * &#x60;payment&#x60;: A payment will be created after user completed the session (default). * &#x60;customer&#x60;: A customer will be created instead of a payment, or updated if &#x60;customer_id&#x60; is given. This customer resource can then be used to perform delayed billing or subscriptions. * &#x60;customer_payment&#x60;: A payment will be created, and customer will be created or updated. You can use this mode to charge money upfront and save customer&#39;s payment details in one go.

Parameters:

  • create_session_request (CreateSessionRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Session, Integer, Hash)>)

    Session data, response status code and response headers



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/komoju-sdk/api/sessions_api.rb', line 100

def create_session_with_http_info(create_session_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.create_session ...'
  end
  # verify the required parameter 'create_session_request' is set
  if @api_client.config.client_side_validation && create_session_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_session_request' when calling SessionsApi.create_session"
  end
  # resource path
  local_var_path = '/sessions'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_session_request)

  # return_type
  return_type = opts[:debug_return_type] || 'Session'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['api_key']

  new_options = opts.merge(
    :operation => :"SessionsApi.create_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#create_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#pay_session(id, pay_session_request, opts = {}) ⇒ PaySessionResponse

Session: Pay Provide customer payment details to pay for a session.

Parameters:

  • id (String)

    A unique identifier for the session.

  • pay_session_request (PaySessionRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



159
160
161
162
# File 'lib/komoju-sdk/api/sessions_api.rb', line 159

def pay_session(id, pay_session_request, opts = {})
  data, _status_code, _headers = pay_session_with_http_info(id, pay_session_request, opts)
  data
end

#pay_session_with_http_info(id, pay_session_request, opts = {}) ⇒ Array<(PaySessionResponse, Integer, Hash)>

Session: Pay Provide customer payment details to pay for a session.

Parameters:

  • id (String)

    A unique identifier for the session.

  • pay_session_request (PaySessionRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PaySessionResponse, Integer, Hash)>)

    PaySessionResponse data, response status code and response headers



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/komoju-sdk/api/sessions_api.rb', line 170

def pay_session_with_http_info(id, pay_session_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.pay_session ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SessionsApi.pay_session"
  end
  # verify the required parameter 'pay_session_request' is set
  if @api_client.config.client_side_validation && pay_session_request.nil?
    fail ArgumentError, "Missing the required parameter 'pay_session_request' when calling SessionsApi.pay_session"
  end
  # resource path
  local_var_path = '/sessions/{id}/pay'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(pay_session_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PaySessionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['api_key']

  new_options = opts.merge(
    :operation => :"SessionsApi.pay_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#pay_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#show_session(id, opts = {}) ⇒ Session

Session: Show Retrieves a Session given its ID. A Session’s status changes when the user completes or cancels their payment. You can listen for those events via webhooks, or use this API to poll for changes.

Parameters:

  • id (String)

    A unique identifier for the session.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



232
233
234
235
# File 'lib/komoju-sdk/api/sessions_api.rb', line 232

def show_session(id, opts = {})
  data, _status_code, _headers = show_session_with_http_info(id, opts)
  data
end

#show_session_with_http_info(id, opts = {}) ⇒ Array<(Session, Integer, Hash)>

Session: Show Retrieves a Session given its ID. A Session&#39;s status changes when the user completes or cancels their payment. You can listen for those events via webhooks, or use this API to poll for changes.

Parameters:

  • id (String)

    A unique identifier for the session.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Session, Integer, Hash)>)

    Session data, response status code and response headers



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/komoju-sdk/api/sessions_api.rb', line 242

def show_session_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.show_session ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SessionsApi.show_session"
  end
  # resource path
  local_var_path = '/sessions/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Session'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['api_key']

  new_options = opts.merge(
    :operation => :"SessionsApi.show_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#show_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end