Class: Komoju::SharedDetailsDisbursements
- Inherits:
-
Object
- Object
- Komoju::SharedDetailsDisbursements
- Defined in:
- lib/komoju-sdk/models/shared_details_disbursements.rb
Instance Attribute Summary collapse
-
#disbursement_amount_total_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#disbursement_fee_total_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#total_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SharedDetailsDisbursements
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SharedDetailsDisbursements
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::SharedDetailsDisbursements` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::SharedDetailsDisbursements`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'disbursement_amount_total_cents') self.disbursement_amount_total_cents = attributes[:'disbursement_amount_total_cents'] else self.disbursement_amount_total_cents = nil end if attributes.key?(:'disbursement_fee_total_cents') self.disbursement_fee_total_cents = attributes[:'disbursement_fee_total_cents'] else self.disbursement_fee_total_cents = nil end if attributes.key?(:'total_cents') self.total_cents = attributes[:'total_cents'] else self.total_cents = nil end end |
Instance Attribute Details
#disbursement_amount_total_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
19 20 21 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 19 def disbursement_amount_total_cents @disbursement_amount_total_cents end |
#disbursement_fee_total_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
22 23 24 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 22 def disbursement_fee_total_cents @disbursement_fee_total_cents end |
#total_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
25 26 27 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 25 def total_cents @total_cents end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 175 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 37 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 28 def self.attribute_map { :'disbursement_amount_total_cents' => :'disbursement_amount_total_cents', :'disbursement_fee_total_cents' => :'disbursement_fee_total_cents', :'total_cents' => :'total_cents' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 145 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 48 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 42 def self.openapi_types { :'disbursement_amount_total_cents' => :'Integer', :'disbursement_fee_total_cents' => :'Integer', :'total_cents' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 122 def ==(o) return true if self.equal?(o) self.class == o.class && disbursement_amount_total_cents == o.disbursement_amount_total_cents && disbursement_fee_total_cents == o.disbursement_fee_total_cents && total_cents == o.total_cents end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 246 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
132 133 134 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 132 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 138 def hash [disbursement_amount_total_cents, disbursement_fee_total_cents, total_cents].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 92 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @disbursement_amount_total_cents.nil? invalid_properties.push('invalid value for "disbursement_amount_total_cents", disbursement_amount_total_cents cannot be nil.') end if @disbursement_fee_total_cents.nil? invalid_properties.push('invalid value for "disbursement_fee_total_cents", disbursement_fee_total_cents cannot be nil.') end if @total_cents.nil? invalid_properties.push('invalid value for "total_cents", total_cents cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
222 223 224 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 222 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 216 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 117 118 |
# File 'lib/komoju-sdk/models/shared_details_disbursements.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @disbursement_amount_total_cents.nil? return false if @disbursement_fee_total_cents.nil? return false if @total_cents.nil? true end |