Class: Komoju::StatementDescriptor
- Inherits:
-
Object
- Object
- Komoju::StatementDescriptor
- Defined in:
- lib/komoju-sdk/models/statement_descriptor.rb
Overview
On supported merchant and supported payment methods, specify a custom statement descriptor for this payment. This helps customer to identify the payment on their statement. See [Dynamic Statement Descriptors & MCCs](doc.komoju.com/docs/payments-with-dynamic-statement-descriptors) for more information.
Instance Attribute Summary collapse
-
#contact_phone ⇒ Object
Contact phone number to be shown on the statement.
-
#statement_city ⇒ Object
Name of the city to be shown on the statement.
-
#statement_descriptor ⇒ Object
Full statement descriptor in Japanese or English.
-
#statement_descriptor_alpha ⇒ Object
Statement descriptor in alphanumeric characters.
-
#statement_descriptor_kana ⇒ Object
Statement descriptor in katakana characters.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StatementDescriptor
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ StatementDescriptor
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::StatementDescriptor` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::StatementDescriptor`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'statement_descriptor') self.statement_descriptor = attributes[:'statement_descriptor'] end if attributes.key?(:'statement_descriptor_alpha') self.statement_descriptor_alpha = attributes[:'statement_descriptor_alpha'] end if attributes.key?(:'statement_descriptor_kana') self.statement_descriptor_kana = attributes[:'statement_descriptor_kana'] end if attributes.key?(:'statement_city') self.statement_city = attributes[:'statement_city'] end if attributes.key?(:'contact_phone') self.contact_phone = attributes[:'contact_phone'] end end |
Instance Attribute Details
#contact_phone ⇒ Object
Contact phone number to be shown on the statement.
32 33 34 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 32 def contact_phone @contact_phone end |
#statement_city ⇒ Object
Name of the city to be shown on the statement.
29 30 31 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 29 def statement_city @statement_city end |
#statement_descriptor ⇒ Object
Full statement descriptor in Japanese or English.
20 21 22 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 20 def statement_descriptor @statement_descriptor end |
#statement_descriptor_alpha ⇒ Object
Statement descriptor in alphanumeric characters.
23 24 25 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 23 def statement_descriptor_alpha @statement_descriptor_alpha end |
#statement_descriptor_kana ⇒ Object
Statement descriptor in katakana characters.
26 27 28 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 26 def statement_descriptor_kana @statement_descriptor_kana end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 175 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 46 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 35 def self.attribute_map { :'statement_descriptor' => :'statement_descriptor', :'statement_descriptor_alpha' => :'statement_descriptor_alpha', :'statement_descriptor_kana' => :'statement_descriptor_kana', :'statement_city' => :'statement_city', :'contact_phone' => :'contact_phone' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 145 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 51 def self.openapi_types { :'statement_descriptor' => :'String', :'statement_descriptor_alpha' => :'String', :'statement_descriptor_kana' => :'String', :'statement_city' => :'String', :'contact_phone' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
120 121 122 123 124 125 126 127 128 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 120 def ==(o) return true if self.equal?(o) self.class == o.class && statement_descriptor == o.statement_descriptor && statement_descriptor_alpha == o.statement_descriptor_alpha && statement_descriptor_kana == o.statement_descriptor_kana && statement_city == o.statement_city && contact_phone == o.contact_phone end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 246 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
132 133 134 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 132 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 138 def hash [statement_descriptor, statement_descriptor_alpha, statement_descriptor_kana, statement_city, contact_phone].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
222 223 224 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 222 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
216 217 218 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 216 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 116 |
# File 'lib/komoju-sdk/models/statement_descriptor.rb', line 113 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |