Class: Komoju::SubmerchantListItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Komoju::SubmerchantListItem
- Defined in:
- lib/komoju-sdk/models/submerchant_list_item.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Account identifier associated with this merchant.
-
#created_at ⇒ Object
Timestamp when this merchant was created.
-
#id ⇒ Object
Unique identifier for this sub-merchant.
-
#live ⇒ Object
Whether this merchant is operating in live (production) mode.
-
#name ⇒ Object
Display name of the sub-merchant.
-
#payments_enabled ⇒ Object
Whether payments are enabled for this merchant.
-
#payouts_enabled ⇒ Object
Whether payouts are enabled for this merchant.
-
#platform_role ⇒ Object
Returns the value of attribute platform_role.
-
#status ⇒ Object
Account application status of the merchant.
-
#updated_at ⇒ Object
Timestamp when this merchant record was last updated.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubmerchantListItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ SubmerchantListItem
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::SubmerchantListItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::SubmerchantListItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'live') self.live = attributes[:'live'] else self.live = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'platform_role') self.platform_role = attributes[:'platform_role'] else self.platform_role = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'payments_enabled') self.payments_enabled = attributes[:'payments_enabled'] else self.payments_enabled = nil end if attributes.key?(:'payouts_enabled') self.payouts_enabled = attributes[:'payouts_enabled'] else self.payouts_enabled = nil end end |
Instance Attribute Details
#account_id ⇒ Object
Account identifier associated with this merchant.
31 32 33 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 31 def account_id @account_id end |
#created_at ⇒ Object
Timestamp when this merchant was created.
25 26 27 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 25 def created_at @created_at end |
#id ⇒ Object
Unique identifier for this sub-merchant.
19 20 21 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 19 def id @id end |
#live ⇒ Object
Whether this merchant is operating in live (production) mode.
22 23 24 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 22 def live @live end |
#name ⇒ Object
Display name of the sub-merchant.
34 35 36 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 34 def name @name end |
#payments_enabled ⇒ Object
Whether payments are enabled for this merchant.
42 43 44 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 42 def payments_enabled @payments_enabled end |
#payouts_enabled ⇒ Object
Whether payouts are enabled for this merchant.
45 46 47 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 45 def payouts_enabled @payouts_enabled end |
#platform_role ⇒ Object
Returns the value of attribute platform_role.
36 37 38 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 36 def platform_role @platform_role end |
#status ⇒ Object
Account application status of the merchant.
39 40 41 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 39 def status @status end |
#updated_at ⇒ Object
Timestamp when this merchant record was last updated.
28 29 30 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 28 def updated_at @updated_at end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 423 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 70 def self.attribute_map { :'id' => :'id', :'live' => :'live', :'created_at' => :'created_at', :'updated_at' => :'updated_at', :'account_id' => :'account_id', :'name' => :'name', :'platform_role' => :'platform_role', :'status' => :'status', :'payments_enabled' => :'payments_enabled', :'payouts_enabled' => :'payouts_enabled' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 393 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 112 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 96 def self.openapi_types { :'id' => :'String', :'live' => :'Boolean', :'created_at' => :'Time', :'updated_at' => :'Time', :'account_id' => :'String', :'name' => :'String', :'platform_role' => :'MerchantRole', :'status' => :'String', :'payments_enabled' => :'Boolean', :'payouts_enabled' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 363 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && live == o.live && created_at == o.created_at && updated_at == o.updated_at && account_id == o.account_id && name == o.name && platform_role == o.platform_role && status == o.status && payments_enabled == o.payments_enabled && payouts_enabled == o.payouts_enabled end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 494 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
380 381 382 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 380 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
386 387 388 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 386 def hash [id, live, created_at, updated_at, account_id, name, platform_role, status, payments_enabled, payouts_enabled].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @live.nil? invalid_properties.push('invalid value for "live", live cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @platform_role.nil? invalid_properties.push('invalid value for "platform_role", platform_role cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @payments_enabled.nil? invalid_properties.push('invalid value for "payments_enabled", payments_enabled cannot be nil.') end if @payouts_enabled.nil? invalid_properties.push('invalid value for "payouts_enabled", payouts_enabled cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
470 471 472 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 470 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 476 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
464 465 466 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 464 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/komoju-sdk/models/submerchant_list_item.rb', line 244 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @live.nil? return false if @created_at.nil? return false if @updated_at.nil? return false if @account_id.nil? return false if @name.nil? return false if @platform_role.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["accepted", "declined"]) return false unless status_validator.valid?(@status) return false if @payments_enabled.nil? return false if @payouts_enabled.nil? true end |