Class: Komoju::Subscription
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Komoju::Subscription
- Defined in:
- lib/komoju-sdk/models/subscription.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#created_at ⇒ Object
Timestamp when the subscription was created.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#customer ⇒ Object
Returns the value of attribute customer.
-
#day ⇒ Object
Day of the period on which the subscription is charged.
-
#ended_at ⇒ Object
Timestamp when the subscription ended, or null if still active.
-
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
-
#metadata ⇒ Object
Arbitrary key-value metadata attached to the subscription.
-
#next_capture_at ⇒ Object
Timestamp of the next scheduled subscription charge.
-
#payment_details ⇒ Object
Returns the value of attribute payment_details.
-
#payments ⇒ Object
Array of payment UUIDs associated with this subscription.
-
#period ⇒ Object
Returns the value of attribute period.
-
#resource ⇒ Object
Resource type name, always "subscription".
-
#retry_at ⇒ Object
Timestamp of the next scheduled payment retry, or null.
-
#retry_count ⇒ Object
Number of times payment has been retried after failure.
-
#status ⇒ Object
Current status of the subscription (e.g. "active", "cancelled").
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Subscription
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Subscription
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/komoju-sdk/models/subscription.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::Subscription` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::Subscription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'resource') self.resource = attributes[:'resource'] else self.resource = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'customer') self.customer = attributes[:'customer'] else self.customer = nil end if attributes.key?(:'period') self.period = attributes[:'period'] else self.period = nil end if attributes.key?(:'day') self.day = attributes[:'day'] else self.day = nil end if attributes.key?(:'payment_details') self.payment_details = attributes[:'payment_details'] else self.payment_details = nil end if attributes.key?(:'retry_count') self.retry_count = attributes[:'retry_count'] else self.retry_count = nil end if attributes.key?(:'retry_at') self.retry_at = attributes[:'retry_at'] else self.retry_at = nil end if attributes.key?(:'next_capture_at') self.next_capture_at = attributes[:'next_capture_at'] else self.next_capture_at = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'ended_at') self.ended_at = attributes[:'ended_at'] else self.ended_at = nil end if attributes.key?(:'metadata') self. = attributes[:'metadata'] else self. = nil end if attributes.key?(:'payments') if (value = attributes[:'payments']).is_a?(Array) self.payments = value end else self.payments = nil end end |
Instance Attribute Details
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
28 29 30 |
# File 'lib/komoju-sdk/models/subscription.rb', line 28 def amount @amount end |
#created_at ⇒ Object
Timestamp when the subscription was created.
51 52 53 |
# File 'lib/komoju-sdk/models/subscription.rb', line 51 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
30 31 32 |
# File 'lib/komoju-sdk/models/subscription.rb', line 30 def currency @currency end |
#customer ⇒ Object
Returns the value of attribute customer.
32 33 34 |
# File 'lib/komoju-sdk/models/subscription.rb', line 32 def customer @customer end |
#day ⇒ Object
Day of the period on which the subscription is charged.
37 38 39 |
# File 'lib/komoju-sdk/models/subscription.rb', line 37 def day @day end |
#ended_at ⇒ Object
Timestamp when the subscription ended, or null if still active.
54 55 56 |
# File 'lib/komoju-sdk/models/subscription.rb', line 54 def ended_at @ended_at end |
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
19 20 21 |
# File 'lib/komoju-sdk/models/subscription.rb', line 19 def id @id end |
#metadata ⇒ Object
Arbitrary key-value metadata attached to the subscription.
57 58 59 |
# File 'lib/komoju-sdk/models/subscription.rb', line 57 def @metadata end |
#next_capture_at ⇒ Object
Timestamp of the next scheduled subscription charge.
48 49 50 |
# File 'lib/komoju-sdk/models/subscription.rb', line 48 def next_capture_at @next_capture_at end |
#payment_details ⇒ Object
Returns the value of attribute payment_details.
39 40 41 |
# File 'lib/komoju-sdk/models/subscription.rb', line 39 def payment_details @payment_details end |
#payments ⇒ Object
Array of payment UUIDs associated with this subscription.
60 61 62 |
# File 'lib/komoju-sdk/models/subscription.rb', line 60 def payments @payments end |
#period ⇒ Object
Returns the value of attribute period.
34 35 36 |
# File 'lib/komoju-sdk/models/subscription.rb', line 34 def period @period end |
#resource ⇒ Object
Resource type name, always "subscription".
22 23 24 |
# File 'lib/komoju-sdk/models/subscription.rb', line 22 def resource @resource end |
#retry_at ⇒ Object
Timestamp of the next scheduled payment retry, or null.
45 46 47 |
# File 'lib/komoju-sdk/models/subscription.rb', line 45 def retry_at @retry_at end |
#retry_count ⇒ Object
Number of times payment has been retried after failure.
42 43 44 |
# File 'lib/komoju-sdk/models/subscription.rb', line 42 def retry_count @retry_count end |
#status ⇒ Object
Current status of the subscription (e.g. "active", "cancelled").
25 26 27 |
# File 'lib/komoju-sdk/models/subscription.rb', line 25 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/komoju-sdk/models/subscription.rb', line 583 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
107 108 109 |
# File 'lib/komoju-sdk/models/subscription.rb', line 107 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
112 113 114 |
# File 'lib/komoju-sdk/models/subscription.rb', line 112 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/komoju-sdk/models/subscription.rb', line 85 def self.attribute_map { :'id' => :'id', :'resource' => :'resource', :'status' => :'status', :'amount' => :'amount', :'currency' => :'currency', :'customer' => :'customer', :'period' => :'period', :'day' => :'day', :'payment_details' => :'payment_details', :'retry_count' => :'retry_count', :'retry_at' => :'retry_at', :'next_capture_at' => :'next_capture_at', :'created_at' => :'created_at', :'ended_at' => :'ended_at', :'metadata' => :'metadata', :'payments' => :'payments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/komoju-sdk/models/subscription.rb', line 553 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
139 140 141 142 143 144 |
# File 'lib/komoju-sdk/models/subscription.rb', line 139 def self.openapi_nullable Set.new([ :'retry_at', :'ended_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/komoju-sdk/models/subscription.rb', line 117 def self.openapi_types { :'id' => :'String', :'resource' => :'String', :'status' => :'String', :'amount' => :'Integer', :'currency' => :'Currency', :'customer' => :'SubscriptionCustomer', :'period' => :'SubscriptionPeriod', :'day' => :'Integer', :'payment_details' => :'SubscriptionPaymentDetails', :'retry_count' => :'Integer', :'retry_at' => :'Time', :'next_capture_at' => :'Time', :'created_at' => :'Time', :'ended_at' => :'Time', :'metadata' => :'Object', :'payments' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/komoju-sdk/models/subscription.rb', line 517 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && resource == o.resource && status == o.status && amount == o.amount && currency == o.currency && customer == o.customer && period == o.period && day == o.day && payment_details == o.payment_details && retry_count == o.retry_count && retry_at == o.retry_at && next_capture_at == o.next_capture_at && created_at == o.created_at && ended_at == o.ended_at && == o. && payments == o.payments end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'lib/komoju-sdk/models/subscription.rb', line 654 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
540 541 542 |
# File 'lib/komoju-sdk/models/subscription.rb', line 540 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
546 547 548 |
# File 'lib/komoju-sdk/models/subscription.rb', line 546 def hash [id, resource, status, amount, currency, customer, period, day, payment_details, retry_count, retry_at, next_capture_at, created_at, ended_at, , payments].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/komoju-sdk/models/subscription.rb', line 263 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length > 25 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.') end if @id.to_s.length < 25 invalid_properties.push('invalid value for "id", the character length must be greater than or equal to 25.') end if @resource.nil? invalid_properties.push('invalid value for "resource", resource cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @amount < 0 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @customer.nil? invalid_properties.push('invalid value for "customer", customer cannot be nil.') end if @period.nil? invalid_properties.push('invalid value for "period", period cannot be nil.') end if @day.nil? invalid_properties.push('invalid value for "day", day cannot be nil.') end if @payment_details.nil? invalid_properties.push('invalid value for "payment_details", payment_details cannot be nil.') end if @retry_count.nil? invalid_properties.push('invalid value for "retry_count", retry_count cannot be nil.') end if @next_capture_at.nil? invalid_properties.push('invalid value for "next_capture_at", next_capture_at cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @metadata.nil? invalid_properties.push('invalid value for "metadata", metadata cannot be nil.') end if @payments.nil? invalid_properties.push('invalid value for "payments", payments cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
630 631 632 |
# File 'lib/komoju-sdk/models/subscription.rb', line 630 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
636 637 638 639 640 641 642 643 644 645 646 647 648 |
# File 'lib/komoju-sdk/models/subscription.rb', line 636 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
624 625 626 |
# File 'lib/komoju-sdk/models/subscription.rb', line 624 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/komoju-sdk/models/subscription.rb', line 339 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id.to_s.length > 25 return false if @id.to_s.length < 25 return false if @resource.nil? resource_validator = EnumAttributeValidator.new('String', ["subscription"]) return false unless resource_validator.valid?(@resource) return false if @status.nil? return false if @amount.nil? return false if @amount < 0 return false if @currency.nil? return false if @customer.nil? return false if @period.nil? return false if @day.nil? return false if @payment_details.nil? return false if @retry_count.nil? return false if @next_capture_at.nil? return false if @created_at.nil? return false if @metadata.nil? return false if @payments.nil? true end |