Class: Komoju::SubscriptionCustomer

Inherits:
ApiModelBase show all
Defined in:
lib/komoju-sdk/models/subscription_customer.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionCustomer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::SubscriptionCustomer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::SubscriptionCustomer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'uuid')
    self.uuid = attributes[:'uuid']
  else
    self.uuid = nil
  end

  if attributes.key?(:'merchant_id')
    self.merchant_id = attributes[:'merchant_id']
  else
    self.merchant_id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'locale')
    self.locale = attributes[:'locale']
  else
    self.locale = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  else
    self.phone = nil
  end

  if attributes.key?(:'archived_at')
    self.archived_at = attributes[:'archived_at']
  else
    self.archived_at = nil
  end
end

Instance Attribute Details

#archived_atObject

Timestamp when the customer was archived, or null if still active.



47
48
49
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 47

def archived_at
  @archived_at
end

#created_atObject

Timestamp when the customer was created.



28
29
30
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 28

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



36
37
38
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 36

def currency
  @currency
end

#emailObject

Customer's email address, or null if not provided.



34
35
36
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 34

def email
  @email
end

#idObject

Internal numeric ID of the customer.



19
20
21
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 19

def id
  @id
end

#localeObject

Returns the value of attribute locale.



38
39
40
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 38

def locale
  @locale
end

#merchant_idObject

Internal numeric ID of the merchant.



25
26
27
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 25

def merchant_id
  @merchant_id
end

#nameObject

Customer-defined display name, or null if not set.



41
42
43
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 41

def name
  @name
end

#phoneObject

Customer's phone number, or null if not set.



44
45
46
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 44

def phone
  @phone
end

#updated_atObject

Timestamp when the customer was last updated.



31
32
33
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 31

def updated_at
  @updated_at
end

#uuidObject

A unique 25-character alphanumeric resource identifier.



22
23
24
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 22

def uuid
  @uuid
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 409

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 72

def self.attribute_map
  {
    :'id' => :'id',
    :'uuid' => :'uuid',
    :'merchant_id' => :'merchant_id',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'email' => :'email',
    :'currency' => :'currency',
    :'locale' => :'locale',
    :'name' => :'name',
    :'phone' => :'phone',
    :'archived_at' => :'archived_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 379

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
120
121
122
123
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 116

def self.openapi_nullable
  Set.new([
    :'email',
    :'name',
    :'phone',
    :'archived_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 99

def self.openapi_types
  {
    :'id' => :'Integer',
    :'uuid' => :'String',
    :'merchant_id' => :'Integer',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'email' => :'String',
    :'currency' => :'Currency',
    :'locale' => :'Locale',
    :'name' => :'String',
    :'phone' => :'String',
    :'archived_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 348

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      uuid == o.uuid &&
      merchant_id == o.merchant_id &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      email == o.email &&
      currency == o.currency &&
      locale == o.locale &&
      name == o.name &&
      phone == o.phone &&
      archived_at == o.archived_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



480
481
482
483
484
485
486
487
488
489
490
491
492
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 480

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


366
367
368
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 366

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



372
373
374
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 372

def hash
  [id, uuid, merchant_id, created_at, updated_at, email, currency, locale, name, phone, archived_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 210

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @uuid.nil?
    invalid_properties.push('invalid value for "uuid", uuid cannot be nil.')
  end

  if @uuid.to_s.length > 25
    invalid_properties.push('invalid value for "uuid", the character length must be smaller than or equal to 25.')
  end

  if @uuid.to_s.length < 25
    invalid_properties.push('invalid value for "uuid", the character length must be greater than or equal to 25.')
  end

  if @merchant_id.nil?
    invalid_properties.push('invalid value for "merchant_id", merchant_id cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @locale.nil?
    invalid_properties.push('invalid value for "locale", locale cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



456
457
458
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 456

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 462

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



450
451
452
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 450

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/komoju-sdk/models/subscription_customer.rb', line 254

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @uuid.nil?
  return false if @uuid.to_s.length > 25
  return false if @uuid.to_s.length < 25
  return false if @merchant_id.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @currency.nil?
  return false if @locale.nil?
  true
end