Class: Komoju::TokensApi
- Inherits:
-
Object
- Object
- Komoju::TokensApi
- Defined in:
- lib/komoju-sdk/api/tokens_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_token(create_token_request, opts = {}) ⇒ Token
Token: Create Creates a token with the given
payment_details. -
#create_token_with_http_info(create_token_request, opts = {}) ⇒ Array<(Token, Integer, Hash)>
Token: Create Creates a token with the given `payment_details`.
-
#initialize(api_client = ApiClient.default) ⇒ TokensApi
constructor
A new instance of TokensApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/komoju-sdk/api/tokens_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_token(create_token_request, opts = {}) ⇒ Token
Token: Create
Creates a token with the given payment_details. It is recommended to have a client application make this request directly so that sensitive payment information (e.g. credit card number) doesn't hit your server. Receiving credit card numbers requires your business to be PCI-DSS compliant. Once you turn your customer's details into a token, the token string can safely be sent to your server and used as payment_details to a future KOMOJU API request. A currency may be optionally specified. When currency is provided, KOMOJU will ensure that the payment made using the new token is in the same currency.
27 28 29 30 |
# File 'lib/komoju-sdk/api/tokens_api.rb', line 27 def create_token(create_token_request, opts = {}) data, _status_code, _headers = create_token_with_http_info(create_token_request, opts) data end |
#create_token_with_http_info(create_token_request, opts = {}) ⇒ Array<(Token, Integer, Hash)>
Token: Create Creates a token with the given `payment_details`. It is recommended to have a client application make this request directly so that sensitive payment information (e.g. credit card number) doesn't hit your server. Receiving credit card numbers requires your business to be PCI-DSS compliant. Once you turn your customer's details into a token, the token string can safely be sent to your server and used as `payment_details` to a future KOMOJU API request. A `currency` may be optionally specified. When `currency` is provided, KOMOJU will ensure that the payment made using the new token is in the same currency.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/komoju-sdk/api/tokens_api.rb', line 37 def create_token_with_http_info(create_token_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TokensApi.create_token ...' end # verify the required parameter 'create_token_request' is set if @api_client.config.client_side_validation && create_token_request.nil? fail ArgumentError, "Missing the required parameter 'create_token_request' when calling TokensApi.create_token" end # resource path local_var_path = '/tokens' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_token_request) # return_type return_type = opts[:debug_return_type] || 'Token' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"TokensApi.create_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TokensApi#create_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |