Class: Komoju::UpdatePaymentMethodRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/update_payment_method_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UpdatePaymentMethodRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 359

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::UpdatePaymentMethodRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::UpdatePaymentMethodRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'locale')
    self.locale = attributes[:'locale']
  end

  if attributes.key?(:'shared_payment_method_data_open_time')
    self.shared_payment_method_data_open_time = attributes[:'shared_payment_method_data_open_time']
  end

  if attributes.key?(:'shared_payment_method_data_close_time')
    self.shared_payment_method_data_close_time = attributes[:'shared_payment_method_data_close_time']
  end

  if attributes.key?(:'shared_payment_method_data_privacy_policy_url')
    self.shared_payment_method_data_privacy_policy_url = attributes[:'shared_payment_method_data_privacy_policy_url']
  end

  if attributes.key?(:'shared_payment_method_data_terms_of_service_url')
    self.shared_payment_method_data_terms_of_service_url = attributes[:'shared_payment_method_data_terms_of_service_url']
  end

  if attributes.key?(:'shared_payment_method_data_pci_compliance_proofs')
    if (value = attributes[:'shared_payment_method_data_pci_compliance_proofs']).is_a?(Array)
      self.shared_payment_method_data_pci_compliance_proofs = value
    end
  end

  if attributes.key?(:'shared_payment_method_data_shareholder_registers')
    if (value = attributes[:'shared_payment_method_data_shareholder_registers']).is_a?(Array)
      self.shared_payment_method_data_shareholder_registers = value
    end
  end

  if attributes.key?(:'shared_payment_method_data_has_processed_cc_before')
    self.shared_payment_method_data_has_processed_cc_before = attributes[:'shared_payment_method_data_has_processed_cc_before']
  end

  if attributes.key?(:'shared_payment_method_data_processes_card_info')
    self.shared_payment_method_data_processes_card_info = attributes[:'shared_payment_method_data_processes_card_info']
  end

  if attributes.key?(:'shared_payment_method_data_conducts_door_to_door_sales')
    self.shared_payment_method_data_conducts_door_to_door_sales = attributes[:'shared_payment_method_data_conducts_door_to_door_sales']
  end

  if attributes.key?(:'shared_payment_method_data_conducts_telemarketing')
    self.shared_payment_method_data_conducts_telemarketing = attributes[:'shared_payment_method_data_conducts_telemarketing']
  end

  if attributes.key?(:'shared_payment_method_data_conducts_mlm_scheme')
    self.shared_payment_method_data_conducts_mlm_scheme = attributes[:'shared_payment_method_data_conducts_mlm_scheme']
  end

  if attributes.key?(:'shared_payment_method_data_conducts_business_opportunity_scheme')
    self.shared_payment_method_data_conducts_business_opportunity_scheme = attributes[:'shared_payment_method_data_conducts_business_opportunity_scheme']
  end

  if attributes.key?(:'shared_payment_method_data_provides_specified_continuous_services')
    self.shared_payment_method_data_provides_specified_continuous_services = attributes[:'shared_payment_method_data_provides_specified_continuous_services']
  end

  if attributes.key?(:'shared_payment_method_data_violated_consumer_contract_act')
    self.shared_payment_method_data_violated_consumer_contract_act = attributes[:'shared_payment_method_data_violated_consumer_contract_act']
  end

  if attributes.key?(:'shared_payment_method_data_violated_commercial_transaction_act')
    self.shared_payment_method_data_violated_commercial_transaction_act = attributes[:'shared_payment_method_data_violated_commercial_transaction_act']
  end

  if attributes.key?(:'linepay_accepted_line_tos')
    self.linepay_accepted_line_tos = attributes[:'linepay_accepted_line_tos']
  end

  if attributes.key?(:'linepay_fields')
    self.linepay_fields = attributes[:'linepay_fields']
  end

  if attributes.key?(:'paypay_accepted_paypay_tos')
    self.paypay_accepted_paypay_tos = attributes[:'paypay_accepted_paypay_tos']
  end

  if attributes.key?(:'paypay_fields')
    self.paypay_fields = attributes[:'paypay_fields']
  end

  if attributes.key?(:'merpay_accepted_merpay_tos')
    self.merpay_accepted_merpay_tos = attributes[:'merpay_accepted_merpay_tos']
  end

  if attributes.key?(:'merpay_fields')
    self.merpay_fields = attributes[:'merpay_fields']
  end

  if attributes.key?(:'convenience_store_expected_number_of_payments')
    self.convenience_store_expected_number_of_payments = attributes[:'convenience_store_expected_number_of_payments']
  end

  if attributes.key?(:'convenience_store_fields')
    self.convenience_store_fields = attributes[:'convenience_store_fields']
  end

  if attributes.key?(:'seven_eleven_site_is_public')
    self.seven_eleven_site_is_public = attributes[:'seven_eleven_site_is_public']
  end

  if attributes.key?(:'seven_eleven_no_direct_delivery_from_producer')
    self.seven_eleven_no_direct_delivery_from_producer = attributes[:'seven_eleven_no_direct_delivery_from_producer']
  end

  if attributes.key?(:'seven_eleven_no_ticket_sales')
    self.seven_eleven_no_ticket_sales = attributes[:'seven_eleven_no_ticket_sales']
  end

  if attributes.key?(:'seven_eleven_correct_flow_for_order_items')
    self.seven_eleven_correct_flow_for_order_items = attributes[:'seven_eleven_correct_flow_for_order_items']
  end

  if attributes.key?(:'seven_eleven_delivery_within_two_months')
    self.seven_eleven_delivery_within_two_months = attributes[:'seven_eleven_delivery_within_two_months']
  end

  if attributes.key?(:'seven_eleven_all_items_are_cheaper_than_konbini_limit')
    self.seven_eleven_all_items_are_cheaper_than_konbini_limit = attributes[:'seven_eleven_all_items_are_cheaper_than_konbini_limit']
  end

  if attributes.key?(:'seven_eleven_display_sales_permit_number')
    self.seven_eleven_display_sales_permit_number = attributes[:'seven_eleven_display_sales_permit_number']
  end

  if attributes.key?(:'seven_eleven_order_fee_is_displayed')
    self.seven_eleven_order_fee_is_displayed = attributes[:'seven_eleven_order_fee_is_displayed']
  end

  if attributes.key?(:'seven_eleven_no_international_transaction')
    self.seven_eleven_no_international_transaction = attributes[:'seven_eleven_no_international_transaction']
  end

  if attributes.key?(:'seven_eleven_provided_info_matches_sctl')
    self.seven_eleven_provided_info_matches_sctl = attributes[:'seven_eleven_provided_info_matches_sctl']
  end

  if attributes.key?(:'seven_eleven_sctl_page_has_phone_number')
    self.seven_eleven_sctl_page_has_phone_number = attributes[:'seven_eleven_sctl_page_has_phone_number']
  end

  if attributes.key?(:'seven_eleven_product_pages_are_public')
    self.seven_eleven_product_pages_are_public = attributes[:'seven_eleven_product_pages_are_public']
  end

  if attributes.key?(:'seven_eleven_have_sold_as_regular_price')
    self.seven_eleven_have_sold_as_regular_price = attributes[:'seven_eleven_have_sold_as_regular_price']
  end

  if attributes.key?(:'seven_eleven_note')
    self.seven_eleven_note = attributes[:'seven_eleven_note']
  end

  if attributes.key?(:'seven_eleven_fields')
    self.seven_eleven_fields = attributes[:'seven_eleven_fields']
  end

  if attributes.key?(:'visa_mastercard_credit_card_access_restrictions')
    self.visa_mastercard_credit_card_access_restrictions = attributes[:'visa_mastercard_credit_card_access_restrictions']
  end

  if attributes.key?(:'visa_mastercard_credit_card_mfa_implementation')
    self.visa_mastercard_credit_card_mfa_implementation = attributes[:'visa_mastercard_credit_card_mfa_implementation']
  end

  if attributes.key?(:'visa_mastercard_credit_card_account_lock')
    self. = attributes[:'visa_mastercard_credit_card_account_lock']
  end

  if attributes.key?(:'visa_mastercard_credit_card_public_directories')
    self.visa_mastercard_credit_card_public_directories = attributes[:'visa_mastercard_credit_card_public_directories']
  end

  if attributes.key?(:'visa_mastercard_credit_card_file_extension_restrictions')
    self.visa_mastercard_credit_card_file_extension_restrictions = attributes[:'visa_mastercard_credit_card_file_extension_restrictions']
  end

  if attributes.key?(:'visa_mastercard_credit_card_vulnerability_assessments')
    self.visa_mastercard_credit_card_vulnerability_assessments = attributes[:'visa_mastercard_credit_card_vulnerability_assessments']
  end

  if attributes.key?(:'visa_mastercard_credit_card_sql_injection_and_xss')
    self.visa_mastercard_credit_card_sql_injection_and_xss = attributes[:'visa_mastercard_credit_card_sql_injection_and_xss']
  end

  if attributes.key?(:'visa_mastercard_credit_card_source_code_review')
    self.visa_mastercard_credit_card_source_code_review = attributes[:'visa_mastercard_credit_card_source_code_review']
  end

  if attributes.key?(:'visa_mastercard_credit_card_anti_virus_software')
    self.visa_mastercard_credit_card_anti_virus_software = attributes[:'visa_mastercard_credit_card_anti_virus_software']
  end

  if attributes.key?(:'visa_mastercard_credit_card_fields')
    self.visa_mastercard_credit_card_fields = attributes[:'visa_mastercard_credit_card_fields']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_access_restrictions')
    self.jcb_amex_diners_credit_card_access_restrictions = attributes[:'jcb_amex_diners_credit_card_access_restrictions']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_mfa_implementation')
    self.jcb_amex_diners_credit_card_mfa_implementation = attributes[:'jcb_amex_diners_credit_card_mfa_implementation']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_account_lock')
    self. = attributes[:'jcb_amex_diners_credit_card_account_lock']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_public_directories')
    self.jcb_amex_diners_credit_card_public_directories = attributes[:'jcb_amex_diners_credit_card_public_directories']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_file_extension_restrictions')
    self.jcb_amex_diners_credit_card_file_extension_restrictions = attributes[:'jcb_amex_diners_credit_card_file_extension_restrictions']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_vulnerability_assessments')
    self.jcb_amex_diners_credit_card_vulnerability_assessments = attributes[:'jcb_amex_diners_credit_card_vulnerability_assessments']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_sql_injection_and_xss')
    self.jcb_amex_diners_credit_card_sql_injection_and_xss = attributes[:'jcb_amex_diners_credit_card_sql_injection_and_xss']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_source_code_review')
    self.jcb_amex_diners_credit_card_source_code_review = attributes[:'jcb_amex_diners_credit_card_source_code_review']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_anti_virus_software')
    self.jcb_amex_diners_credit_card_anti_virus_software = attributes[:'jcb_amex_diners_credit_card_anti_virus_software']
  end

  if attributes.key?(:'jcb_amex_diners_credit_card_fields')
    self.jcb_amex_diners_credit_card_fields = attributes[:'jcb_amex_diners_credit_card_fields']
  end
end

Instance Attribute Details

#convenience_store_expected_number_of_paymentsObject

Estimated monthly number of convenience store payments.



84
85
86
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 84

def convenience_store_expected_number_of_payments
  @convenience_store_expected_number_of_payments
end

#convenience_store_fieldsObject

Serialized form fields for the convenience store application.



87
88
89
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 87

def convenience_store_fields
  @convenience_store_fields
end

#jcb_amex_diners_credit_card_access_restrictionsObject

Confirmation that the site has appropriate access restrictions in place (JCB/Amex/Diners).



165
166
167
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 165

def jcb_amex_diners_credit_card_access_restrictions
  @jcb_amex_diners_credit_card_access_restrictions
end

#jcb_amex_diners_credit_card_account_lockObject

Confirmation that account lockout policies are in place (JCB/Amex/Diners).



171
172
173
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 171

def 
  @jcb_amex_diners_credit_card_account_lock
end

#jcb_amex_diners_credit_card_anti_virus_softwareObject

Confirmation that anti-virus software is installed and maintained (JCB/Amex/Diners).



189
190
191
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 189

def jcb_amex_diners_credit_card_anti_virus_software
  @jcb_amex_diners_credit_card_anti_virus_software
end

#jcb_amex_diners_credit_card_fieldsObject

Serialized form fields for the JCB/Amex/Diners credit card application.



192
193
194
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 192

def jcb_amex_diners_credit_card_fields
  @jcb_amex_diners_credit_card_fields
end

#jcb_amex_diners_credit_card_file_extension_restrictionsObject

Confirmation that file extension restrictions are enforced (JCB/Amex/Diners).



177
178
179
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 177

def jcb_amex_diners_credit_card_file_extension_restrictions
  @jcb_amex_diners_credit_card_file_extension_restrictions
end

#jcb_amex_diners_credit_card_mfa_implementationObject

Confirmation that multi-factor authentication is implemented (JCB/Amex/Diners).



168
169
170
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 168

def jcb_amex_diners_credit_card_mfa_implementation
  @jcb_amex_diners_credit_card_mfa_implementation
end

#jcb_amex_diners_credit_card_public_directoriesObject

Confirmation that public directory listing is disabled (JCB/Amex/Diners).



174
175
176
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 174

def jcb_amex_diners_credit_card_public_directories
  @jcb_amex_diners_credit_card_public_directories
end

#jcb_amex_diners_credit_card_source_code_reviewObject

Confirmation that source code security review is performed (JCB/Amex/Diners).



186
187
188
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 186

def jcb_amex_diners_credit_card_source_code_review
  @jcb_amex_diners_credit_card_source_code_review
end

#jcb_amex_diners_credit_card_sql_injection_and_xssObject

Confirmation that the site is protected against SQL injection and XSS attacks (JCB/Amex/Diners).



183
184
185
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 183

def jcb_amex_diners_credit_card_sql_injection_and_xss
  @jcb_amex_diners_credit_card_sql_injection_and_xss
end

#jcb_amex_diners_credit_card_vulnerability_assessmentsObject

Confirmation that regular vulnerability assessments are conducted (JCB/Amex/Diners).



180
181
182
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 180

def jcb_amex_diners_credit_card_vulnerability_assessments
  @jcb_amex_diners_credit_card_vulnerability_assessments
end

#linepay_accepted_line_tosObject

Whether the merchant has accepted LINE Pay’s terms of service.



66
67
68
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 66

def linepay_accepted_line_tos
  @linepay_accepted_line_tos
end

#linepay_fieldsObject

Serialized form fields for the LINE Pay application.



69
70
71
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 69

def linepay_fields
  @linepay_fields
end

#localeObject

Returns the value of attribute locale.



18
19
20
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 18

def locale
  @locale
end

#merpay_accepted_merpay_tosObject

Whether the merchant has accepted Merpay’s terms of service.



78
79
80
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 78

def merpay_accepted_merpay_tos
  @merpay_accepted_merpay_tos
end

#merpay_fieldsObject

Serialized form fields for the Merpay application.



81
82
83
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 81

def merpay_fields
  @merpay_fields
end

#paypay_accepted_paypay_tosObject

Whether the merchant has accepted PayPay’s terms of service.



72
73
74
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 72

def paypay_accepted_paypay_tos
  @paypay_accepted_paypay_tos
end

#paypay_fieldsObject

Serialized form fields for the PayPay application.



75
76
77
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 75

def paypay_fields
  @paypay_fields
end

#seven_eleven_all_items_are_cheaper_than_konbini_limitObject

Confirmation that all items are priced below the konbini payment limit.



105
106
107
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 105

def seven_eleven_all_items_are_cheaper_than_konbini_limit
  @seven_eleven_all_items_are_cheaper_than_konbini_limit
end

#seven_eleven_correct_flow_for_order_itemsObject

Confirmation that the order flow matches Seven-Eleven’s requirements.



99
100
101
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 99

def seven_eleven_correct_flow_for_order_items
  @seven_eleven_correct_flow_for_order_items
end

#seven_eleven_delivery_within_two_monthsObject

Confirmation that all ordered items will be delivered within two months.



102
103
104
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 102

def seven_eleven_delivery_within_two_months
  @seven_eleven_delivery_within_two_months
end

#seven_eleven_display_sales_permit_numberObject

Confirmation that any required sales permit numbers are displayed.



108
109
110
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 108

def seven_eleven_display_sales_permit_number
  @seven_eleven_display_sales_permit_number
end

#seven_eleven_fieldsObject

Serialized form fields for the Seven-Eleven application.



132
133
134
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 132

def seven_eleven_fields
  @seven_eleven_fields
end

#seven_eleven_have_sold_as_regular_priceObject

Confirmation that items have been sold at regular (non-discounted) price before.



126
127
128
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 126

def seven_eleven_have_sold_as_regular_price
  @seven_eleven_have_sold_as_regular_price
end

#seven_eleven_no_direct_delivery_from_producerObject

Confirmation that products are not delivered directly from producers.



93
94
95
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 93

def seven_eleven_no_direct_delivery_from_producer
  @seven_eleven_no_direct_delivery_from_producer
end

#seven_eleven_no_international_transactionObject

Confirmation that transactions are domestic only.



114
115
116
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 114

def seven_eleven_no_international_transaction
  @seven_eleven_no_international_transaction
end

#seven_eleven_no_ticket_salesObject

Confirmation that the merchant does not sell tickets.



96
97
98
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 96

def seven_eleven_no_ticket_sales
  @seven_eleven_no_ticket_sales
end

#seven_eleven_noteObject

Free-text notes for the Seven-Eleven application.



129
130
131
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 129

def seven_eleven_note
  @seven_eleven_note
end

#seven_eleven_order_fee_is_displayedObject

Confirmation that the order fee is clearly displayed to customers.



111
112
113
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 111

def seven_eleven_order_fee_is_displayed
  @seven_eleven_order_fee_is_displayed
end

#seven_eleven_product_pages_are_publicObject

Confirmation that product detail pages are publicly viewable.



123
124
125
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 123

def seven_eleven_product_pages_are_public
  @seven_eleven_product_pages_are_public
end

#seven_eleven_provided_info_matches_sctlObject

Confirmation that site info matches the Specified Commercial Transaction Law disclosure page.



117
118
119
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 117

def seven_eleven_provided_info_matches_sctl
  @seven_eleven_provided_info_matches_sctl
end

#seven_eleven_sctl_page_has_phone_numberObject

Confirmation that the SCTL page includes a phone number.



120
121
122
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 120

def seven_eleven_sctl_page_has_phone_number
  @seven_eleven_sctl_page_has_phone_number
end

#seven_eleven_site_is_publicObject

Whether the merchant’s website is publicly accessible.



90
91
92
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 90

def seven_eleven_site_is_public
  @seven_eleven_site_is_public
end

#shared_payment_method_data_close_timeObject

Business closing time for this merchant’s store.



24
25
26
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 24

def shared_payment_method_data_close_time
  @shared_payment_method_data_close_time
end

#shared_payment_method_data_conducts_business_opportunity_schemeObject

Whether the merchant offers business opportunity schemes.



54
55
56
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 54

def shared_payment_method_data_conducts_business_opportunity_scheme
  @shared_payment_method_data_conducts_business_opportunity_scheme
end

#shared_payment_method_data_conducts_door_to_door_salesObject

Whether the merchant conducts door-to-door sales.



45
46
47
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 45

def shared_payment_method_data_conducts_door_to_door_sales
  @shared_payment_method_data_conducts_door_to_door_sales
end

#shared_payment_method_data_conducts_mlm_schemeObject

Whether the merchant operates a multi-level marketing scheme.



51
52
53
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 51

def shared_payment_method_data_conducts_mlm_scheme
  @shared_payment_method_data_conducts_mlm_scheme
end

#shared_payment_method_data_conducts_telemarketingObject

Whether the merchant conducts telemarketing activities.



48
49
50
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 48

def shared_payment_method_data_conducts_telemarketing
  @shared_payment_method_data_conducts_telemarketing
end

#shared_payment_method_data_has_processed_cc_beforeObject

Whether the merchant has previously processed credit card payments.



39
40
41
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 39

def shared_payment_method_data_has_processed_cc_before
  @shared_payment_method_data_has_processed_cc_before
end

#shared_payment_method_data_open_timeObject

Business opening time for this merchant’s store.



21
22
23
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 21

def shared_payment_method_data_open_time
  @shared_payment_method_data_open_time
end

#shared_payment_method_data_pci_compliance_proofsObject

File IDs of uploaded PCI compliance proof documents.



33
34
35
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 33

def shared_payment_method_data_pci_compliance_proofs
  @shared_payment_method_data_pci_compliance_proofs
end

#shared_payment_method_data_privacy_policy_urlObject

URL to the merchant’s privacy policy page.



27
28
29
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 27

def shared_payment_method_data_privacy_policy_url
  @shared_payment_method_data_privacy_policy_url
end

#shared_payment_method_data_processes_card_infoObject

Whether the merchant directly handles or stores card information.



42
43
44
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 42

def shared_payment_method_data_processes_card_info
  @shared_payment_method_data_processes_card_info
end

#shared_payment_method_data_provides_specified_continuous_servicesObject

Whether the merchant provides services subject to the Specified Commercial Transaction Act.



57
58
59
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 57

def shared_payment_method_data_provides_specified_continuous_services
  @shared_payment_method_data_provides_specified_continuous_services
end

#shared_payment_method_data_shareholder_registersObject

File IDs of uploaded shareholder register documents.



36
37
38
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 36

def shared_payment_method_data_shareholder_registers
  @shared_payment_method_data_shareholder_registers
end

#shared_payment_method_data_terms_of_service_urlObject

URL to the merchant’s terms of service page.



30
31
32
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 30

def shared_payment_method_data_terms_of_service_url
  @shared_payment_method_data_terms_of_service_url
end

#shared_payment_method_data_violated_commercial_transaction_actObject

Whether the merchant has violated the Commercial Transaction Act.



63
64
65
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 63

def shared_payment_method_data_violated_commercial_transaction_act
  @shared_payment_method_data_violated_commercial_transaction_act
end

#shared_payment_method_data_violated_consumer_contract_actObject

Whether the merchant has violated the Consumer Contract Act.



60
61
62
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 60

def shared_payment_method_data_violated_consumer_contract_act
  @shared_payment_method_data_violated_consumer_contract_act
end

#visa_mastercard_credit_card_access_restrictionsObject

Confirmation that the site has appropriate access restrictions in place.



135
136
137
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 135

def visa_mastercard_credit_card_access_restrictions
  @visa_mastercard_credit_card_access_restrictions
end

#visa_mastercard_credit_card_account_lockObject

Confirmation that account lockout policies are in place.



141
142
143
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 141

def 
  @visa_mastercard_credit_card_account_lock
end

#visa_mastercard_credit_card_anti_virus_softwareObject

Confirmation that anti-virus software is installed and maintained.



159
160
161
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 159

def visa_mastercard_credit_card_anti_virus_software
  @visa_mastercard_credit_card_anti_virus_software
end

#visa_mastercard_credit_card_fieldsObject

Serialized form fields for the Visa/Mastercard credit card application.



162
163
164
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 162

def visa_mastercard_credit_card_fields
  @visa_mastercard_credit_card_fields
end

#visa_mastercard_credit_card_file_extension_restrictionsObject

Confirmation that file extension restrictions are enforced.



147
148
149
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 147

def visa_mastercard_credit_card_file_extension_restrictions
  @visa_mastercard_credit_card_file_extension_restrictions
end

#visa_mastercard_credit_card_mfa_implementationObject

Confirmation that multi-factor authentication is implemented.



138
139
140
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 138

def visa_mastercard_credit_card_mfa_implementation
  @visa_mastercard_credit_card_mfa_implementation
end

#visa_mastercard_credit_card_public_directoriesObject

Confirmation that public directory listing is disabled.



144
145
146
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 144

def visa_mastercard_credit_card_public_directories
  @visa_mastercard_credit_card_public_directories
end

#visa_mastercard_credit_card_source_code_reviewObject

Confirmation that source code security review is performed.



156
157
158
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 156

def visa_mastercard_credit_card_source_code_review
  @visa_mastercard_credit_card_source_code_review
end

#visa_mastercard_credit_card_sql_injection_and_xssObject

Confirmation that the site is protected against SQL injection and XSS attacks.



153
154
155
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 153

def visa_mastercard_credit_card_sql_injection_and_xss
  @visa_mastercard_credit_card_sql_injection_and_xss
end

#visa_mastercard_credit_card_vulnerability_assessmentsObject

Confirmation that regular vulnerability assessments are conducted.



150
151
152
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 150

def visa_mastercard_credit_card_vulnerability_assessments
  @visa_mastercard_credit_card_vulnerability_assessments
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 739

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



282
283
284
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 282

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 217

def self.attribute_map
  {
    :'locale' => :'locale',
    :'shared_payment_method_data_open_time' => :'shared_payment_method_data.open_time',
    :'shared_payment_method_data_close_time' => :'shared_payment_method_data.close_time',
    :'shared_payment_method_data_privacy_policy_url' => :'shared_payment_method_data.privacy_policy_url',
    :'shared_payment_method_data_terms_of_service_url' => :'shared_payment_method_data.terms_of_service_url',
    :'shared_payment_method_data_pci_compliance_proofs' => :'shared_payment_method_data.pci_compliance_proofs',
    :'shared_payment_method_data_shareholder_registers' => :'shared_payment_method_data.shareholder_registers',
    :'shared_payment_method_data_has_processed_cc_before' => :'shared_payment_method_data.has_processed_cc_before',
    :'shared_payment_method_data_processes_card_info' => :'shared_payment_method_data.processes_card_info',
    :'shared_payment_method_data_conducts_door_to_door_sales' => :'shared_payment_method_data.conducts_door_to_door_sales',
    :'shared_payment_method_data_conducts_telemarketing' => :'shared_payment_method_data.conducts_telemarketing',
    :'shared_payment_method_data_conducts_mlm_scheme' => :'shared_payment_method_data.conducts_mlm_scheme',
    :'shared_payment_method_data_conducts_business_opportunity_scheme' => :'shared_payment_method_data.conducts_business_opportunity_scheme',
    :'shared_payment_method_data_provides_specified_continuous_services' => :'shared_payment_method_data.provides_specified_continuous_services',
    :'shared_payment_method_data_violated_consumer_contract_act' => :'shared_payment_method_data.violated_consumer_contract_act',
    :'shared_payment_method_data_violated_commercial_transaction_act' => :'shared_payment_method_data.violated_commercial_transaction_act',
    :'linepay_accepted_line_tos' => :'linepay.accepted_line_tos',
    :'linepay_fields' => :'linepay.fields',
    :'paypay_accepted_paypay_tos' => :'paypay.accepted_paypay_tos',
    :'paypay_fields' => :'paypay.fields',
    :'merpay_accepted_merpay_tos' => :'merpay.accepted_merpay_tos',
    :'merpay_fields' => :'merpay.fields',
    :'convenience_store_expected_number_of_payments' => :'convenience_store.expected_number_of_payments',
    :'convenience_store_fields' => :'convenience_store.fields',
    :'seven_eleven_site_is_public' => :'seven_eleven.site_is_public',
    :'seven_eleven_no_direct_delivery_from_producer' => :'seven_eleven.no_direct_delivery_from_producer',
    :'seven_eleven_no_ticket_sales' => :'seven_eleven.no_ticket_sales',
    :'seven_eleven_correct_flow_for_order_items' => :'seven_eleven.correct_flow_for_order_items',
    :'seven_eleven_delivery_within_two_months' => :'seven_eleven.delivery_within_two_months',
    :'seven_eleven_all_items_are_cheaper_than_konbini_limit' => :'seven_eleven.all_items_are_cheaper_than_konbini_limit',
    :'seven_eleven_display_sales_permit_number' => :'seven_eleven.display_sales_permit_number',
    :'seven_eleven_order_fee_is_displayed' => :'seven_eleven.order_fee_is_displayed',
    :'seven_eleven_no_international_transaction' => :'seven_eleven.no_international_transaction',
    :'seven_eleven_provided_info_matches_sctl' => :'seven_eleven.provided_info_matches_sctl',
    :'seven_eleven_sctl_page_has_phone_number' => :'seven_eleven.sctl_page_has_phone_number',
    :'seven_eleven_product_pages_are_public' => :'seven_eleven.product_pages_are_public',
    :'seven_eleven_have_sold_as_regular_price' => :'seven_eleven.have_sold_as_regular_price',
    :'seven_eleven_note' => :'seven_eleven.note',
    :'seven_eleven_fields' => :'seven_eleven.fields',
    :'visa_mastercard_credit_card_access_restrictions' => :'visa_mastercard_credit_card.access_restrictions',
    :'visa_mastercard_credit_card_mfa_implementation' => :'visa_mastercard_credit_card.mfa_implementation',
    :'visa_mastercard_credit_card_account_lock' => :'visa_mastercard_credit_card.account_lock',
    :'visa_mastercard_credit_card_public_directories' => :'visa_mastercard_credit_card.public_directories',
    :'visa_mastercard_credit_card_file_extension_restrictions' => :'visa_mastercard_credit_card.file_extension_restrictions',
    :'visa_mastercard_credit_card_vulnerability_assessments' => :'visa_mastercard_credit_card.vulnerability_assessments',
    :'visa_mastercard_credit_card_sql_injection_and_xss' => :'visa_mastercard_credit_card.sql_injection_and_xss',
    :'visa_mastercard_credit_card_source_code_review' => :'visa_mastercard_credit_card.source_code_review',
    :'visa_mastercard_credit_card_anti_virus_software' => :'visa_mastercard_credit_card.anti_virus_software',
    :'visa_mastercard_credit_card_fields' => :'visa_mastercard_credit_card.fields',
    :'jcb_amex_diners_credit_card_access_restrictions' => :'jcb_amex_diners_credit_card.access_restrictions',
    :'jcb_amex_diners_credit_card_mfa_implementation' => :'jcb_amex_diners_credit_card.mfa_implementation',
    :'jcb_amex_diners_credit_card_account_lock' => :'jcb_amex_diners_credit_card.account_lock',
    :'jcb_amex_diners_credit_card_public_directories' => :'jcb_amex_diners_credit_card.public_directories',
    :'jcb_amex_diners_credit_card_file_extension_restrictions' => :'jcb_amex_diners_credit_card.file_extension_restrictions',
    :'jcb_amex_diners_credit_card_vulnerability_assessments' => :'jcb_amex_diners_credit_card.vulnerability_assessments',
    :'jcb_amex_diners_credit_card_sql_injection_and_xss' => :'jcb_amex_diners_credit_card.sql_injection_and_xss',
    :'jcb_amex_diners_credit_card_source_code_review' => :'jcb_amex_diners_credit_card.source_code_review',
    :'jcb_amex_diners_credit_card_anti_virus_software' => :'jcb_amex_diners_credit_card.anti_virus_software',
    :'jcb_amex_diners_credit_card_fields' => :'jcb_amex_diners_credit_card.fields'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 709

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



352
353
354
355
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 352

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 287

def self.openapi_types
  {
    :'locale' => :'Locale',
    :'shared_payment_method_data_open_time' => :'String',
    :'shared_payment_method_data_close_time' => :'String',
    :'shared_payment_method_data_privacy_policy_url' => :'String',
    :'shared_payment_method_data_terms_of_service_url' => :'String',
    :'shared_payment_method_data_pci_compliance_proofs' => :'Array<String>',
    :'shared_payment_method_data_shareholder_registers' => :'Array<String>',
    :'shared_payment_method_data_has_processed_cc_before' => :'Boolean',
    :'shared_payment_method_data_processes_card_info' => :'Boolean',
    :'shared_payment_method_data_conducts_door_to_door_sales' => :'Boolean',
    :'shared_payment_method_data_conducts_telemarketing' => :'Boolean',
    :'shared_payment_method_data_conducts_mlm_scheme' => :'Boolean',
    :'shared_payment_method_data_conducts_business_opportunity_scheme' => :'Boolean',
    :'shared_payment_method_data_provides_specified_continuous_services' => :'Boolean',
    :'shared_payment_method_data_violated_consumer_contract_act' => :'Boolean',
    :'shared_payment_method_data_violated_commercial_transaction_act' => :'Boolean',
    :'linepay_accepted_line_tos' => :'Boolean',
    :'linepay_fields' => :'String',
    :'paypay_accepted_paypay_tos' => :'Boolean',
    :'paypay_fields' => :'String',
    :'merpay_accepted_merpay_tos' => :'Boolean',
    :'merpay_fields' => :'String',
    :'convenience_store_expected_number_of_payments' => :'Integer',
    :'convenience_store_fields' => :'String',
    :'seven_eleven_site_is_public' => :'Boolean',
    :'seven_eleven_no_direct_delivery_from_producer' => :'Boolean',
    :'seven_eleven_no_ticket_sales' => :'Boolean',
    :'seven_eleven_correct_flow_for_order_items' => :'Boolean',
    :'seven_eleven_delivery_within_two_months' => :'Boolean',
    :'seven_eleven_all_items_are_cheaper_than_konbini_limit' => :'Boolean',
    :'seven_eleven_display_sales_permit_number' => :'Boolean',
    :'seven_eleven_order_fee_is_displayed' => :'Boolean',
    :'seven_eleven_no_international_transaction' => :'Boolean',
    :'seven_eleven_provided_info_matches_sctl' => :'Boolean',
    :'seven_eleven_sctl_page_has_phone_number' => :'Boolean',
    :'seven_eleven_product_pages_are_public' => :'Boolean',
    :'seven_eleven_have_sold_as_regular_price' => :'Boolean',
    :'seven_eleven_note' => :'String',
    :'seven_eleven_fields' => :'String',
    :'visa_mastercard_credit_card_access_restrictions' => :'Boolean',
    :'visa_mastercard_credit_card_mfa_implementation' => :'Boolean',
    :'visa_mastercard_credit_card_account_lock' => :'Boolean',
    :'visa_mastercard_credit_card_public_directories' => :'Boolean',
    :'visa_mastercard_credit_card_file_extension_restrictions' => :'Boolean',
    :'visa_mastercard_credit_card_vulnerability_assessments' => :'Boolean',
    :'visa_mastercard_credit_card_sql_injection_and_xss' => :'Boolean',
    :'visa_mastercard_credit_card_source_code_review' => :'Boolean',
    :'visa_mastercard_credit_card_anti_virus_software' => :'Boolean',
    :'visa_mastercard_credit_card_fields' => :'String',
    :'jcb_amex_diners_credit_card_access_restrictions' => :'Boolean',
    :'jcb_amex_diners_credit_card_mfa_implementation' => :'Boolean',
    :'jcb_amex_diners_credit_card_account_lock' => :'Boolean',
    :'jcb_amex_diners_credit_card_public_directories' => :'Boolean',
    :'jcb_amex_diners_credit_card_file_extension_restrictions' => :'Boolean',
    :'jcb_amex_diners_credit_card_vulnerability_assessments' => :'Boolean',
    :'jcb_amex_diners_credit_card_sql_injection_and_xss' => :'Boolean',
    :'jcb_amex_diners_credit_card_source_code_review' => :'Boolean',
    :'jcb_amex_diners_credit_card_anti_virus_software' => :'Boolean',
    :'jcb_amex_diners_credit_card_fields' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 630

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      locale == o.locale &&
      shared_payment_method_data_open_time == o.shared_payment_method_data_open_time &&
      shared_payment_method_data_close_time == o.shared_payment_method_data_close_time &&
      shared_payment_method_data_privacy_policy_url == o.shared_payment_method_data_privacy_policy_url &&
      shared_payment_method_data_terms_of_service_url == o.shared_payment_method_data_terms_of_service_url &&
      shared_payment_method_data_pci_compliance_proofs == o.shared_payment_method_data_pci_compliance_proofs &&
      shared_payment_method_data_shareholder_registers == o.shared_payment_method_data_shareholder_registers &&
      shared_payment_method_data_has_processed_cc_before == o.shared_payment_method_data_has_processed_cc_before &&
      shared_payment_method_data_processes_card_info == o.shared_payment_method_data_processes_card_info &&
      shared_payment_method_data_conducts_door_to_door_sales == o.shared_payment_method_data_conducts_door_to_door_sales &&
      shared_payment_method_data_conducts_telemarketing == o.shared_payment_method_data_conducts_telemarketing &&
      shared_payment_method_data_conducts_mlm_scheme == o.shared_payment_method_data_conducts_mlm_scheme &&
      shared_payment_method_data_conducts_business_opportunity_scheme == o.shared_payment_method_data_conducts_business_opportunity_scheme &&
      shared_payment_method_data_provides_specified_continuous_services == o.shared_payment_method_data_provides_specified_continuous_services &&
      shared_payment_method_data_violated_consumer_contract_act == o.shared_payment_method_data_violated_consumer_contract_act &&
      shared_payment_method_data_violated_commercial_transaction_act == o.shared_payment_method_data_violated_commercial_transaction_act &&
      linepay_accepted_line_tos == o.linepay_accepted_line_tos &&
      linepay_fields == o.linepay_fields &&
      paypay_accepted_paypay_tos == o.paypay_accepted_paypay_tos &&
      paypay_fields == o.paypay_fields &&
      merpay_accepted_merpay_tos == o.merpay_accepted_merpay_tos &&
      merpay_fields == o.merpay_fields &&
      convenience_store_expected_number_of_payments == o.convenience_store_expected_number_of_payments &&
      convenience_store_fields == o.convenience_store_fields &&
      seven_eleven_site_is_public == o.seven_eleven_site_is_public &&
      seven_eleven_no_direct_delivery_from_producer == o.seven_eleven_no_direct_delivery_from_producer &&
      seven_eleven_no_ticket_sales == o.seven_eleven_no_ticket_sales &&
      seven_eleven_correct_flow_for_order_items == o.seven_eleven_correct_flow_for_order_items &&
      seven_eleven_delivery_within_two_months == o.seven_eleven_delivery_within_two_months &&
      seven_eleven_all_items_are_cheaper_than_konbini_limit == o.seven_eleven_all_items_are_cheaper_than_konbini_limit &&
      seven_eleven_display_sales_permit_number == o.seven_eleven_display_sales_permit_number &&
      seven_eleven_order_fee_is_displayed == o.seven_eleven_order_fee_is_displayed &&
      seven_eleven_no_international_transaction == o.seven_eleven_no_international_transaction &&
      seven_eleven_provided_info_matches_sctl == o.seven_eleven_provided_info_matches_sctl &&
      seven_eleven_sctl_page_has_phone_number == o.seven_eleven_sctl_page_has_phone_number &&
      seven_eleven_product_pages_are_public == o.seven_eleven_product_pages_are_public &&
      seven_eleven_have_sold_as_regular_price == o.seven_eleven_have_sold_as_regular_price &&
      seven_eleven_note == o.seven_eleven_note &&
      seven_eleven_fields == o.seven_eleven_fields &&
      visa_mastercard_credit_card_access_restrictions == o.visa_mastercard_credit_card_access_restrictions &&
      visa_mastercard_credit_card_mfa_implementation == o.visa_mastercard_credit_card_mfa_implementation &&
       == o. &&
      visa_mastercard_credit_card_public_directories == o.visa_mastercard_credit_card_public_directories &&
      visa_mastercard_credit_card_file_extension_restrictions == o.visa_mastercard_credit_card_file_extension_restrictions &&
      visa_mastercard_credit_card_vulnerability_assessments == o.visa_mastercard_credit_card_vulnerability_assessments &&
      visa_mastercard_credit_card_sql_injection_and_xss == o.visa_mastercard_credit_card_sql_injection_and_xss &&
      visa_mastercard_credit_card_source_code_review == o.visa_mastercard_credit_card_source_code_review &&
      visa_mastercard_credit_card_anti_virus_software == o.visa_mastercard_credit_card_anti_virus_software &&
      visa_mastercard_credit_card_fields == o.visa_mastercard_credit_card_fields &&
      jcb_amex_diners_credit_card_access_restrictions == o.jcb_amex_diners_credit_card_access_restrictions &&
      jcb_amex_diners_credit_card_mfa_implementation == o.jcb_amex_diners_credit_card_mfa_implementation &&
       == o. &&
      jcb_amex_diners_credit_card_public_directories == o.jcb_amex_diners_credit_card_public_directories &&
      jcb_amex_diners_credit_card_file_extension_restrictions == o.jcb_amex_diners_credit_card_file_extension_restrictions &&
      jcb_amex_diners_credit_card_vulnerability_assessments == o.jcb_amex_diners_credit_card_vulnerability_assessments &&
      jcb_amex_diners_credit_card_sql_injection_and_xss == o.jcb_amex_diners_credit_card_sql_injection_and_xss &&
      jcb_amex_diners_credit_card_source_code_review == o.jcb_amex_diners_credit_card_source_code_review &&
      jcb_amex_diners_credit_card_anti_virus_software == o.jcb_amex_diners_credit_card_anti_virus_software &&
      jcb_amex_diners_credit_card_fields == o.jcb_amex_diners_credit_card_fields
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



810
811
812
813
814
815
816
817
818
819
820
821
822
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 810

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


696
697
698
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 696

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



702
703
704
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 702

def hash
  [locale, shared_payment_method_data_open_time, shared_payment_method_data_close_time, shared_payment_method_data_privacy_policy_url, shared_payment_method_data_terms_of_service_url, shared_payment_method_data_pci_compliance_proofs, shared_payment_method_data_shareholder_registers, shared_payment_method_data_has_processed_cc_before, shared_payment_method_data_processes_card_info, shared_payment_method_data_conducts_door_to_door_sales, shared_payment_method_data_conducts_telemarketing, shared_payment_method_data_conducts_mlm_scheme, shared_payment_method_data_conducts_business_opportunity_scheme, shared_payment_method_data_provides_specified_continuous_services, shared_payment_method_data_violated_consumer_contract_act, shared_payment_method_data_violated_commercial_transaction_act, linepay_accepted_line_tos, linepay_fields, paypay_accepted_paypay_tos, paypay_fields, merpay_accepted_merpay_tos, merpay_fields, convenience_store_expected_number_of_payments, convenience_store_fields, seven_eleven_site_is_public, seven_eleven_no_direct_delivery_from_producer, seven_eleven_no_ticket_sales, seven_eleven_correct_flow_for_order_items, seven_eleven_delivery_within_two_months, seven_eleven_all_items_are_cheaper_than_konbini_limit, seven_eleven_display_sales_permit_number, seven_eleven_order_fee_is_displayed, seven_eleven_no_international_transaction, seven_eleven_provided_info_matches_sctl, seven_eleven_sctl_page_has_phone_number, seven_eleven_product_pages_are_public, seven_eleven_have_sold_as_regular_price, seven_eleven_note, seven_eleven_fields, visa_mastercard_credit_card_access_restrictions, visa_mastercard_credit_card_mfa_implementation, , visa_mastercard_credit_card_public_directories, visa_mastercard_credit_card_file_extension_restrictions, visa_mastercard_credit_card_vulnerability_assessments, visa_mastercard_credit_card_sql_injection_and_xss, visa_mastercard_credit_card_source_code_review, visa_mastercard_credit_card_anti_virus_software, visa_mastercard_credit_card_fields, jcb_amex_diners_credit_card_access_restrictions, jcb_amex_diners_credit_card_mfa_implementation, , jcb_amex_diners_credit_card_public_directories, jcb_amex_diners_credit_card_file_extension_restrictions, jcb_amex_diners_credit_card_vulnerability_assessments, jcb_amex_diners_credit_card_sql_injection_and_xss, jcb_amex_diners_credit_card_source_code_review, jcb_amex_diners_credit_card_anti_virus_software, jcb_amex_diners_credit_card_fields].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



615
616
617
618
619
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 615

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



786
787
788
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 786

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



792
793
794
795
796
797
798
799
800
801
802
803
804
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 792

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



780
781
782
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 780

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



623
624
625
626
# File 'lib/komoju-sdk/models/update_payment_method_request.rb', line 623

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end