Class: Komoju::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/configuration.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|_self| ... } ⇒ Configuration

Returns a new instance of Configuration.

Yields:

  • (_self)

Yield Parameters:



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/komoju-sdk/configuration.rb', line 165

def initialize
  @scheme = 'https'
  @host = 'komoju.com'
  @base_path = '/api/v1'
  @server_index = nil
  @server_operation_index = {}
  @server_variables = {}
  @server_operation_variables = {}
  @client_side_validation = true
  @ssl_verify = true
  @ssl_verify_mode = nil
  @ssl_ca_file = nil
  @ssl_client_cert = nil
  @ssl_client_key = nil
  @middlewares = Hash.new { |h, k| h[k] = [] }
  @configure_connection_blocks = []
  @timeout = 60
  # return data as binary instead of file
  @return_binary_data = false
  @params_encoder = nil
  @debugging = false
  @ignore_operation_servers = false
  @inject_format = false
  @force_ending_format = false
  @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)

  yield(self) if block_given?
end

Instance Attribute Details

#access_tokenObject

Defines the access token (Bearer) used with OAuth2.



69
70
71
# File 'lib/komoju-sdk/configuration.rb', line 69

def access_token
  @access_token
end

#access_token_getterProc

Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2. Overrides the access_token if set

Returns:

  • (Proc)


74
75
76
# File 'lib/komoju-sdk/configuration.rb', line 74

def access_token_getter
  @access_token_getter
end

#base_pathObject

Defines url base path



23
24
25
# File 'lib/komoju-sdk/configuration.rb', line 23

def base_path
  @base_path
end

#client_side_validationtrue, false

Set this to false to skip client side validation in the operation. Default to true.

Returns:

  • (true, false)


116
117
118
# File 'lib/komoju-sdk/configuration.rb', line 116

def client_side_validation
  @client_side_validation
end

#debuggingtrue, false

Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with ‘logger.debug` (see the `logger` attribute). Default to false.

Returns:

  • (true, false)


86
87
88
# File 'lib/komoju-sdk/configuration.rb', line 86

def debugging
  @debugging
end

#force_ending_formatObject

Returns the value of attribute force_ending_format.



163
164
165
# File 'lib/komoju-sdk/configuration.rb', line 163

def force_ending_format
  @force_ending_format
end

#hostObject

Defines url host



20
21
22
# File 'lib/komoju-sdk/configuration.rb', line 20

def host
  @host
end

#ignore_operation_serverstrue, false

Set this to ignore operation servers for the API client. This is useful when you need to send requests to a different server than the one specified in the OpenAPI document. Will default to the base url defined in the spec but can be overridden by setting ‘scheme`, `host`, `base_path` directly. Default to false.

Returns:

  • (true, false)


94
95
96
# File 'lib/komoju-sdk/configuration.rb', line 94

def ignore_operation_servers
  @ignore_operation_servers
end

#inject_formatObject

Returns the value of attribute inject_format.



161
162
163
# File 'lib/komoju-sdk/configuration.rb', line 161

def inject_format
  @inject_format
end

#logger#debug

Defines the logger used for debugging. Default to ‘Rails.logger` (when in Rails) or logging to STDOUT.

Returns:

  • (#debug)


100
101
102
# File 'lib/komoju-sdk/configuration.rb', line 100

def logger
  @logger
end

#params_encoderObject

Set this to customize parameters encoder of array parameter. Default to nil. Faraday uses NestedParamsEncoder when nil.

github.com/lostisland/faraday/tree/main/lib/faraday/encoders

See Also:

  • params_encoder option of Faraday. Related source code:


157
158
159
# File 'lib/komoju-sdk/configuration.rb', line 157

def params_encoder
  @params_encoder
end

#passwordObject



43
44
45
# File 'lib/komoju-sdk/configuration.rb', line 43

def password
  @password ||= ''
end

#proxyObject

Proxy setting HTTP Proxy settings



150
151
152
# File 'lib/komoju-sdk/configuration.rb', line 150

def proxy
  @proxy
end

#return_binary_dataObject

Set this to return data as binary instead of downloading a temp file. When enabled (set to true) HTTP responses with return type ‘File` will be returned as a stream of binary data. Default to false.



79
80
81
# File 'lib/komoju-sdk/configuration.rb', line 79

def return_binary_data
  @return_binary_data
end

#schemeObject

Defines url scheme



17
18
19
# File 'lib/komoju-sdk/configuration.rb', line 17

def scheme
  @scheme
end

#server_indexObject

Define server configuration index



26
27
28
# File 'lib/komoju-sdk/configuration.rb', line 26

def server_index
  @server_index
end

#server_operation_indexObject

Define server operation configuration index



29
30
31
# File 'lib/komoju-sdk/configuration.rb', line 29

def server_operation_index
  @server_operation_index
end

#server_operation_variablesObject

Default server operation variables



35
36
37
# File 'lib/komoju-sdk/configuration.rb', line 35

def server_operation_variables
  @server_operation_variables
end

#server_variablesObject

Default server variables



32
33
34
# File 'lib/komoju-sdk/configuration.rb', line 32

def server_variables
  @server_variables
end

#ssl_ca_fileString

TLS/SSL setting Set this to customize the certificate file to verify the peer.

Returns:

  • (String)

    the path to the certificate file



138
139
140
# File 'lib/komoju-sdk/configuration.rb', line 138

def ssl_ca_file
  @ssl_ca_file
end

#ssl_client_certObject

TLS/SSL setting Client certificate file (for client certificate)



142
143
144
# File 'lib/komoju-sdk/configuration.rb', line 142

def ssl_client_cert
  @ssl_client_cert
end

#ssl_client_keyObject

TLS/SSL setting Client private key file (for client certificate)



146
147
148
# File 'lib/komoju-sdk/configuration.rb', line 146

def ssl_client_key
  @ssl_client_key
end

#ssl_verifytrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.

Returns:

  • (true, false)


125
126
127
# File 'lib/komoju-sdk/configuration.rb', line 125

def ssl_verify
  @ssl_verify
end

#ssl_verify_modeObject

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Any ‘OpenSSL::SSL::` constant (see ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)



132
133
134
# File 'lib/komoju-sdk/configuration.rb', line 132

def ssl_verify_mode
  @ssl_verify_mode
end

#temp_folder_pathString

Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use ‘Tempfile`.

Returns:

  • (String)


107
108
109
# File 'lib/komoju-sdk/configuration.rb', line 107

def temp_folder_path
  @temp_folder_path
end

#timeoutObject

The time limit for HTTP request in seconds. Default to 0 (never times out).



111
112
113
# File 'lib/komoju-sdk/configuration.rb', line 111

def timeout
  @timeout
end

#usernameObject (readonly)

Internal username used for HTTP Basic Auth. Use api_key= to set this.



66
67
68
# File 'lib/komoju-sdk/configuration.rb', line 66

def username
  @username
end

Class Method Details

.defaultObject

The default Configuration object.



195
196
197
# File 'lib/komoju-sdk/configuration.rb', line 195

def self.default
  @@default ||= Configuration.new
end

Instance Method Details

#access_token_with_refreshObject

Gets access_token using access_token_getter or uses the static access_token



255
256
257
258
# File 'lib/komoju-sdk/configuration.rb', line 255

def access_token_with_refresh
  return access_token if access_token_getter.nil?
  access_token_getter.call
end

#api_keyString

Gets the KOMOJU API key.

Returns:

  • (String)


60
61
62
# File 'lib/komoju-sdk/configuration.rb', line 60

def api_key
  @username
end

#api_key=(key) ⇒ String

Sets the KOMOJU API key. KOMOJU uses HTTP Basic Auth with the API key as username and empty password.

Examples:

config.api_key = 'your_api_key_here'

Returns:

  • (String)


53
54
55
# File 'lib/komoju-sdk/configuration.rb', line 53

def api_key=(key)
  @username = key
end

#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object

Gets API key (with prefix if set).

Parameters:

  • param_name (String)

    the parameter name of API key auth



244
245
246
247
248
249
250
251
252
# File 'lib/komoju-sdk/configuration.rb', line 244

def api_key_with_prefix(param_name, param_alias = nil)
  key = @api_key[param_name]
  key = @api_key.fetch(param_alias, key) unless param_alias.nil?
  if @api_key_prefix[param_name]
    "#{@api_key_prefix[param_name]} #{key}"
  else
    key
  end
end

#auth_settingsObject

Returns Auth Settings hash for api client.



266
267
268
269
270
271
272
273
274
275
276
# File 'lib/komoju-sdk/configuration.rb', line 266

def auth_settings
  {
    'api_key' =>
      {
        type: 'basic',
        in: 'header',
        key: 'Authorization',
        value: basic_auth_token
      },
  }
end

#base_url(operation = nil) ⇒ Object

Returns base URL for specified operation based on server settings



232
233
234
235
236
237
238
239
240
# File 'lib/komoju-sdk/configuration.rb', line 232

def base_url(operation = nil)
  return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if ignore_operation_servers
  if operation_server_settings.key?(operation) then
    index = server_operation_index.fetch(operation, server_index)
    server_url(index.nil? ? 0 : index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation])
  else
    server_index.nil? ? "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') : server_url(server_index, server_variables, nil)
  end
end

#base_url=(url) ⇒ Object

Sets scheme, host, and base_path from a full URL string.

Examples:

config.base_url = 'https://sandbox.komoju.com/api/v1'

Parameters:



224
225
226
227
228
229
# File 'lib/komoju-sdk/configuration.rb', line 224

def base_url=(url)
  uri = URI.parse(url)
  self.scheme = uri.scheme
  self.host   = uri.host
  self.base_path = uri.path
end

#basic_auth_tokenObject

Gets Basic Auth token string



261
262
263
# File 'lib/komoju-sdk/configuration.rb', line 261

def basic_auth_token
  'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n")
end

#configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:



199
200
201
# File 'lib/komoju-sdk/configuration.rb', line 199

def configure
  yield(self) if block_given?
end

#configure_connection(conn) ⇒ Object



347
348
349
350
351
# File 'lib/komoju-sdk/configuration.rb', line 347

def configure_connection(conn)
  @configure_connection_blocks.each do |block|
    block.call(conn)
  end
end

#configure_faraday_connection(&block) ⇒ Object

Configure Faraday connection directly.

“‘ c.configure_faraday_connection do |conn|

conn.use Faraday::HttpCache, shared_cache: false, logger: logger
conn.response :logger, nil, headers: true, bodies: true, log_level: :debug do |logger|
  logger.filter(/(Authorization: )(.*)/, '\1[REDACTED]')
end

end

c.configure_faraday_connection do |conn|

conn.adapter :typhoeus

end “‘

Parameters:

  • block (Proc)

    ‘#call`able object that takes one arg, the connection



343
344
345
# File 'lib/komoju-sdk/configuration.rb', line 343

def configure_faraday_connection(&block)
  @configure_connection_blocks << block
end

#configure_middleware(connection) ⇒ Object

Set up middleware on the connection



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/komoju-sdk/configuration.rb', line 390

def configure_middleware(connection)
  return if @middlewares.empty?

  [:request, :response, :use, :insert, :insert_before, :insert_after, :swap].each do |operation|
    next unless @middlewares.key?(operation)

    @middlewares[operation].each do |key, args, block|
      connection.builder.send(operation, key, *args, &block)
    end
  end

  if @middlewares.key?(:delete)
    @middlewares[:delete].each do |key, _args, _block|
      connection.builder.delete(key)
    end
  end
end

#operation_server_settingsObject



288
289
290
291
# File 'lib/komoju-sdk/configuration.rb', line 288

def operation_server_settings
  {
  }
end

#request(*middleware) ⇒ Object

Adds request middleware to the stack



359
360
361
# File 'lib/komoju-sdk/configuration.rb', line 359

def request(*middleware)
  set_faraday_middleware(:request, *middleware)
end

#response(*middleware) ⇒ Object

Adds response middleware to the stack



364
365
366
# File 'lib/komoju-sdk/configuration.rb', line 364

def response(*middleware)
  set_faraday_middleware(:response, *middleware)
end

#server_settingsObject

Returns an array of Server setting



279
280
281
282
283
284
285
286
# File 'lib/komoju-sdk/configuration.rb', line 279

def server_settings
  [
    {
      url: "https://komoju.com/api/v1",
      description: "No description provided",
    }
  ]
end

#server_url(index, variables = {}, servers = nil) ⇒ Object

Returns URL based on server settings

Parameters:

  • index

    array index of the server settings

  • variables (defaults to: {})

    hash of variable and the corresponding value



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/komoju-sdk/configuration.rb', line 297

def server_url(index, variables = {}, servers = nil)
  servers = server_settings if servers == nil

  # check array index out of bound
  if (index.nil? || index < 0 || index >= servers.size)
    fail ArgumentError, "Invalid index #{index} when selecting the server. Must not be nil and must be less than #{servers.size}"
  end

  server = servers[index]
  url = server[:url]

  return url unless server.key? :variables

  # go through variable and assign a value
  server[:variables].each do |name, variable|
    if variables.key?(name)
      if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name]))
        url.gsub! "{" + name.to_s + "}", variables[name]
      else
        fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}."
      end
    else
      # use default value
      url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value]
    end
  end

  url
end

#set_faraday_middleware(operation, key, *args, &block) ⇒ Object

Adds Faraday middleware setting information to the stack

Examples:

Use the ‘set_faraday_middleware` method to set middleware information

config.set_faraday_middleware(:request, :retry, max: 3, methods: [:get, :post], retry_statuses: [503])
config.set_faraday_middleware(:response, :logger, nil, { bodies: true, log_level: :debug })
config.set_faraday_middleware(:use, Faraday::HttpCache, store: Rails.cache, shared_cache: false)
config.set_faraday_middleware(:insert, 0, FaradayMiddleware::FollowRedirects, { standards_compliant: true, limit: 1 })
config.set_faraday_middleware(:swap, 0, Faraday::Response::Logger)
config.set_faraday_middleware(:delete, Faraday::Multipart::Middleware)

See Also:



379
380
381
382
383
384
385
386
# File 'lib/komoju-sdk/configuration.rb', line 379

def set_faraday_middleware(operation, key, *args, &block)
  unless [:request, :response, :use, :insert, :insert_before, :insert_after, :swap, :delete].include?(operation)
    fail ArgumentError, "Invalid faraday middleware operation #{operation}. Must be" \
                        " :request, :response, :use, :insert, :insert_before, :insert_after, :swap or :delete."
  end

  @middlewares[operation] << [key, args, block]
end

#use(*middleware) ⇒ Object

Adds middleware to the stack



354
355
356
# File 'lib/komoju-sdk/configuration.rb', line 354

def use(*middleware)
  set_faraday_middleware(:use, *middleware)
end