Class: Komoju::Disbursement
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Komoju::Disbursement
- Defined in:
- lib/komoju-sdk/models/disbursement.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_name_kana ⇒ Object
Name of the recipient bank account holder in katakana.
-
#account_number ⇒ Object
Recipient's bank account number.
-
#account_type ⇒ Object
Type of the recipient's bank account.
-
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#bank_code ⇒ Object
4-digit Zengin bank code of the recipient's bank.
-
#branch_code ⇒ Object
3-digit Zengin branch code.
-
#created_at ⇒ Object
Timestamp when the disbursement was created.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#error ⇒ Object
Error message if the disbursement failed, otherwise null.
-
#external_id ⇒ Object
Merchant-assigned external reference ID for this disbursement.
-
#fee ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#fee_tax ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
-
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
-
#last_updated_at ⇒ Object
Timestamp when the disbursement record was last updated.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Disbursement
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Disbursement
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 143 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::Disbursement` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::Disbursement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'amount') self.amount = attributes[:'amount'] else self.amount = nil end if attributes.key?(:'fee') self.fee = attributes[:'fee'] else self.fee = nil end if attributes.key?(:'fee_tax') self.fee_tax = attributes[:'fee_tax'] else self.fee_tax = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'bank_code') self.bank_code = attributes[:'bank_code'] else self.bank_code = nil end if attributes.key?(:'branch_code') self.branch_code = attributes[:'branch_code'] else self.branch_code = nil end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] else self.account_type = nil end if attributes.key?(:'account_number') self.account_number = attributes[:'account_number'] else self.account_number = nil end if attributes.key?(:'account_name_kana') self.account_name_kana = attributes[:'account_name_kana'] else self.account_name_kana = nil end if attributes.key?(:'error') self.error = attributes[:'error'] else self.error = nil end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] else self.external_id = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'last_updated_at') self.last_updated_at = attributes[:'last_updated_at'] else self.last_updated_at = nil end end |
Instance Attribute Details
#account_name_kana ⇒ Object
Name of the recipient bank account holder in katakana.
47 48 49 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 47 def account_name_kana @account_name_kana end |
#account_number ⇒ Object
Recipient's bank account number.
44 45 46 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 44 def account_number @account_number end |
#account_type ⇒ Object
Type of the recipient's bank account.
41 42 43 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 41 def account_type @account_type end |
#amount ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
24 25 26 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 24 def amount @amount end |
#bank_code ⇒ Object
4-digit Zengin bank code of the recipient's bank.
35 36 37 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 35 def bank_code @bank_code end |
#branch_code ⇒ Object
3-digit Zengin branch code.
38 39 40 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 38 def branch_code @branch_code end |
#created_at ⇒ Object
Timestamp when the disbursement was created.
56 57 58 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 56 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
21 22 23 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 21 def currency @currency end |
#error ⇒ Object
Error message if the disbursement failed, otherwise null.
50 51 52 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 50 def error @error end |
#external_id ⇒ Object
Merchant-assigned external reference ID for this disbursement.
53 54 55 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 53 def external_id @external_id end |
#fee ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
27 28 29 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 27 def fee @fee end |
#fee_tax ⇒ Object
Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).
30 31 32 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 30 def fee_tax @fee_tax end |
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
19 20 21 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 19 def id @id end |
#last_updated_at ⇒ Object
Timestamp when the disbursement record was last updated.
59 60 61 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 59 def last_updated_at @last_updated_at end |
#status ⇒ Object
Returns the value of attribute status.
32 33 34 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 32 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 600 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
105 106 107 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 105 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
110 111 112 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 110 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 84 def self.attribute_map { :'id' => :'id', :'currency' => :'currency', :'amount' => :'amount', :'fee' => :'fee', :'fee_tax' => :'fee_tax', :'status' => :'status', :'bank_code' => :'bank_code', :'branch_code' => :'branch_code', :'account_type' => :'account_type', :'account_number' => :'account_number', :'account_name_kana' => :'account_name_kana', :'error' => :'error', :'external_id' => :'external_id', :'created_at' => :'created_at', :'last_updated_at' => :'last_updated_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 570 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
136 137 138 139 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 136 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 115 def self.openapi_types { :'id' => :'String', :'currency' => :'Currency', :'amount' => :'Integer', :'fee' => :'Integer', :'fee_tax' => :'Integer', :'status' => :'DisbursementStatus', :'bank_code' => :'String', :'branch_code' => :'String', :'account_type' => :'String', :'account_number' => :'String', :'account_name_kana' => :'String', :'error' => :'String', :'external_id' => :'String', :'created_at' => :'Time', :'last_updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 535 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && currency == o.currency && amount == o.amount && fee == o.fee && fee_tax == o.fee_tax && status == o.status && bank_code == o.bank_code && branch_code == o.branch_code && account_type == o.account_type && account_number == o.account_number && account_name_kana == o.account_name_kana && error == o.error && external_id == o.external_id && created_at == o.created_at && last_updated_at == o.last_updated_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
671 672 673 674 675 676 677 678 679 680 681 682 683 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 671 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
557 558 559 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 557 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
563 564 565 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 563 def hash [id, currency, amount, fee, fee_tax, status, bank_code, branch_code, account_type, account_number, account_name_kana, error, external_id, created_at, last_updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 250 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length > 25 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.') end if @id.to_s.length < 25 invalid_properties.push('invalid value for "id", the character length must be greater than or equal to 25.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @amount < 0 invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.') end if @fee.nil? invalid_properties.push('invalid value for "fee", fee cannot be nil.') end if @fee < 0 invalid_properties.push('invalid value for "fee", must be greater than or equal to 0.') end if @fee_tax.nil? invalid_properties.push('invalid value for "fee_tax", fee_tax cannot be nil.') end if @fee_tax < 0 invalid_properties.push('invalid value for "fee_tax", must be greater than or equal to 0.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @bank_code.nil? invalid_properties.push('invalid value for "bank_code", bank_code cannot be nil.') end if @branch_code.nil? invalid_properties.push('invalid value for "branch_code", branch_code cannot be nil.') end if @account_type.nil? invalid_properties.push('invalid value for "account_type", account_type cannot be nil.') end if @account_number.nil? invalid_properties.push('invalid value for "account_number", account_number cannot be nil.') end if @account_name_kana.nil? invalid_properties.push('invalid value for "account_name_kana", account_name_kana cannot be nil.') end if @error.nil? invalid_properties.push('invalid value for "error", error cannot be nil.') end if @external_id.nil? invalid_properties.push('invalid value for "external_id", external_id cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @last_updated_at.nil? invalid_properties.push('invalid value for "last_updated_at", last_updated_at cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
647 648 649 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 647 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
653 654 655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 653 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
641 642 643 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 641 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/komoju-sdk/models/disbursement.rb', line 338 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id.to_s.length > 25 return false if @id.to_s.length < 25 return false if @currency.nil? return false if @amount.nil? return false if @amount < 0 return false if @fee.nil? return false if @fee < 0 return false if @fee_tax.nil? return false if @fee_tax < 0 return false if @status.nil? return false if @bank_code.nil? return false if @branch_code.nil? return false if @account_type.nil? return false if @account_number.nil? return false if @account_name_kana.nil? return false if @error.nil? return false if @external_id.nil? return false if @created_at.nil? return false if @last_updated_at.nil? true end |