Class: Komoju::EventsApi
- Inherits:
-
Object
- Object
- Komoju::EventsApi
- Defined in:
- lib/komoju-sdk/api/events_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ EventsApi
constructor
A new instance of EventsApi.
-
#list_events(opts = {}) ⇒ EventList
Event: List Lists out past webhook events from most-recent to least-recent.
-
#list_events_with_http_info(opts = {}) ⇒ Array<(EventList, Integer, Hash)>
Event: List Lists out past webhook events from most-recent to least-recent.
-
#show_event(id, opts = {}) ⇒ Event
Event Show View an event given an ‘id`.
-
#show_event_with_http_info(id, opts = {}) ⇒ Array<(Event, Integer, Hash)>
Event Show View an event given an `id`.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/komoju-sdk/api/events_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_events(opts = {}) ⇒ EventList
Event: List Lists out past webhook events from most-recent to least-recent.
30 31 32 33 |
# File 'lib/komoju-sdk/api/events_api.rb', line 30 def list_events(opts = {}) data, _status_code, _headers = list_events_with_http_info(opts) data end |
#list_events_with_http_info(opts = {}) ⇒ Array<(EventList, Integer, Hash)>
Event: List Lists out past webhook events from most-recent to least-recent.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/komoju-sdk/api/events_api.rb', line 43 def list_events_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.list_events ...' end # resource path local_var_path = '/events' # query parameters query_params = opts[:query_params] || {} query_params[:'start_time'] = opts[:'start_time'] if !opts[:'start_time'].nil? query_params[:'end_time'] = opts[:'end_time'] if !opts[:'end_time'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventList' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"EventsApi.list_events", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#list_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_event(id, opts = {}) ⇒ Event
Event Show View an event given an ‘id`. Event `id`s can be saved from a webhook or found by querying all events.
96 97 98 99 |
# File 'lib/komoju-sdk/api/events_api.rb', line 96 def show_event(id, opts = {}) data, _status_code, _headers = show_event_with_http_info(id, opts) data end |
#show_event_with_http_info(id, opts = {}) ⇒ Array<(Event, Integer, Hash)>
Event Show View an event given an `id`. Event `id`s can be saved from a webhook or found by querying all events.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/komoju-sdk/api/events_api.rb', line 106 def show_event_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsApi.show_event ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EventsApi.show_event" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling EventsApi.show_event, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling EventsApi.show_event, the character length must be great than or equal to 25.' end # resource path local_var_path = '/events/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Event' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"EventsApi.show_event", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsApi#show_event\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |