Class: Komoju::OneClickApi
- Inherits:
-
Object
- Object
- Komoju::OneClickApi
- Defined in:
- lib/komoju-sdk/api/one_click_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_external_customer(id, opts = {}) ⇒ DeleteExternalCustomerResponse
External Customer: Destroy Deletes the external customer created by the Hosted Page One-Click feature with the given ‘id`.
-
#delete_external_customer_with_http_info(id, opts = {}) ⇒ Array<(DeleteExternalCustomerResponse, Integer, Hash)>
External Customer: Destroy Deletes the external customer created by the Hosted Page One-Click feature with the given `id`.
-
#initialize(api_client = ApiClient.default) ⇒ OneClickApi
constructor
A new instance of OneClickApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ OneClickApi
Returns a new instance of OneClickApi.
19 20 21 |
# File 'lib/komoju-sdk/api/one_click_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/komoju-sdk/api/one_click_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_external_customer(id, opts = {}) ⇒ DeleteExternalCustomerResponse
External Customer: Destroy Deletes the external customer created by the Hosted Page One-Click feature with the given ‘id`. This completely erases the stored payment details from our database.
27 28 29 30 |
# File 'lib/komoju-sdk/api/one_click_api.rb', line 27 def delete_external_customer(id, opts = {}) data, _status_code, _headers = delete_external_customer_with_http_info(id, opts) data end |
#delete_external_customer_with_http_info(id, opts = {}) ⇒ Array<(DeleteExternalCustomerResponse, Integer, Hash)>
External Customer: Destroy Deletes the external customer created by the Hosted Page One-Click feature with the given `id`. This completely erases the stored payment details from our database.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/komoju-sdk/api/one_click_api.rb', line 37 def delete_external_customer_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OneClickApi.delete_external_customer ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling OneClickApi.delete_external_customer" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling OneClickApi.delete_external_customer, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling OneClickApi.delete_external_customer, the character length must be great than or equal to 25.' end # resource path local_var_path = '/external_customers/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteExternalCustomerResponse' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"OneClickApi.delete_external_customer", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OneClickApi#delete_external_customer\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |