Class: Komoju::PaymentDetailsPaidy

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/payment_details_paidy.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentDetailsPaidy

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 191

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::PaymentDetailsPaidy` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::PaymentDetailsPaidy`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'customer_age')
    self.customer_age = attributes[:'customer_age']
  end

  if attributes.key?(:'customer_last_order_amount')
    self.customer_last_order_amount = attributes[:'customer_last_order_amount']
  end

  if attributes.key?(:'customer_last_order_at')
    self.customer_last_order_at = attributes[:'customer_last_order_at']
  end

  if attributes.key?(:'customer_lifetime_value')
    self.customer_lifetime_value = attributes[:'customer_lifetime_value']
  end

  if attributes.key?(:'customer_name')
    self.customer_name = attributes[:'customer_name']
  else
    self.customer_name = nil
  end

  if attributes.key?(:'customer_order_count')
    self.customer_order_count = attributes[:'customer_order_count']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'external_customer_id')
    self.external_customer_id = attributes[:'external_customer_id']
  end

  if attributes.key?(:'item_title')
    self.item_title = attributes[:'item_title']
  end

  if attributes.key?(:'customer_name_kana')
    self.customer_name_kana = attributes[:'customer_name_kana']
  end

  if attributes.key?(:'capture')
    self.capture = attributes[:'capture']
  end

  if attributes.key?(:'shipping_address_name')
    self.shipping_address_name = attributes[:'shipping_address_name']
  end

  if attributes.key?(:'shipping_address_line1')
    self.shipping_address_line1 = attributes[:'shipping_address_line1']
  end

  if attributes.key?(:'shipping_address_line2')
    self.shipping_address_line2 = attributes[:'shipping_address_line2']
  end

  if attributes.key?(:'shipping_address_city')
    self.shipping_address_city = attributes[:'shipping_address_city']
  end

  if attributes.key?(:'shipping_address_state')
    self.shipping_address_state = attributes[:'shipping_address_state']
  end

  if attributes.key?(:'shipping_address_zip')
    self.shipping_address_zip = attributes[:'shipping_address_zip']
  end

  if attributes.key?(:'shipping_address_country')
    self.shipping_address_country = attributes[:'shipping_address_country']
  end

  if attributes.key?(:'billing_address_name')
    self.billing_address_name = attributes[:'billing_address_name']
  end

  if attributes.key?(:'billing_address_line1')
    self.billing_address_line1 = attributes[:'billing_address_line1']
  end

  if attributes.key?(:'billing_address_line2')
    self.billing_address_line2 = attributes[:'billing_address_line2']
  end

  if attributes.key?(:'billing_address_city')
    self.billing_address_city = attributes[:'billing_address_city']
  end

  if attributes.key?(:'billing_address_state')
    self.billing_address_state = attributes[:'billing_address_state']
  end

  if attributes.key?(:'billing_address_zip')
    self.billing_address_zip = attributes[:'billing_address_zip']
  end

  if attributes.key?(:'billing_address_country')
    self.billing_address_country = attributes[:'billing_address_country']
  end
end

Instance Attribute Details

#billing_address_cityObject

Billing address city.



79
80
81
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 79

def billing_address_city
  @billing_address_city
end

#billing_address_countryObject

Billing address country.



88
89
90
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 88

def billing_address_country
  @billing_address_country
end

#billing_address_line1Object

Billing address line 1.



73
74
75
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 73

def billing_address_line1
  @billing_address_line1
end

#billing_address_line2Object

Billing address line 2.



76
77
78
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 76

def billing_address_line2
  @billing_address_line2
end

#billing_address_nameObject

Billing address name. This is the paying customer’s name.



70
71
72
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 70

def billing_address_name
  @billing_address_name
end

#billing_address_stateObject

Billing address state.



82
83
84
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 82

def billing_address_state
  @billing_address_state
end

#billing_address_zipObject

Billing address ZIP code.



85
86
87
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 85

def billing_address_zip
  @billing_address_zip
end

#captureObject

Returns the value of attribute capture.



46
47
48
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 46

def capture
  @capture
end

#customer_ageObject

Returns the value of attribute customer_age.



22
23
24
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 22

def customer_age
  @customer_age
end

#customer_last_order_amountObject

Returns the value of attribute customer_last_order_amount.



24
25
26
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 24

def customer_last_order_amount
  @customer_last_order_amount
end

#customer_last_order_atObject

Returns the value of attribute customer_last_order_at.



26
27
28
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 26

def customer_last_order_at
  @customer_last_order_at
end

#customer_lifetime_valueObject

Returns the value of attribute customer_lifetime_value.



28
29
30
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 28

def customer_lifetime_value
  @customer_lifetime_value
end

#customer_nameObject

Returns the value of attribute customer_name.



30
31
32
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 30

def customer_name
  @customer_name
end

#customer_name_kanaObject

Returns the value of attribute customer_name_kana.



44
45
46
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 44

def customer_name_kana
  @customer_name_kana
end

#customer_order_countObject

Returns the value of attribute customer_order_count.



32
33
34
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 32

def customer_order_count
  @customer_order_count
end

#emailObject

Customer’s email address. Will be used for fraud prevention and payment receipt.



35
36
37
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 35

def email
  @email
end

#external_customer_idObject

Returns the value of attribute external_customer_id.



40
41
42
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 40

def external_customer_id
  @external_customer_id
end

#item_titleObject

Returns the value of attribute item_title.



42
43
44
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 42

def item_title
  @item_title
end

#phoneObject

Customer’s phone number



38
39
40
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 38

def phone
  @phone
end

#shipping_address_cityObject

Shipping address city. Name of city, municipality, or village. Required for physical products.



58
59
60
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 58

def shipping_address_city
  @shipping_address_city
end

#shipping_address_countryObject

Shipping address country. Required for physical products.



67
68
69
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 67

def shipping_address_country
  @shipping_address_country
end

#shipping_address_line1Object

Shipping address line 1. For Japanese addresses: building name, apartment number. Required for physical products.



52
53
54
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 52

def shipping_address_line1
  @shipping_address_line1
end

#shipping_address_line2Object

Shipping address line 2. For Japanese addresses: district, land number, land number extension.



55
56
57
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 55

def shipping_address_line2
  @shipping_address_line2
end

#shipping_address_nameObject

Shipping address name. This is the recipient’s name.



49
50
51
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 49

def shipping_address_name
  @shipping_address_name
end

#shipping_address_stateObject

Shipping address state / prefecture. Required for physical products.



61
62
63
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 61

def shipping_address_state
  @shipping_address_state
end

#shipping_address_zipObject

Shipping address ZIP code, in a 7-digit format (NNN-NNNN). Required for physical products.



64
65
66
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 64

def shipping_address_zip
  @shipping_address_zip
end

#typeObject

Payment method type.



20
21
22
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 20

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 475

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



146
147
148
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 146

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 113

def self.attribute_map
  {
    :'type' => :'type',
    :'customer_age' => :'customer_age',
    :'customer_last_order_amount' => :'customer_last_order_amount',
    :'customer_last_order_at' => :'customer_last_order_at',
    :'customer_lifetime_value' => :'customer_lifetime_value',
    :'customer_name' => :'customer_name',
    :'customer_order_count' => :'customer_order_count',
    :'email' => :'email',
    :'phone' => :'phone',
    :'external_customer_id' => :'external_customer_id',
    :'item_title' => :'item_title',
    :'customer_name_kana' => :'customer_name_kana',
    :'capture' => :'capture',
    :'shipping_address_name' => :'shipping_address_name',
    :'shipping_address_line1' => :'shipping_address_line1',
    :'shipping_address_line2' => :'shipping_address_line2',
    :'shipping_address_city' => :'shipping_address_city',
    :'shipping_address_state' => :'shipping_address_state',
    :'shipping_address_zip' => :'shipping_address_zip',
    :'shipping_address_country' => :'shipping_address_country',
    :'billing_address_name' => :'billing_address_name',
    :'billing_address_line1' => :'billing_address_line1',
    :'billing_address_line2' => :'billing_address_line2',
    :'billing_address_city' => :'billing_address_city',
    :'billing_address_state' => :'billing_address_state',
    :'billing_address_zip' => :'billing_address_zip',
    :'billing_address_country' => :'billing_address_country'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 445

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



184
185
186
187
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 184

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 151

def self.openapi_types
  {
    :'type' => :'String',
    :'customer_age' => :'Integer',
    :'customer_last_order_amount' => :'Integer',
    :'customer_last_order_at' => :'Integer',
    :'customer_lifetime_value' => :'Integer',
    :'customer_name' => :'String',
    :'customer_order_count' => :'Integer',
    :'email' => :'String',
    :'phone' => :'String',
    :'external_customer_id' => :'String',
    :'item_title' => :'String',
    :'customer_name_kana' => :'String',
    :'capture' => :'Boolean',
    :'shipping_address_name' => :'String',
    :'shipping_address_line1' => :'String',
    :'shipping_address_line2' => :'String',
    :'shipping_address_city' => :'String',
    :'shipping_address_state' => :'String',
    :'shipping_address_zip' => :'String',
    :'shipping_address_country' => :'String',
    :'billing_address_name' => :'String',
    :'billing_address_line1' => :'String',
    :'billing_address_line2' => :'String',
    :'billing_address_city' => :'String',
    :'billing_address_state' => :'String',
    :'billing_address_zip' => :'String',
    :'billing_address_country' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 398

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      customer_age == o.customer_age &&
      customer_last_order_amount == o.customer_last_order_amount &&
      customer_last_order_at == o.customer_last_order_at &&
      customer_lifetime_value == o.customer_lifetime_value &&
      customer_name == o.customer_name &&
      customer_order_count == o.customer_order_count &&
      email == o.email &&
      phone == o.phone &&
      external_customer_id == o.external_customer_id &&
      item_title == o.item_title &&
      customer_name_kana == o.customer_name_kana &&
      capture == o.capture &&
      shipping_address_name == o.shipping_address_name &&
      shipping_address_line1 == o.shipping_address_line1 &&
      shipping_address_line2 == o.shipping_address_line2 &&
      shipping_address_city == o.shipping_address_city &&
      shipping_address_state == o.shipping_address_state &&
      shipping_address_zip == o.shipping_address_zip &&
      shipping_address_country == o.shipping_address_country &&
      billing_address_name == o.billing_address_name &&
      billing_address_line1 == o.billing_address_line1 &&
      billing_address_line2 == o.billing_address_line2 &&
      billing_address_city == o.billing_address_city &&
      billing_address_state == o.billing_address_state &&
      billing_address_zip == o.billing_address_zip &&
      billing_address_country == o.billing_address_country
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



546
547
548
549
550
551
552
553
554
555
556
557
558
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 546

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


432
433
434
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 432

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



438
439
440
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 438

def hash
  [type, customer_age, customer_last_order_amount, customer_last_order_at, customer_lifetime_value, customer_name, customer_order_count, email, phone, external_customer_id, item_title, customer_name_kana, capture, shipping_address_name, shipping_address_line1, shipping_address_line2, shipping_address_city, shipping_address_state, shipping_address_zip, shipping_address_country, billing_address_name, billing_address_line1, billing_address_line2, billing_address_city, billing_address_state, billing_address_zip, billing_address_country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 319

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @customer_name.nil?
    invalid_properties.push('invalid value for "customer_name", customer_name cannot be nil.')
  end

  pattern = Regexp.new(/\A([() \-_+]*[0-9]){10}[() \-_+0-9]*\Z/)
  if !@phone.nil? && @phone !~ pattern
    invalid_properties.push("invalid value for \"phone\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[0-9]{3}-[0-9]{4}$/)
  if !@shipping_address_zip.nil? && @shipping_address_zip !~ pattern
    invalid_properties.push("invalid value for \"shipping_address_zip\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



522
523
524
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 522

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



528
529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 528

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



516
517
518
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 516

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



345
346
347
348
349
350
351
352
353
354
# File 'lib/komoju-sdk/models/payment_details_paidy.rb', line 345

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["paidy"])
  return false unless type_validator.valid?(@type)
  return false if @customer_name.nil?
  return false if !@phone.nil? && @phone !~ Regexp.new(/\A([() \-_+]*[0-9]){10}[() \-_+0-9]*\Z/)
  return false if !@shipping_address_zip.nil? && @shipping_address_zip !~ Regexp.new(/^[0-9]{3}-[0-9]{4}$/)
  true
end