Class: Komoju::PaymentMethod

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/payment_method.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentMethod

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/komoju-sdk/models/payment_method.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::PaymentMethod` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::PaymentMethod`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'hashed_gateway')
    self.hashed_gateway = attributes[:'hashed_gateway']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'exchange_rate')
    self.exchange_rate = attributes[:'exchange_rate']
  end

  if attributes.key?(:'offsite')
    self.offsite = attributes[:'offsite']
  end

  if attributes.key?(:'additional_fields')
    if (value = attributes[:'additional_fields']).is_a?(Array)
      self.additional_fields = value
    end
  end

  if attributes.key?(:'brands')
    self.brands = attributes[:'brands']
  end

  if attributes.key?(:'seven_eleven_merchant_number')
    self.seven_eleven_merchant_number = attributes[:'seven_eleven_merchant_number']
  end

  if attributes.key?(:'installments')
    if (value = attributes[:'installments']).is_a?(Array)
      self.installments = value
    end
  end

  if attributes.key?(:'api_endpoint')
    self.api_endpoint = attributes[:'api_endpoint']
  end
end

Instance Attribute Details

#additional_fieldsObject

Names of additional input fields required to complete payment with this method.



36
37
38
# File 'lib/komoju-sdk/models/payment_method.rb', line 36

def additional_fields
  @additional_fields
end

#amountObject

Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).



25
26
27
# File 'lib/komoju-sdk/models/payment_method.rb', line 25

def amount
  @amount
end

#api_endpointObject

Only for Komoju Pay



47
48
49
# File 'lib/komoju-sdk/models/payment_method.rb', line 47

def api_endpoint
  @api_endpoint
end

#brandsObject

Returns the value of attribute brands.



38
39
40
# File 'lib/komoju-sdk/models/payment_method.rb', line 38

def brands
  @brands
end

#currencyObject

Returns the value of attribute currency.



27
28
29
# File 'lib/komoju-sdk/models/payment_method.rb', line 27

def currency
  @currency
end

#exchange_rateObject

Exchange rate applied when this payment method’s currency differs from the session currency.



30
31
32
# File 'lib/komoju-sdk/models/payment_method.rb', line 30

def exchange_rate
  @exchange_rate
end

#hashed_gatewayObject

Hashed identifier of the payment gateway processing this method.



22
23
24
# File 'lib/komoju-sdk/models/payment_method.rb', line 22

def hashed_gateway
  @hashed_gateway
end

#installmentsObject

Only for Komoju Pay



44
45
46
# File 'lib/komoju-sdk/models/payment_method.rb', line 44

def installments
  @installments
end

#offsiteObject

Whether this payment method redirects the customer to an external site to complete payment.



33
34
35
# File 'lib/komoju-sdk/models/payment_method.rb', line 33

def offsite
  @offsite
end

#seven_eleven_merchant_numberObject

Only for Konbini



41
42
43
# File 'lib/komoju-sdk/models/payment_method.rb', line 41

def seven_eleven_merchant_number
  @seven_eleven_merchant_number
end

#typeObject

Machine-readable type slug for this payment method (e.g. "credit_card", "konbini").



19
20
21
# File 'lib/komoju-sdk/models/payment_method.rb', line 19

def type
  @type
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/komoju-sdk/models/payment_method.rb', line 285

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/komoju-sdk/models/payment_method.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/komoju-sdk/models/payment_method.rb', line 72

def self.attribute_map
  {
    :'type' => :'type',
    :'hashed_gateway' => :'hashed_gateway',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'exchange_rate' => :'exchange_rate',
    :'offsite' => :'offsite',
    :'additional_fields' => :'additional_fields',
    :'brands' => :'brands',
    :'seven_eleven_merchant_number' => :'seven_eleven_merchant_number',
    :'installments' => :'installments',
    :'api_endpoint' => :'api_endpoint'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/komoju-sdk/models/payment_method.rb', line 255

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
115
# File 'lib/komoju-sdk/models/payment_method.rb', line 111

def self.openapi_nullable
  Set.new([
    :'seven_eleven_merchant_number',
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/komoju-sdk/models/payment_method.rb', line 94

def self.openapi_types
  {
    :'type' => :'String',
    :'hashed_gateway' => :'String',
    :'amount' => :'Integer',
    :'currency' => :'Currency',
    :'exchange_rate' => :'Float',
    :'offsite' => :'Boolean',
    :'additional_fields' => :'Array<String>',
    :'brands' => :'PaymentMethodBrands',
    :'seven_eleven_merchant_number' => :'String',
    :'installments' => :'Array<PaymentMethodInstallmentsInner>',
    :'api_endpoint' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/komoju-sdk/models/payment_method.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      hashed_gateway == o.hashed_gateway &&
      amount == o.amount &&
      currency == o.currency &&
      exchange_rate == o.exchange_rate &&
      offsite == o.offsite &&
      additional_fields == o.additional_fields &&
      brands == o.brands &&
      seven_eleven_merchant_number == o.seven_eleven_merchant_number &&
      installments == o.installments &&
      api_endpoint == o.api_endpoint
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/komoju-sdk/models/payment_method.rb', line 356

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/komoju-sdk/models/payment_method.rb', line 242

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



248
249
250
# File 'lib/komoju-sdk/models/payment_method.rb', line 248

def hash
  [type, hashed_gateway, amount, currency, exchange_rate, offsite, additional_fields, brands, seven_eleven_merchant_number, installments, api_endpoint].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/komoju-sdk/models/payment_method.rb', line 185

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@amount.nil? && @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
# File 'lib/komoju-sdk/models/payment_method.rb', line 332

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/komoju-sdk/models/payment_method.rb', line 338

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



326
327
328
# File 'lib/komoju-sdk/models/payment_method.rb', line 326

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
# File 'lib/komoju-sdk/models/payment_method.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  return false if !@amount.nil? && @amount < 0
  true
end