Class: Komoju::ResponsePaymentDetailsCreditCardKorea
- Inherits:
-
Object
- Object
- Komoju::ResponsePaymentDetailsCreditCardKorea
- Defined in:
- lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#billing_address_city ⇒ Object
Billing address city.
-
#billing_address_country ⇒ Object
Billing address country.
-
#billing_address_line1 ⇒ Object
Billing address line 1.
-
#billing_address_line2 ⇒ Object
Billing address line 2.
-
#billing_address_name ⇒ Object
Billing address name.
-
#billing_address_state ⇒ Object
Billing address state.
-
#billing_address_zip ⇒ Object
Billing address ZIP code.
-
#brand ⇒ Object
Card brand (e.g. "visa", "mastercard", "jcb").
-
#last_four_digits ⇒ Object
Last four digits of the card number.
-
#month ⇒ Object
Credit card expiration month.
-
#shipping_address_city ⇒ Object
Shipping address city.
-
#shipping_address_country ⇒ Object
Shipping address country.
-
#shipping_address_line1 ⇒ Object
Shipping address line 1.
-
#shipping_address_line2 ⇒ Object
Shipping address line 2.
-
#shipping_address_name ⇒ Object
Shipping address name.
-
#shipping_address_state ⇒ Object
Shipping address state.
-
#shipping_address_zip ⇒ Object
Shipping address ZIP code.
-
#type ⇒ Object
Payment method type.
-
#verification_value ⇒ Object
Returns the value of attribute verification_value.
-
#year ⇒ Object
Credit card expiration year.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResponsePaymentDetailsCreditCardKorea
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ResponsePaymentDetailsCreditCardKorea
Initializes the object
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 165 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ResponsePaymentDetailsCreditCardKorea` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ResponsePaymentDetailsCreditCardKorea`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'brand') self.brand = attributes[:'brand'] else self.brand = nil end if attributes.key?(:'last_four_digits') self.last_four_digits = attributes[:'last_four_digits'] else self.last_four_digits = nil end if attributes.key?(:'month') self.month = attributes[:'month'] else self.month = nil end if attributes.key?(:'year') self.year = attributes[:'year'] else self.year = nil end if attributes.key?(:'verification_value') self.verification_value = attributes[:'verification_value'] end if attributes.key?(:'shipping_address_name') self.shipping_address_name = attributes[:'shipping_address_name'] end if attributes.key?(:'shipping_address_line1') self.shipping_address_line1 = attributes[:'shipping_address_line1'] end if attributes.key?(:'shipping_address_line2') self.shipping_address_line2 = attributes[:'shipping_address_line2'] end if attributes.key?(:'shipping_address_city') self.shipping_address_city = attributes[:'shipping_address_city'] end if attributes.key?(:'shipping_address_state') self.shipping_address_state = attributes[:'shipping_address_state'] end if attributes.key?(:'shipping_address_zip') self.shipping_address_zip = attributes[:'shipping_address_zip'] end if attributes.key?(:'shipping_address_country') self.shipping_address_country = attributes[:'shipping_address_country'] end if attributes.key?(:'billing_address_name') self.billing_address_name = attributes[:'billing_address_name'] end if attributes.key?(:'billing_address_line1') self.billing_address_line1 = attributes[:'billing_address_line1'] end if attributes.key?(:'billing_address_line2') self.billing_address_line2 = attributes[:'billing_address_line2'] end if attributes.key?(:'billing_address_city') self.billing_address_city = attributes[:'billing_address_city'] end if attributes.key?(:'billing_address_state') self.billing_address_state = attributes[:'billing_address_state'] end if attributes.key?(:'billing_address_zip') self.billing_address_zip = attributes[:'billing_address_zip'] end if attributes.key?(:'billing_address_country') self.billing_address_country = attributes[:'billing_address_country'] end end |
Instance Attribute Details
#billing_address_city ⇒ Object
Billing address city.
67 68 69 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 67 def billing_address_city @billing_address_city end |
#billing_address_country ⇒ Object
Billing address country.
76 77 78 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 76 def billing_address_country @billing_address_country end |
#billing_address_line1 ⇒ Object
Billing address line 1.
61 62 63 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 61 def billing_address_line1 @billing_address_line1 end |
#billing_address_line2 ⇒ Object
Billing address line 2.
64 65 66 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 64 def billing_address_line2 @billing_address_line2 end |
#billing_address_name ⇒ Object
Billing address name. This is the paying customer’s name.
58 59 60 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 58 def billing_address_name @billing_address_name end |
#billing_address_state ⇒ Object
Billing address state.
70 71 72 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 70 def billing_address_state @billing_address_state end |
#billing_address_zip ⇒ Object
Billing address ZIP code.
73 74 75 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 73 def billing_address_zip @billing_address_zip end |
#brand ⇒ Object
Card brand (e.g. "visa", "mastercard", "jcb").
23 24 25 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 23 def brand @brand end |
#last_four_digits ⇒ Object
Last four digits of the card number.
26 27 28 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 26 def last_four_digits @last_four_digits end |
#month ⇒ Object
Credit card expiration month.
29 30 31 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 29 def month @month end |
#shipping_address_city ⇒ Object
Shipping address city.
46 47 48 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 46 def shipping_address_city @shipping_address_city end |
#shipping_address_country ⇒ Object
Shipping address country.
55 56 57 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 55 def shipping_address_country @shipping_address_country end |
#shipping_address_line1 ⇒ Object
Shipping address line 1.
40 41 42 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 40 def shipping_address_line1 @shipping_address_line1 end |
#shipping_address_line2 ⇒ Object
Shipping address line 2.
43 44 45 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 43 def shipping_address_line2 @shipping_address_line2 end |
#shipping_address_name ⇒ Object
Shipping address name. This is the recipient’s name.
37 38 39 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 37 def shipping_address_name @shipping_address_name end |
#shipping_address_state ⇒ Object
Shipping address state.
49 50 51 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 49 def shipping_address_state @shipping_address_state end |
#shipping_address_zip ⇒ Object
Shipping address ZIP code.
52 53 54 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 52 def shipping_address_zip @shipping_address_zip end |
#type ⇒ Object
Payment method type.
20 21 22 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 20 def type @type end |
#verification_value ⇒ Object
Returns the value of attribute verification_value.
34 35 36 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 34 def verification_value @verification_value end |
#year ⇒ Object
Credit card expiration year. If this value is less than 100, it will be treated as two digits year in the current century. E.g. If current year is ‘2024`, `99` means `2099`.
32 33 34 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 32 def year @year end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 461 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
127 128 129 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 127 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 101 def self.attribute_map { :'type' => :'type', :'brand' => :'brand', :'last_four_digits' => :'last_four_digits', :'month' => :'month', :'year' => :'year', :'verification_value' => :'verification_value', :'shipping_address_name' => :'shipping_address_name', :'shipping_address_line1' => :'shipping_address_line1', :'shipping_address_line2' => :'shipping_address_line2', :'shipping_address_city' => :'shipping_address_city', :'shipping_address_state' => :'shipping_address_state', :'shipping_address_zip' => :'shipping_address_zip', :'shipping_address_country' => :'shipping_address_country', :'billing_address_name' => :'billing_address_name', :'billing_address_line1' => :'billing_address_line1', :'billing_address_line2' => :'billing_address_line2', :'billing_address_city' => :'billing_address_city', :'billing_address_state' => :'billing_address_state', :'billing_address_zip' => :'billing_address_zip', :'billing_address_country' => :'billing_address_country' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 431 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
158 159 160 161 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 158 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 132 def self.openapi_types { :'type' => :'String', :'brand' => :'String', :'last_four_digits' => :'String', :'month' => :'Integer', :'year' => :'Integer', :'verification_value' => :'String', :'shipping_address_name' => :'String', :'shipping_address_line1' => :'String', :'shipping_address_line2' => :'String', :'shipping_address_city' => :'String', :'shipping_address_state' => :'String', :'shipping_address_zip' => :'String', :'shipping_address_country' => :'String', :'billing_address_name' => :'String', :'billing_address_line1' => :'String', :'billing_address_line2' => :'String', :'billing_address_city' => :'String', :'billing_address_state' => :'String', :'billing_address_zip' => :'String', :'billing_address_country' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 391 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && brand == o.brand && last_four_digits == o.last_four_digits && month == o.month && year == o.year && verification_value == o.verification_value && shipping_address_name == o.shipping_address_name && shipping_address_line1 == o.shipping_address_line1 && shipping_address_line2 == o.shipping_address_line2 && shipping_address_city == o.shipping_address_city && shipping_address_state == o.shipping_address_state && shipping_address_zip == o.shipping_address_zip && shipping_address_country == o.shipping_address_country && billing_address_name == o.billing_address_name && billing_address_line1 == o.billing_address_line1 && billing_address_line2 == o.billing_address_line2 && billing_address_city == o.billing_address_city && billing_address_state == o.billing_address_state && billing_address_zip == o.billing_address_zip && billing_address_country == o.billing_address_country end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
532 533 534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 532 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
418 419 420 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 418 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
424 425 426 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 424 def hash [type, brand, last_four_digits, month, year, verification_value, shipping_address_name, shipping_address_line1, shipping_address_line2, shipping_address_city, shipping_address_state, shipping_address_zip, shipping_address_country, billing_address_name, billing_address_line1, billing_address_line2, billing_address_city, billing_address_state, billing_address_zip, billing_address_country].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 271 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @brand.nil? invalid_properties.push('invalid value for "brand", brand cannot be nil.') end if @last_four_digits.nil? invalid_properties.push('invalid value for "last_four_digits", last_four_digits cannot be nil.') end if @month.nil? invalid_properties.push('invalid value for "month", month cannot be nil.') end if @month > 12 invalid_properties.push('invalid value for "month", must be smaller than or equal to 12.') end if @month < 1 invalid_properties.push('invalid value for "month", must be greater than or equal to 1.') end if @year.nil? invalid_properties.push('invalid value for "year", year cannot be nil.') end if @year > 2100 invalid_properties.push('invalid value for "year", must be smaller than or equal to 2100.') end if @year < 0 invalid_properties.push('invalid value for "year", must be greater than or equal to 0.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
508 509 510 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 508 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
514 515 516 517 518 519 520 521 522 523 524 525 526 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 514 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
502 503 504 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 502 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/komoju-sdk/models/response_payment_details_credit_card_korea.rb', line 315 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["credit_card_korea"]) return false unless type_validator.valid?(@type) return false if @brand.nil? return false if @last_four_digits.nil? return false if @month.nil? return false if @month > 12 return false if @month < 1 return false if @year.nil? return false if @year > 2100 return false if @year < 0 verification_value_validator = EnumAttributeValidator.new('String', ["Approved", "Invalid", "Not Checked", "Not Supplied"]) return false unless verification_value_validator.valid?(@verification_value) true end |