Class: Komoju::Session

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/session.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Session

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/komoju-sdk/models/session.rb', line 175

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::Session` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::Session`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'resource')
    self.resource = attributes[:'resource']
  else
    self.resource = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'session_url')
    self.session_url = attributes[:'session_url']
  else
    self.session_url = nil
  end

  if attributes.key?(:'return_url')
    self.return_url = attributes[:'return_url']
  else
    self.return_url = nil
  end

  if attributes.key?(:'default_locale')
    self.default_locale = attributes[:'default_locale']
  else
    self.default_locale = nil
  end

  if attributes.key?(:'payment_methods')
    if (value = attributes[:'payment_methods']).is_a?(Array)
      self.payment_methods = value
    end
  else
    self.payment_methods = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'cancelled_at')
    self.cancelled_at = attributes[:'cancelled_at']
  else
    self.cancelled_at = nil
  end

  if attributes.key?(:'completed_at')
    self.completed_at = attributes[:'completed_at']
  else
    self.completed_at = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'expired')
    self.expired = attributes[:'expired']
  else
    self.expired = nil
  end

  if attributes.key?(:'merchant')
    self.merchant = attributes[:'merchant']
  else
    self.merchant = nil
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  else
    self. = nil
  end

  if attributes.key?(:'payment')
    self.payment = attributes[:'payment']
  end

  if attributes.key?(:'payment_data')
    self.payment_data = attributes[:'payment_data']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'secure_token')
    self.secure_token = attributes[:'secure_token']
  end

  if attributes.key?(:'line_items')
    if (value = attributes[:'line_items']).is_a?(Array)
      self.line_items = value
    end
  end

  if attributes.key?(:'merchant_id')
    self.merchant_id = attributes[:'merchant_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end
end

Instance Attribute Details

#amountObject

Amount greater than or equal to 0, in the lowest denomination of the currency (e.g. cents for USD).



27
28
29
# File 'lib/komoju-sdk/models/session.rb', line 27

def amount
  @amount
end

#cancelled_atObject

Timestamp when the session was cancelled, or null if not cancelled.



46
47
48
# File 'lib/komoju-sdk/models/session.rb', line 46

def cancelled_at
  @cancelled_at
end

#completed_atObject

Timestamp when the session was completed, or null if not completed.



49
50
51
# File 'lib/komoju-sdk/models/session.rb', line 49

def completed_at
  @completed_at
end

#created_atObject

Timestamp when the session was created.



43
44
45
# File 'lib/komoju-sdk/models/session.rb', line 43

def created_at
  @created_at
end

#currencyObject

Returns the value of attribute currency.



29
30
31
# File 'lib/komoju-sdk/models/session.rb', line 29

def currency
  @currency
end

#customer_idObject

Subscription customer UUID. Only present when mode includes "customer".



66
67
68
# File 'lib/komoju-sdk/models/session.rb', line 66

def customer_id
  @customer_id
end

#default_localeObject

Returns the value of attribute default_locale.



37
38
39
# File 'lib/komoju-sdk/models/session.rb', line 37

def default_locale
  @default_locale
end

#emailObject

Customer email. Only present when an email was provided.



77
78
79
# File 'lib/komoju-sdk/models/session.rb', line 77

def email
  @email
end

#expiredObject

Whether the session has expired.



54
55
56
# File 'lib/komoju-sdk/models/session.rb', line 54

def expired
  @expired
end

#idObject

A unique 25-character alphanumeric resource identifier.



19
20
21
# File 'lib/komoju-sdk/models/session.rb', line 19

def id
  @id
end

#line_itemsObject

Line items for this session. Only present when line items were provided on create.



71
72
73
# File 'lib/komoju-sdk/models/session.rb', line 71

def line_items
  @line_items
end

#merchantObject

Returns the value of attribute merchant.



56
57
58
# File 'lib/komoju-sdk/models/session.rb', line 56

def merchant
  @merchant
end

#merchant_idObject

Merchant UUID. Only present for Platform Model seller merchants.



74
75
76
# File 'lib/komoju-sdk/models/session.rb', line 74

def merchant_id
  @merchant_id
end

#metadataObject

Arbitrary key-value metadata attached to this session at creation time.



59
60
61
# File 'lib/komoju-sdk/models/session.rb', line 59

def 
  @metadata
end

#modeObject

Returns the value of attribute mode.



24
25
26
# File 'lib/komoju-sdk/models/session.rb', line 24

def mode
  @mode
end

#paymentObject

Returns the value of attribute payment.



61
62
63
# File 'lib/komoju-sdk/models/session.rb', line 61

def payment
  @payment
end

#payment_dataObject

Returns the value of attribute payment_data.



63
64
65
# File 'lib/komoju-sdk/models/session.rb', line 63

def payment_data
  @payment_data
end

#payment_methodsObject

List of payment methods available for this session.



40
41
42
# File 'lib/komoju-sdk/models/session.rb', line 40

def payment_methods
  @payment_methods
end

#resourceObject

Resource type name, always "session".



22
23
24
# File 'lib/komoju-sdk/models/session.rb', line 22

def resource
  @resource
end

#return_urlObject

URL the customer is redirected to after completing or cancelling the session.



35
36
37
# File 'lib/komoju-sdk/models/session.rb', line 35

def return_url
  @return_url
end

#secure_tokenObject

Returns the value of attribute secure_token.



68
69
70
# File 'lib/komoju-sdk/models/session.rb', line 68

def secure_token
  @secure_token
end

#session_urlObject

URL to redirect the customer to for completing the session.



32
33
34
# File 'lib/komoju-sdk/models/session.rb', line 32

def session_url
  @session_url
end

#statusObject

Returns the value of attribute status.



51
52
53
# File 'lib/komoju-sdk/models/session.rb', line 51

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/komoju-sdk/models/session.rb', line 531

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



131
132
133
# File 'lib/komoju-sdk/models/session.rb', line 131

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/komoju-sdk/models/session.rb', line 102

def self.attribute_map
  {
    :'id' => :'id',
    :'resource' => :'resource',
    :'mode' => :'mode',
    :'amount' => :'amount',
    :'currency' => :'currency',
    :'session_url' => :'session_url',
    :'return_url' => :'return_url',
    :'default_locale' => :'default_locale',
    :'payment_methods' => :'payment_methods',
    :'created_at' => :'created_at',
    :'cancelled_at' => :'cancelled_at',
    :'completed_at' => :'completed_at',
    :'status' => :'status',
    :'expired' => :'expired',
    :'merchant' => :'merchant',
    :'metadata' => :'metadata',
    :'payment' => :'payment',
    :'payment_data' => :'payment_data',
    :'customer_id' => :'customer_id',
    :'secure_token' => :'secure_token',
    :'line_items' => :'line_items',
    :'merchant_id' => :'merchant_id',
    :'email' => :'email'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'lib/komoju-sdk/models/session.rb', line 501

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



165
166
167
168
169
170
171
# File 'lib/komoju-sdk/models/session.rb', line 165

def self.openapi_nullable
  Set.new([
    :'return_url',
    :'cancelled_at',
    :'completed_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/komoju-sdk/models/session.rb', line 136

def self.openapi_types
  {
    :'id' => :'String',
    :'resource' => :'String',
    :'mode' => :'SessionMode',
    :'amount' => :'Integer',
    :'currency' => :'Currency',
    :'session_url' => :'String',
    :'return_url' => :'String',
    :'default_locale' => :'Locale',
    :'payment_methods' => :'Array<PaymentMethod>',
    :'created_at' => :'Time',
    :'cancelled_at' => :'Time',
    :'completed_at' => :'Time',
    :'status' => :'SessionStatus',
    :'expired' => :'Boolean',
    :'merchant' => :'MerchantData',
    :'metadata' => :'Object',
    :'payment' => :'Payment',
    :'payment_data' => :'PaymentData',
    :'customer_id' => :'String',
    :'secure_token' => :'SecureToken',
    :'line_items' => :'Array<LineItem>',
    :'merchant_id' => :'String',
    :'email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
# File 'lib/komoju-sdk/models/session.rb', line 458

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      resource == o.resource &&
      mode == o.mode &&
      amount == o.amount &&
      currency == o.currency &&
      session_url == o.session_url &&
      return_url == o.return_url &&
      default_locale == o.default_locale &&
      payment_methods == o.payment_methods &&
      created_at == o.created_at &&
      cancelled_at == o.cancelled_at &&
      completed_at == o.completed_at &&
      status == o.status &&
      expired == o.expired &&
      merchant == o.merchant &&
       == o. &&
      payment == o.payment &&
      payment_data == o.payment_data &&
      customer_id == o.customer_id &&
      secure_token == o.secure_token &&
      line_items == o.line_items &&
      merchant_id == o.merchant_id &&
      email == o.email
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/komoju-sdk/models/session.rb', line 602

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


488
489
490
# File 'lib/komoju-sdk/models/session.rb', line 488

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



494
495
496
# File 'lib/komoju-sdk/models/session.rb', line 494

def hash
  [id, resource, mode, amount, currency, session_url, return_url, default_locale, payment_methods, created_at, cancelled_at, completed_at, status, expired, merchant, , payment, payment_data, customer_id, secure_token, line_items, merchant_id, email].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/komoju-sdk/models/session.rb', line 319

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @id.to_s.length > 25
    invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.')
  end

  if @id.to_s.length < 25
    invalid_properties.push('invalid value for "id", the character length must be great than or equal to 25.')
  end

  if @resource.nil?
    invalid_properties.push('invalid value for "resource", resource cannot be nil.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @amount < 0
    invalid_properties.push('invalid value for "amount", must be greater than or equal to 0.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @session_url.nil?
    invalid_properties.push('invalid value for "session_url", session_url cannot be nil.')
  end

  if @default_locale.nil?
    invalid_properties.push('invalid value for "default_locale", default_locale cannot be nil.')
  end

  if @payment_methods.nil?
    invalid_properties.push('invalid value for "payment_methods", payment_methods cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @expired.nil?
    invalid_properties.push('invalid value for "expired", expired cannot be nil.')
  end

  if @merchant.nil?
    invalid_properties.push('invalid value for "merchant", merchant cannot be nil.')
  end

  if @metadata.nil?
    invalid_properties.push('invalid value for "metadata", metadata cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



578
579
580
# File 'lib/komoju-sdk/models/session.rb', line 578

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/komoju-sdk/models/session.rb', line 584

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



572
573
574
# File 'lib/komoju-sdk/models/session.rb', line 572

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/komoju-sdk/models/session.rb', line 391

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @id.to_s.length > 25
  return false if @id.to_s.length < 25
  return false if @resource.nil?
  resource_validator = EnumAttributeValidator.new('String', ["session"])
  return false unless resource_validator.valid?(@resource)
  return false if @mode.nil?
  return false if @amount.nil?
  return false if @amount < 0
  return false if @currency.nil?
  return false if @session_url.nil?
  return false if @default_locale.nil?
  return false if @payment_methods.nil?
  return false if @created_at.nil?
  return false if @status.nil?
  return false if @expired.nil?
  return false if @merchant.nil?
  return false if @metadata.nil?
  true
end