Class: Komoju::Settlement
- Inherits:
-
Object
- Object
- Komoju::Settlement
- Defined in:
- lib/komoju-sdk/models/settlement.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bank_transfer_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#company_name ⇒ Object
Legal company name of the merchant.
-
#created_at ⇒ Object
Timestamp when this settlement record was created.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#cutoff_time ⇒ Object
Cutoff timestamp for transactions included in this settlement.
-
#cycle ⇒ Object
Settlement cycle identifier (e.g. the week or month period covered).
-
#download ⇒ Object
Returns the value of attribute download.
-
#fee_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#fee_tax_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#fx_conversion_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#fx_conversion_rate ⇒ Object
Exchange rate applied for FX conversion.
-
#fx_currency ⇒ Object
Returns the value of attribute fx_currency.
-
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
-
#merchant_name ⇒ Object
Name of the merchant associated with this settlement.
-
#reference ⇒ Object
Human-readable reference code for this settlement.
-
#remittance_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#resource ⇒ Object
Resource type name, always "settlement".
-
#settlement_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
-
#status ⇒ Object
Returns the value of attribute status.
-
#transaction_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Settlement
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Settlement
Initializes the object
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/komoju-sdk/models/settlement.rb', line 161 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::Settlement` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::Settlement`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'resource') self.resource = attributes[:'resource'] else self.resource = nil end if attributes.key?(:'reference') self.reference = attributes[:'reference'] else self.reference = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'merchant_name') self.merchant_name = attributes[:'merchant_name'] else self.merchant_name = nil end if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] else self.company_name = nil end if attributes.key?(:'cycle') self.cycle = attributes[:'cycle'] else self.cycle = nil end if attributes.key?(:'transaction_amount_cents') self.transaction_amount_cents = attributes[:'transaction_amount_cents'] else self.transaction_amount_cents = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] else self.currency = nil end if attributes.key?(:'fee_amount_cents') self.fee_amount_cents = attributes[:'fee_amount_cents'] else self.fee_amount_cents = nil end if attributes.key?(:'fee_tax_amount_cents') self.fee_tax_amount_cents = attributes[:'fee_tax_amount_cents'] else self.fee_tax_amount_cents = nil end if attributes.key?(:'settlement_amount_cents') self.settlement_amount_cents = attributes[:'settlement_amount_cents'] else self.settlement_amount_cents = nil end if attributes.key?(:'fx_currency') self.fx_currency = attributes[:'fx_currency'] else self.fx_currency = nil end if attributes.key?(:'fx_conversion_rate') self.fx_conversion_rate = attributes[:'fx_conversion_rate'] else self.fx_conversion_rate = nil end if attributes.key?(:'fx_conversion_amount_cents') self.fx_conversion_amount_cents = attributes[:'fx_conversion_amount_cents'] else self.fx_conversion_amount_cents = nil end if attributes.key?(:'bank_transfer_amount_cents') self.bank_transfer_amount_cents = attributes[:'bank_transfer_amount_cents'] else self.bank_transfer_amount_cents = nil end if attributes.key?(:'remittance_amount_cents') self.remittance_amount_cents = attributes[:'remittance_amount_cents'] else self.remittance_amount_cents = nil end if attributes.key?(:'cutoff_time') self.cutoff_time = attributes[:'cutoff_time'] else self.cutoff_time = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'download') self.download = attributes[:'download'] else self.download = nil end end |
Instance Attribute Details
#bank_transfer_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
61 62 63 |
# File 'lib/komoju-sdk/models/settlement.rb', line 61 def bank_transfer_amount_cents @bank_transfer_amount_cents end |
#company_name ⇒ Object
Legal company name of the merchant.
33 34 35 |
# File 'lib/komoju-sdk/models/settlement.rb', line 33 def company_name @company_name end |
#created_at ⇒ Object
Timestamp when this settlement record was created.
70 71 72 |
# File 'lib/komoju-sdk/models/settlement.rb', line 70 def created_at @created_at end |
#currency ⇒ Object
Returns the value of attribute currency.
41 42 43 |
# File 'lib/komoju-sdk/models/settlement.rb', line 41 def currency @currency end |
#cutoff_time ⇒ Object
Cutoff timestamp for transactions included in this settlement.
67 68 69 |
# File 'lib/komoju-sdk/models/settlement.rb', line 67 def cutoff_time @cutoff_time end |
#cycle ⇒ Object
Settlement cycle identifier (e.g. the week or month period covered).
36 37 38 |
# File 'lib/komoju-sdk/models/settlement.rb', line 36 def cycle @cycle end |
#download ⇒ Object
Returns the value of attribute download.
72 73 74 |
# File 'lib/komoju-sdk/models/settlement.rb', line 72 def download @download end |
#fee_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
44 45 46 |
# File 'lib/komoju-sdk/models/settlement.rb', line 44 def fee_amount_cents @fee_amount_cents end |
#fee_tax_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
47 48 49 |
# File 'lib/komoju-sdk/models/settlement.rb', line 47 def fee_tax_amount_cents @fee_tax_amount_cents end |
#fx_conversion_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
58 59 60 |
# File 'lib/komoju-sdk/models/settlement.rb', line 58 def fx_conversion_amount_cents @fx_conversion_amount_cents end |
#fx_conversion_rate ⇒ Object
Exchange rate applied for FX conversion.
55 56 57 |
# File 'lib/komoju-sdk/models/settlement.rb', line 55 def fx_conversion_rate @fx_conversion_rate end |
#fx_currency ⇒ Object
Returns the value of attribute fx_currency.
52 53 54 |
# File 'lib/komoju-sdk/models/settlement.rb', line 52 def fx_currency @fx_currency end |
#id ⇒ Object
A unique 25-character alphanumeric resource identifier.
19 20 21 |
# File 'lib/komoju-sdk/models/settlement.rb', line 19 def id @id end |
#merchant_name ⇒ Object
Name of the merchant associated with this settlement.
30 31 32 |
# File 'lib/komoju-sdk/models/settlement.rb', line 30 def merchant_name @merchant_name end |
#reference ⇒ Object
Human-readable reference code for this settlement.
25 26 27 |
# File 'lib/komoju-sdk/models/settlement.rb', line 25 def reference @reference end |
#remittance_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
64 65 66 |
# File 'lib/komoju-sdk/models/settlement.rb', line 64 def remittance_amount_cents @remittance_amount_cents end |
#resource ⇒ Object
Resource type name, always "settlement".
22 23 24 |
# File 'lib/komoju-sdk/models/settlement.rb', line 22 def resource @resource end |
#settlement_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
50 51 52 |
# File 'lib/komoju-sdk/models/settlement.rb', line 50 def settlement_amount_cents @settlement_amount_cents end |
#status ⇒ Object
Returns the value of attribute status.
27 28 29 |
# File 'lib/komoju-sdk/models/settlement.rb', line 27 def status @status end |
#transaction_amount_cents ⇒ Object
Amount in the lowest denomination of the currency (e.g. cents for USD).
39 40 41 |
# File 'lib/komoju-sdk/models/settlement.rb', line 39 def transaction_amount_cents @transaction_amount_cents end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 |
# File 'lib/komoju-sdk/models/settlement.rb', line 510 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) rescue value when :Date Date.parse(value) rescue value when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Komoju.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
123 124 125 |
# File 'lib/komoju-sdk/models/settlement.rb', line 123 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/komoju-sdk/models/settlement.rb', line 97 def self.attribute_map { :'id' => :'id', :'resource' => :'resource', :'reference' => :'reference', :'status' => :'status', :'merchant_name' => :'merchant_name', :'company_name' => :'company_name', :'cycle' => :'cycle', :'transaction_amount_cents' => :'transaction_amount_cents', :'currency' => :'currency', :'fee_amount_cents' => :'fee_amount_cents', :'fee_tax_amount_cents' => :'fee_tax_amount_cents', :'settlement_amount_cents' => :'settlement_amount_cents', :'fx_currency' => :'fx_currency', :'fx_conversion_rate' => :'fx_conversion_rate', :'fx_conversion_amount_cents' => :'fx_conversion_amount_cents', :'bank_transfer_amount_cents' => :'bank_transfer_amount_cents', :'remittance_amount_cents' => :'remittance_amount_cents', :'cutoff_time' => :'cutoff_time', :'created_at' => :'created_at', :'download' => :'download' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 |
# File 'lib/komoju-sdk/models/settlement.rb', line 480 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end begin new(transformed_hash) rescue ArgumentError => e obj = allocate transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) } obj end end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
154 155 156 157 |
# File 'lib/komoju-sdk/models/settlement.rb', line 154 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/komoju-sdk/models/settlement.rb', line 128 def self.openapi_types { :'id' => :'String', :'resource' => :'String', :'reference' => :'String', :'status' => :'Status', :'merchant_name' => :'String', :'company_name' => :'String', :'cycle' => :'String', :'transaction_amount_cents' => :'Integer', :'currency' => :'Currency', :'fee_amount_cents' => :'Integer', :'fee_tax_amount_cents' => :'Integer', :'settlement_amount_cents' => :'Integer', :'fx_currency' => :'Currency', :'fx_conversion_rate' => :'String', :'fx_conversion_amount_cents' => :'Integer', :'bank_transfer_amount_cents' => :'Integer', :'remittance_amount_cents' => :'Integer', :'cutoff_time' => :'Time', :'created_at' => :'Time', :'download' => :'SettlementDownload' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/komoju-sdk/models/settlement.rb', line 440 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && resource == o.resource && reference == o.reference && status == o.status && merchant_name == o.merchant_name && company_name == o.company_name && cycle == o.cycle && transaction_amount_cents == o.transaction_amount_cents && currency == o.currency && fee_amount_cents == o.fee_amount_cents && fee_tax_amount_cents == o.fee_tax_amount_cents && settlement_amount_cents == o.settlement_amount_cents && fx_currency == o.fx_currency && fx_conversion_rate == o.fx_conversion_rate && fx_conversion_amount_cents == o.fx_conversion_amount_cents && bank_transfer_amount_cents == o.bank_transfer_amount_cents && remittance_amount_cents == o.remittance_amount_cents && cutoff_time == o.cutoff_time && created_at == o.created_at && download == o.download end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
581 582 583 584 585 586 587 588 589 590 591 592 593 |
# File 'lib/komoju-sdk/models/settlement.rb', line 581 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
467 468 469 |
# File 'lib/komoju-sdk/models/settlement.rb', line 467 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
473 474 475 |
# File 'lib/komoju-sdk/models/settlement.rb', line 473 def hash [id, resource, reference, status, merchant_name, company_name, cycle, transaction_amount_cents, currency, fee_amount_cents, fee_tax_amount_cents, settlement_amount_cents, fx_currency, fx_conversion_rate, fx_conversion_amount_cents, bank_transfer_amount_cents, remittance_amount_cents, cutoff_time, created_at, download].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/komoju-sdk/models/settlement.rb', line 297 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @id.to_s.length > 25 invalid_properties.push('invalid value for "id", the character length must be smaller than or equal to 25.') end if @id.to_s.length < 25 invalid_properties.push('invalid value for "id", the character length must be great than or equal to 25.') end if @resource.nil? invalid_properties.push('invalid value for "resource", resource cannot be nil.') end if @reference.nil? invalid_properties.push('invalid value for "reference", reference cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @merchant_name.nil? invalid_properties.push('invalid value for "merchant_name", merchant_name cannot be nil.') end if @company_name.nil? invalid_properties.push('invalid value for "company_name", company_name cannot be nil.') end if @cycle.nil? invalid_properties.push('invalid value for "cycle", cycle cannot be nil.') end if @transaction_amount_cents.nil? invalid_properties.push('invalid value for "transaction_amount_cents", transaction_amount_cents cannot be nil.') end if @currency.nil? invalid_properties.push('invalid value for "currency", currency cannot be nil.') end if @fee_amount_cents.nil? invalid_properties.push('invalid value for "fee_amount_cents", fee_amount_cents cannot be nil.') end if @fee_tax_amount_cents.nil? invalid_properties.push('invalid value for "fee_tax_amount_cents", fee_tax_amount_cents cannot be nil.') end if @settlement_amount_cents.nil? invalid_properties.push('invalid value for "settlement_amount_cents", settlement_amount_cents cannot be nil.') end if @fx_currency.nil? invalid_properties.push('invalid value for "fx_currency", fx_currency cannot be nil.') end if @fx_conversion_rate.nil? invalid_properties.push('invalid value for "fx_conversion_rate", fx_conversion_rate cannot be nil.') end if @fx_conversion_amount_cents.nil? invalid_properties.push('invalid value for "fx_conversion_amount_cents", fx_conversion_amount_cents cannot be nil.') end if @bank_transfer_amount_cents.nil? invalid_properties.push('invalid value for "bank_transfer_amount_cents", bank_transfer_amount_cents cannot be nil.') end if @remittance_amount_cents.nil? invalid_properties.push('invalid value for "remittance_amount_cents", remittance_amount_cents cannot be nil.') end if @cutoff_time.nil? invalid_properties.push('invalid value for "cutoff_time", cutoff_time cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @download.nil? invalid_properties.push('invalid value for "download", download cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
557 558 559 |
# File 'lib/komoju-sdk/models/settlement.rb', line 557 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
563 564 565 566 567 568 569 570 571 572 573 574 575 |
# File 'lib/komoju-sdk/models/settlement.rb', line 563 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
551 552 553 |
# File 'lib/komoju-sdk/models/settlement.rb', line 551 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 |
# File 'lib/komoju-sdk/models/settlement.rb', line 393 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @id.to_s.length > 25 return false if @id.to_s.length < 25 return false if @resource.nil? return false if @reference.nil? return false if @status.nil? return false if @merchant_name.nil? return false if @company_name.nil? return false if @cycle.nil? return false if @transaction_amount_cents.nil? return false if @currency.nil? return false if @fee_amount_cents.nil? return false if @fee_tax_amount_cents.nil? return false if @settlement_amount_cents.nil? return false if @fx_currency.nil? return false if @fx_conversion_rate.nil? return false if @fx_conversion_amount_cents.nil? return false if @bank_transfer_amount_cents.nil? return false if @remittance_amount_cents.nil? return false if @cutoff_time.nil? return false if @created_at.nil? return false if @download.nil? true end |