Class: Komoju::SettlementsApi
- Inherits:
-
Object
- Object
- Komoju::SettlementsApi
- Defined in:
- lib/komoju-sdk/api/settlements_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#balance_transactions(currency, opts = {}) ⇒ BalanceTransactionList
Balance: Transactions Given a currency, view the ledger transactions of the currently authenticated merchant.
-
#balance_transactions_with_http_info(currency, opts = {}) ⇒ Array<(BalanceTransactionList, Integer, Hash)>
Balance: Transactions Given a currency, view the ledger transactions of the currently authenticated merchant.
-
#initialize(api_client = ApiClient.default) ⇒ SettlementsApi
constructor
A new instance of SettlementsApi.
-
#list_settlements(opts = {}) ⇒ SettlementList
Settlement: Index Retrieves a paginated list of settlements from most-recent to least-recent.
-
#list_settlements_with_http_info(opts = {}) ⇒ Array<(SettlementList, Integer, Hash)>
Settlement: Index Retrieves a paginated list of settlements from most-recent to least-recent.
-
#show_balance(currency, opts = {}) ⇒ ShowBalance200Response
Balance: Show Given a currency, view the unsettled balance of the currently authenticated merchant.
-
#show_balance_with_http_info(currency, opts = {}) ⇒ Array<(ShowBalance200Response, Integer, Hash)>
Balance: Show Given a currency, view the unsettled balance of the currently authenticated merchant.
-
#show_settlement(id, opts = {}) ⇒ SettlementShow
Settlement: Show Retrieves a single settlement by its
id, including a breakdown of payments, refunds, fees, corrections, and disbursements. -
#show_settlement_csv(id, opts = {}) ⇒ nil
Settlement: CSV Retrieves the settlement in CSV format.
-
#show_settlement_csv_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: CSV Retrieves the settlement in CSV format.
-
#show_settlement_pdf(id, opts = {}) ⇒ nil
Settlement: PDF Retrieves the settlement in PDF format.
-
#show_settlement_pdf_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: PDF Retrieves the settlement in PDF format.
-
#show_settlement_with_http_info(id, opts = {}) ⇒ Array<(SettlementShow, Integer, Hash)>
Settlement: Show Retrieves a single settlement by its `id`, including a breakdown of payments, refunds, fees, corrections, and disbursements.
-
#show_settlement_xls(id, opts = {}) ⇒ nil
Settlement: XLS Retrieves the settlement in XLS format.
-
#show_settlement_xls_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: XLS Retrieves the settlement in XLS format.
-
#show_transaction(currency, transaction_uuid, opts = {}) ⇒ Array<Transaction>
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency.
-
#show_transaction_with_http_info(currency, transaction_uuid, opts = {}) ⇒ Array<(Array<Transaction>, Integer, Hash)>
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SettlementsApi
Returns a new instance of SettlementsApi.
19 20 21 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#balance_transactions(currency, opts = {}) ⇒ BalanceTransactionList
Balance: Transactions Given a currency, view the ledger transactions of the currently authenticated merchant. Will split ledger transactions into line items when appropriate.
32 33 34 35 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 32 def balance_transactions(currency, opts = {}) data, _status_code, _headers = balance_transactions_with_http_info(currency, opts) data end |
#balance_transactions_with_http_info(currency, opts = {}) ⇒ Array<(BalanceTransactionList, Integer, Hash)>
Balance: Transactions Given a currency, view the ledger transactions of the currently authenticated merchant. Will split ledger transactions into line items when appropriate.
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 47 def balance_transactions_with_http_info(currency, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.balance_transactions ...' end # verify the required parameter 'currency' is set if @api_client.config.client_side_validation && currency.nil? fail ArgumentError, "Missing the required parameter 'currency' when calling SettlementsApi.balance_transactions" end # resource path local_var_path = '/balances/{currency}/transactions'.sub('{currency}', CGI.escape(currency.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'start_time'] = opts[:'start_time'] if !opts[:'start_time'].nil? query_params[:'end_time'] = opts[:'end_time'] if !opts[:'end_time'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? query_params[:'type'] = opts[:'type'] if !opts[:'type'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BalanceTransactionList' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.balance_transactions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#balance_transactions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_settlements(opts = {}) ⇒ SettlementList
Settlement: Index
Retrieves a paginated list of settlements from most-recent to least-recent. Pagination can be configured with page and per_page parameters.
108 109 110 111 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 108 def list_settlements(opts = {}) data, _status_code, _headers = list_settlements_with_http_info(opts) data end |
#list_settlements_with_http_info(opts = {}) ⇒ Array<(SettlementList, Integer, Hash)>
Settlement: Index Retrieves a paginated list of settlements from most-recent to least-recent. Pagination can be configured with `page` and `per_page` parameters.
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 121 def list_settlements_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.list_settlements ...' end # resource path local_var_path = '/settlements' # query parameters query_params = opts[:query_params] || {} query_params[:'start_time'] = opts[:'start_time'] if !opts[:'start_time'].nil? query_params[:'end_time'] = opts[:'end_time'] if !opts[:'end_time'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SettlementList' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.list_settlements", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#list_settlements\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_balance(currency, opts = {}) ⇒ ShowBalance200Response
Balance: Show Given a currency, view the unsettled balance of the currently authenticated merchant.
174 175 176 177 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 174 def show_balance(currency, opts = {}) data, _status_code, _headers = show_balance_with_http_info(currency, opts) data end |
#show_balance_with_http_info(currency, opts = {}) ⇒ Array<(ShowBalance200Response, Integer, Hash)>
Balance: Show Given a currency, view the unsettled balance of the currently authenticated merchant.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 184 def show_balance_with_http_info(currency, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_balance ...' end # verify the required parameter 'currency' is set if @api_client.config.client_side_validation && currency.nil? fail ArgumentError, "Missing the required parameter 'currency' when calling SettlementsApi.show_balance" end # resource path local_var_path = '/balances/{currency}'.sub('{currency}', CGI.escape(currency.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ShowBalance200Response' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_balance", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_balance\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement(id, opts = {}) ⇒ SettlementShow
Settlement: Show
Retrieves a single settlement by its id, including a breakdown of payments, refunds, fees, corrections, and disbursements.
237 238 239 240 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 237 def show_settlement(id, opts = {}) data, _status_code, _headers = show_settlement_with_http_info(id, opts) data end |
#show_settlement_csv(id, opts = {}) ⇒ nil
Settlement: CSV Retrieves the settlement in CSV format.
308 309 310 311 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 308 def show_settlement_csv(id, opts = {}) show_settlement_csv_with_http_info(id, opts) nil end |
#show_settlement_csv_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: CSV Retrieves the settlement in CSV format.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 318 def show_settlement_csv_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement_csv ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement_csv" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_csv, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_csv, the character length must be greater than or equal to 25.' end # resource path local_var_path = '/settlements/{id}/csv'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement_csv", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement_csv\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement_pdf(id, opts = {}) ⇒ nil
Settlement: PDF Retrieves the settlement in PDF format.
377 378 379 380 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 377 def show_settlement_pdf(id, opts = {}) show_settlement_pdf_with_http_info(id, opts) nil end |
#show_settlement_pdf_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: PDF Retrieves the settlement in PDF format.
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 387 def show_settlement_pdf_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement_pdf ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement_pdf" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_pdf, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_pdf, the character length must be greater than or equal to 25.' end # resource path local_var_path = '/settlements/{id}/pdf'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement_pdf", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement_with_http_info(id, opts = {}) ⇒ Array<(SettlementShow, Integer, Hash)>
Settlement: Show Retrieves a single settlement by its `id`, including a breakdown of payments, refunds, fees, corrections, and disbursements.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 247 def show_settlement_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement, the character length must be greater than or equal to 25.' end # resource path local_var_path = '/settlements/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SettlementShow' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement_xls(id, opts = {}) ⇒ nil
Settlement: XLS Retrieves the settlement in XLS format.
446 447 448 449 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 446 def show_settlement_xls(id, opts = {}) show_settlement_xls_with_http_info(id, opts) nil end |
#show_settlement_xls_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: XLS Retrieves the settlement in XLS format.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 456 def show_settlement_xls_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement_xls ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement_xls" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_xls, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_xls, the character length must be greater than or equal to 25.' end # resource path local_var_path = '/settlements/{id}/xls'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement_xls", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement_xls\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_transaction(currency, transaction_uuid, opts = {}) ⇒ Array<Transaction>
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency. Will return one entry per line item of the transaction.
516 517 518 519 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 516 def show_transaction(currency, transaction_uuid, opts = {}) data, _status_code, _headers = show_transaction_with_http_info(currency, transaction_uuid, opts) data end |
#show_transaction_with_http_info(currency, transaction_uuid, opts = {}) ⇒ Array<(Array<Transaction>, Integer, Hash)>
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency. Will return one entry per line item of the transaction.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 527 def show_transaction_with_http_info(currency, transaction_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_transaction ...' end # verify the required parameter 'currency' is set if @api_client.config.client_side_validation && currency.nil? fail ArgumentError, "Missing the required parameter 'currency' when calling SettlementsApi.show_transaction" end # verify the required parameter 'transaction_uuid' is set if @api_client.config.client_side_validation && transaction_uuid.nil? fail ArgumentError, "Missing the required parameter 'transaction_uuid' when calling SettlementsApi.show_transaction" end if @api_client.config.client_side_validation && transaction_uuid.to_s.length > 25 fail ArgumentError, 'invalid value for "transaction_uuid" when calling SettlementsApi.show_transaction, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && transaction_uuid.to_s.length < 25 fail ArgumentError, 'invalid value for "transaction_uuid" when calling SettlementsApi.show_transaction, the character length must be greater than or equal to 25.' end # resource path local_var_path = '/balances/{currency}/transactions/{transaction_uuid}'.sub('{currency}', CGI.escape(currency.to_s)).sub('{transaction_uuid}', CGI.escape(transaction_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<Transaction>' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_transaction", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |