Class: Komoju::SettlementsApi
- Inherits:
-
Object
- Object
- Komoju::SettlementsApi
- Defined in:
- lib/komoju-sdk/api/settlements_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SettlementsApi
constructor
A new instance of SettlementsApi.
-
#list_settlements(opts = {}) ⇒ SettlementList
Settlement: Index Retrieves a paginated list of settlements from most-recent to least-recent.
-
#list_settlements_with_http_info(opts = {}) ⇒ Array<(SettlementList, Integer, Hash)>
Settlement: Index Retrieves a paginated list of settlements from most-recent to least-recent.
-
#show_settlement(id, opts = {}) ⇒ SettlementShow
Settlement: Show Retrieves a single settlement by its ‘id`, including a breakdown of payments, refunds, fees, corrections, and disbursements.
-
#show_settlement_csv(id, opts = {}) ⇒ nil
Settlement: CSV Retrieves the settlement in CSV format.
-
#show_settlement_csv_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: CSV Retrieves the settlement in CSV format.
-
#show_settlement_pdf(id, opts = {}) ⇒ nil
Settlement: PDF Retrieves the settlement in PDF format.
-
#show_settlement_pdf_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: PDF Retrieves the settlement in PDF format.
-
#show_settlement_with_http_info(id, opts = {}) ⇒ Array<(SettlementShow, Integer, Hash)>
Settlement: Show Retrieves a single settlement by its `id`, including a breakdown of payments, refunds, fees, corrections, and disbursements.
-
#show_settlement_xls(id, opts = {}) ⇒ nil
Settlement: XLS Retrieves the settlement in XLS format.
-
#show_settlement_xls_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: XLS Retrieves the settlement in XLS format.
-
#show_transaction(currency, transaction_uuid, opts = {}) ⇒ Transaction
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency.
-
#show_transaction_with_http_info(currency, transaction_uuid, opts = {}) ⇒ Array<(Transaction, Integer, Hash)>
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ SettlementsApi
Returns a new instance of SettlementsApi.
19 20 21 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_settlements(opts = {}) ⇒ SettlementList
Settlement: Index Retrieves a paginated list of settlements from most-recent to least-recent. Pagination can be configured with ‘page` and `per_page` parameters.
30 31 32 33 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 30 def list_settlements(opts = {}) data, _status_code, _headers = list_settlements_with_http_info(opts) data end |
#list_settlements_with_http_info(opts = {}) ⇒ Array<(SettlementList, Integer, Hash)>
Settlement: Index Retrieves a paginated list of settlements from most-recent to least-recent. Pagination can be configured with `page` and `per_page` parameters.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 43 def list_settlements_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.list_settlements ...' end # resource path local_var_path = '/settlements' # query parameters query_params = opts[:query_params] || {} query_params[:'start_time'] = opts[:'start_time'] if !opts[:'start_time'].nil? query_params[:'end_time'] = opts[:'end_time'] if !opts[:'end_time'].nil? query_params[:'per_page'] = opts[:'per_page'] if !opts[:'per_page'].nil? query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SettlementList' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.list_settlements", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#list_settlements\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement(id, opts = {}) ⇒ SettlementShow
Settlement: Show Retrieves a single settlement by its ‘id`, including a breakdown of payments, refunds, fees, corrections, and disbursements.
96 97 98 99 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 96 def show_settlement(id, opts = {}) data, _status_code, _headers = show_settlement_with_http_info(id, opts) data end |
#show_settlement_csv(id, opts = {}) ⇒ nil
Settlement: CSV Retrieves the settlement in CSV format.
167 168 169 170 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 167 def show_settlement_csv(id, opts = {}) show_settlement_csv_with_http_info(id, opts) nil end |
#show_settlement_csv_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: CSV Retrieves the settlement in CSV format.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 177 def show_settlement_csv_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement_csv ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement_csv" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_csv, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_csv, the character length must be great than or equal to 25.' end # resource path local_var_path = '/settlements/{id}/csv'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement_csv", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement_csv\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement_pdf(id, opts = {}) ⇒ nil
Settlement: PDF Retrieves the settlement in PDF format.
236 237 238 239 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 236 def show_settlement_pdf(id, opts = {}) show_settlement_pdf_with_http_info(id, opts) nil end |
#show_settlement_pdf_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: PDF Retrieves the settlement in PDF format.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 246 def show_settlement_pdf_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement_pdf ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement_pdf" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_pdf, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_pdf, the character length must be great than or equal to 25.' end # resource path local_var_path = '/settlements/{id}/pdf'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement_pdf", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement_with_http_info(id, opts = {}) ⇒ Array<(SettlementShow, Integer, Hash)>
Settlement: Show Retrieves a single settlement by its `id`, including a breakdown of payments, refunds, fees, corrections, and disbursements.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 106 def show_settlement_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement, the character length must be great than or equal to 25.' end # resource path local_var_path = '/settlements/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SettlementShow' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_settlement_xls(id, opts = {}) ⇒ nil
Settlement: XLS Retrieves the settlement in XLS format.
305 306 307 308 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 305 def show_settlement_xls(id, opts = {}) show_settlement_xls_with_http_info(id, opts) nil end |
#show_settlement_xls_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Settlement: XLS Retrieves the settlement in XLS format.
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 315 def show_settlement_xls_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_settlement_xls ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling SettlementsApi.show_settlement_xls" end if @api_client.config.client_side_validation && id.to_s.length > 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_xls, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && id.to_s.length < 25 fail ArgumentError, 'invalid value for "id" when calling SettlementsApi.show_settlement_xls, the character length must be great than or equal to 25.' end # resource path local_var_path = '/settlements/{id}/xls'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_settlement_xls", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_settlement_xls\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#show_transaction(currency, transaction_uuid, opts = {}) ⇒ Transaction
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency.
375 376 377 378 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 375 def show_transaction(currency, transaction_uuid, opts = {}) data, _status_code, _headers = show_transaction_with_http_info(currency, transaction_uuid, opts) data end |
#show_transaction_with_http_info(currency, transaction_uuid, opts = {}) ⇒ Array<(Transaction, Integer, Hash)>
Balance: Transaction Retrieves a single ledger transaction by its UUID for the given currency.
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/komoju-sdk/api/settlements_api.rb', line 386 def show_transaction_with_http_info(currency, transaction_uuid, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SettlementsApi.show_transaction ...' end # verify the required parameter 'currency' is set if @api_client.config.client_side_validation && currency.nil? fail ArgumentError, "Missing the required parameter 'currency' when calling SettlementsApi.show_transaction" end # verify the required parameter 'transaction_uuid' is set if @api_client.config.client_side_validation && transaction_uuid.nil? fail ArgumentError, "Missing the required parameter 'transaction_uuid' when calling SettlementsApi.show_transaction" end if @api_client.config.client_side_validation && transaction_uuid.to_s.length > 25 fail ArgumentError, 'invalid value for "transaction_uuid" when calling SettlementsApi.show_transaction, the character length must be smaller than or equal to 25.' end if @api_client.config.client_side_validation && transaction_uuid.to_s.length < 25 fail ArgumentError, 'invalid value for "transaction_uuid" when calling SettlementsApi.show_transaction, the character length must be great than or equal to 25.' end # resource path local_var_path = '/balances/{currency}/transactions/{transaction_uuid}'.sub('{' + 'currency' + '}', CGI.escape(currency.to_s)).sub('{' + 'transaction_uuid' + '}', CGI.escape(transaction_uuid.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Transaction' # auth_names auth_names = opts[:debug_auth_names] || ['api_key'] = opts.merge( :operation => :"SettlementsApi.show_transaction", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SettlementsApi#show_transaction\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |