Class: Komoju::ThreeDsAuthResult

Inherits:
Object
  • Object
show all
Defined in:
lib/komoju-sdk/models/three_ds_auth_result.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ThreeDsAuthResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Komoju::ThreeDsAuthResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Komoju::ThreeDsAuthResult`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ds_reference_number')
    self.ds_reference_number = attributes[:'ds_reference_number']
  else
    self.ds_reference_number = nil
  end

  if attributes.key?(:'acs_reference_number')
    self.acs_reference_number = attributes[:'acs_reference_number']
  else
    self.acs_reference_number = nil
  end

  if attributes.key?(:'three_ds_requestor_trans_id')
    self.three_ds_requestor_trans_id = attributes[:'three_ds_requestor_trans_id']
  else
    self.three_ds_requestor_trans_id = nil
  end

  if attributes.key?(:'acs_trans_id')
    self.acs_trans_id = attributes[:'acs_trans_id']
  else
    self.acs_trans_id = nil
  end

  if attributes.key?(:'ds_trans_id')
    self.ds_trans_id = attributes[:'ds_trans_id']
  else
    self.ds_trans_id = nil
  end

  if attributes.key?(:'eci')
    self.eci = attributes[:'eci']
  else
    self.eci = nil
  end

  if attributes.key?(:'message_version')
    self.message_version = attributes[:'message_version']
  else
    self.message_version = nil
  end

  if attributes.key?(:'authentication_type')
    self.authentication_type = attributes[:'authentication_type']
  else
    self.authentication_type = nil
  end

  if attributes.key?(:'authentication_value')
    self.authentication_value = attributes[:'authentication_value']
  else
    self.authentication_value = nil
  end

  if attributes.key?(:'trans_status')
    self.trans_status = attributes[:'trans_status']
  else
    self.trans_status = nil
  end

  if attributes.key?(:'three_ds_server_trans_id')
    self.three_ds_server_trans_id = attributes[:'three_ds_server_trans_id']
  else
    self.three_ds_server_trans_id = nil
  end
end

Instance Attribute Details

#acs_reference_numberObject

Access Control Server reference number assigned by the card scheme.



22
23
24
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 22

def acs_reference_number
  @acs_reference_number
end

#acs_trans_idObject

Access Control Server transaction ID assigned by the card issuer.



28
29
30
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 28

def acs_trans_id
  @acs_trans_id
end

#authentication_typeObject

Authentication type used for this 3DS transaction.



40
41
42
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 40

def authentication_type
  @authentication_type
end

#authentication_valueObject

Cardholder Authentication Verification Value (CAVV) from the issuer.



43
44
45
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 43

def authentication_value
  @authentication_value
end

#ds_reference_numberObject

Directory Server reference number for this 3DS transaction.



19
20
21
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 19

def ds_reference_number
  @ds_reference_number
end

#ds_trans_idObject

Directory Server transaction ID for this authentication.



31
32
33
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 31

def ds_trans_id
  @ds_trans_id
end

#eciObject

Electronic Commerce Indicator indicating the authentication outcome.



34
35
36
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 34

def eci
  @eci
end

#message_versionObject

Version of the 3DS protocol used (e.g. "2.1.0").



37
38
39
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 37

def message_version
  @message_version
end

#three_ds_requestor_trans_idObject

3DS requestor transaction ID generated by the merchant’s 3DS SDK.



25
26
27
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 25

def three_ds_requestor_trans_id
  @three_ds_requestor_trans_id
end

#three_ds_server_trans_idObject

3DS Server transaction ID assigned by the 3DS server.



49
50
51
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 49

def three_ds_server_trans_id
  @three_ds_server_trans_id
end

#trans_statusObject

Transaction status code (e.g. "Y" for authenticated, "N" for not authenticated).



46
47
48
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 46

def trans_status
  @trans_status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 311

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value) rescue value
  when :Date
    Date.parse(value) rescue value
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Komoju.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 69

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 52

def self.attribute_map
  {
    :'ds_reference_number' => :'dsReferenceNumber',
    :'acs_reference_number' => :'acsReferenceNumber',
    :'three_ds_requestor_trans_id' => :'threeDSRequestorTransID',
    :'acs_trans_id' => :'acsTransID',
    :'ds_trans_id' => :'dsTransID',
    :'eci' => :'eci',
    :'message_version' => :'messageVersion',
    :'authentication_type' => :'authenticationType',
    :'authentication_value' => :'authenticationValue',
    :'trans_status' => :'transStatus',
    :'three_ds_server_trans_id' => :'threeDSServerTransID'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 281

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  begin
    new(transformed_hash)
  rescue ArgumentError => e
    obj = allocate
    transformed_hash.each { |k, v| obj.instance_variable_set(:"@#{k}", v) }
    obj
  end
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 74

def self.openapi_types
  {
    :'ds_reference_number' => :'String',
    :'acs_reference_number' => :'String',
    :'three_ds_requestor_trans_id' => :'String',
    :'acs_trans_id' => :'String',
    :'ds_trans_id' => :'String',
    :'eci' => :'String',
    :'message_version' => :'String',
    :'authentication_type' => :'String',
    :'authentication_value' => :'String',
    :'trans_status' => :'String',
    :'three_ds_server_trans_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ds_reference_number == o.ds_reference_number &&
      acs_reference_number == o.acs_reference_number &&
      three_ds_requestor_trans_id == o.three_ds_requestor_trans_id &&
      acs_trans_id == o.acs_trans_id &&
      ds_trans_id == o.ds_trans_id &&
      eci == o.eci &&
      message_version == o.message_version &&
      authentication_type == o.authentication_type &&
      authentication_value == o.authentication_value &&
      trans_status == o.trans_status &&
      three_ds_server_trans_id == o.three_ds_server_trans_id
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 382

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


268
269
270
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 268

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



274
275
276
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 274

def hash
  [ds_reference_number, acs_reference_number, three_ds_requestor_trans_id, acs_trans_id, ds_trans_id, eci, message_version, authentication_type, authentication_value, trans_status, three_ds_server_trans_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 180

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ds_reference_number.nil?
    invalid_properties.push('invalid value for "ds_reference_number", ds_reference_number cannot be nil.')
  end

  if @acs_reference_number.nil?
    invalid_properties.push('invalid value for "acs_reference_number", acs_reference_number cannot be nil.')
  end

  if @three_ds_requestor_trans_id.nil?
    invalid_properties.push('invalid value for "three_ds_requestor_trans_id", three_ds_requestor_trans_id cannot be nil.')
  end

  if @acs_trans_id.nil?
    invalid_properties.push('invalid value for "acs_trans_id", acs_trans_id cannot be nil.')
  end

  if @ds_trans_id.nil?
    invalid_properties.push('invalid value for "ds_trans_id", ds_trans_id cannot be nil.')
  end

  if @eci.nil?
    invalid_properties.push('invalid value for "eci", eci cannot be nil.')
  end

  if @message_version.nil?
    invalid_properties.push('invalid value for "message_version", message_version cannot be nil.')
  end

  if @authentication_type.nil?
    invalid_properties.push('invalid value for "authentication_type", authentication_type cannot be nil.')
  end

  if @authentication_value.nil?
    invalid_properties.push('invalid value for "authentication_value", authentication_value cannot be nil.')
  end

  if @trans_status.nil?
    invalid_properties.push('invalid value for "trans_status", trans_status cannot be nil.')
  end

  if @three_ds_server_trans_id.nil?
    invalid_properties.push('invalid value for "three_ds_server_trans_id", three_ds_server_trans_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 358

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 364

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



352
353
354
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 352

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/komoju-sdk/models/three_ds_auth_result.rb', line 232

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ds_reference_number.nil?
  return false if @acs_reference_number.nil?
  return false if @three_ds_requestor_trans_id.nil?
  return false if @acs_trans_id.nil?
  return false if @ds_trans_id.nil?
  return false if @eci.nil?
  return false if @message_version.nil?
  return false if @authentication_type.nil?
  return false if @authentication_value.nil?
  return false if @trans_status.nil?
  return false if @three_ds_server_trans_id.nil?
  true
end